@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1993--2014 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1993--2020 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -17,13 +17,16 @@
   along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+// Needed because of extension definitions for POSIX functions.
+#include "config.hh"
+
 #include "polynomial.hh"
 
 #include "warn.hh"
 
 #include <cmath>
 
-using namespace std;
+using std::vector;
 
 /*
   Een beter milieu begint bij uzelf. Hergebruik!
@@ -49,11 +52,11 @@ Polynomial::multiply (const Polynomial &p1, const Polynomial &p2)
 {
   Polynomial dest;
 
-  ssize_t deg = p1.degree () + p2.degree ();
-  for (ssize_t i = 0; i <= deg; i++)
+  size_t deg = p1.degree () + p2.degree ();
+  for (size_t i = 0; i <= deg; i++)
     {
       dest.coefs_.push_back (0);
-      for (ssize_t j = 0; j <= i; j++)
+      for (size_t j = 0; j <= i; j++)
         if (i - j <= p2.degree () && j <= p1.degree ())
           dest.coefs_.back () += p1.coefs_[j] * p2.coefs_[i - j];
     }
@@ -61,37 +64,11 @@ Polynomial::multiply (const Polynomial &p1, const Polynomial &p2)
   return dest;
 }
 
-Real
-Polynomial::minmax (Real l, Real r, bool ret_max) const
-{
-  vector<Real> sols;
-  if (l > r)
-    {
-      programming_error ("left bound greater than right bound for polynomial minmax.  flipping bounds.");
-      l = l + r;
-      r = l - r;
-      l = l - r;
-    }
-
-  sols.push_back (eval (l));
-  sols.push_back (eval (r));
-
-  Polynomial deriv (*this);
-  deriv.differentiate ();
-  vector<Real> maxmins = deriv.solve ();
-  for (vsize i = 0; i < maxmins.size (); i++)
-    if (maxmins[i] >= l && maxmins[i] <= r)
-      sols.push_back (eval (maxmins[i]));
-  vector_sort (sols, less<Real> ());
-
-  return ret_max ? sols.back () : sols[0];
-}
-
 void
 Polynomial::differentiate ()
 {
-  for (int i = 1; i <= degree (); i++)
-    coefs_[i - 1] = coefs_[i] * i;
+  for (size_t i = 1; i <= degree (); i++)
+    coefs_[i - 1] = coefs_[i] * static_cast<double> (i);
   coefs_.pop_back ();
 }
 
@@ -130,8 +107,8 @@ Polynomial::clean ()
     We only do relative comparisons. Absolute comparisons break down in
     degenerate cases.  */
   while (degree () > 0
-         && (fabs (coefs_.back ()) < FUDGE * fabs (back (coefs_, 1))
-             || !coefs_.back ()))
+         && (fabs (coefs_.back ()) < FUDGE * fabs (coefs_.rbegin()[1])
+             || coefs_.back () == 0))
     coefs_.pop_back ();
 }
 
@@ -141,7 +118,7 @@ Polynomial::operator += (Polynomial const &p)
   while (degree () < p.degree ())
     coefs_.push_back (0.0);
 
-  for (int i = 0; i <= p.degree (); i++)
+  for (size_t i = 0; i <= p.degree (); i++)
     coefs_[i] += p.coefs_[i];
 }
 
@@ -151,78 +128,21 @@ Polynomial::operator -= (Polynomial const &p)
   while (degree () < p.degree ())
     coefs_.push_back (0.0);
 
-  for (int i = 0; i <= p.degree (); i++)
+  for (size_t i = 0; i <= p.degree (); i++)
     coefs_[i] -= p.coefs_[i];
 }
 
 void
 Polynomial::scalarmultiply (Real fact)
 {
-  for (int i = 0; i <= degree (); i++)
+  for (size_t i = 0; i <= degree (); i++)
     coefs_[i] *= fact;
 }
 
-void
-Polynomial::set_negate (const Polynomial &src)
-{
-  for (int i = 0; i <= src.degree (); i++)
-    coefs_[i] = -src.coefs_[i];
-}
-
-/// mod of #u/v#
-int
-Polynomial::set_mod (const Polynomial &u, const Polynomial &v)
-{
-  (*this) = u;
-
-  if (v.lc () < 0.0)
-    {
-      for (ssize_t k = u.degree () - v.degree () - 1; k >= 0; k -= 2)
-        coefs_[k] = -coefs_[k];
-
-      for (ssize_t k = u.degree () - v.degree (); k >= 0; k--)
-        for (ssize_t j = v.degree () + k - 1; j >= k; j--)
-          coefs_[j] = -coefs_[j] - coefs_[v.degree () + k] * v.coefs_[j - k];
-    }
-  else
-
-    {
-      for (ssize_t k = u.degree () - v.degree (); k >= 0; k--)
-        for (ssize_t j = v.degree () + k - 1; j >= k; j--)
-          coefs_[j] -= coefs_[v.degree () + k] * v.coefs_[j - k];
-    }
-
-  ssize_t k = v.degree () - 1;
-  while (k >= 0 && coefs_[k] == 0.0)
-    k--;
-
-  coefs_.resize (1 + ((k < 0) ? 0 : k));
-  return degree ();
-}
-
-void
-Polynomial::check_sol (Real x) const
-{
-  Real f = eval (x);
-  Polynomial p (*this);
-  p.differentiate ();
-  Real d = p.eval (x);
-
-  if (abs (f) > abs (d) * FUDGE)
-    programming_error ("not a root of polynomial\n");
-}
-
-void
-Polynomial::check_sols (vector<Real> roots) const
-{
-  for (vsize i = 0; i < roots.size (); i++)
-    check_sol (roots[i]);
-}
-
 Polynomial::Polynomial (Real a, Real b)
 {
   coefs_.push_back (a);
-  if (b)
+  if (b != 0)
     coefs_.push_back (b);
 }
 
@@ -236,12 +156,6 @@ inline Real cubic_root (Real x)
   return 0.0;
 }
 
-static bool
-iszero (Real r)
-{
-  return !r;
-}
-
 vector<Real>
 Polynomial::solve_cubic ()const
 {
@@ -265,9 +179,9 @@ Polynomial::solve_cubic ()const
   Real cb = p * p * p;
   Real D = q * q + cb;
 
-  if (iszero (D))
+  if (D == 0)
     {
-      if (iszero (q))   /* one triple solution */
+      if (q == 0)   /* one triple solution */
         {
           sol.push_back (0);
           sol.push_back (0);
@@ -316,20 +230,8 @@ Polynomial::solve_cubic ()const
   return sol;
 }
 
-Real
-Polynomial::lc () const
-{
-  return coefs_.back ();
-}
-
-Real &
-Polynomial::lc ()
-{
-  return coefs_.back ();
-}
-
-ssize_t
-Polynomial::degree ()const
+size_t
+Polynomial::degree () const
 {
   return coefs_.size () - 1;
 }
@@ -361,7 +263,7 @@ vector<Real>
 Polynomial::solve_linear ()const
 {
   vector<Real> s;
-  if (coefs_[1])
+  if (coefs_[1] != 0)
     s.push_back (-coefs_[0] / coefs_[1]);
   return s;
 }
