@@ -22,8 +22,7 @@
 #include <cmath>
 #include <cassert>
 #include <cstdlib>
-
-#include "string-convert.hh"
+#include <utility>
 
 using std::string;
 
@@ -68,20 +67,20 @@ operator << (ostream &o, Rational r)
 Rational
 Rational::abs () const
 {
-  return Rational (num_, den_);
+  return Rational (::abs (sign_), num_, den_);
 }
 
 I64
 Rational::trunc_int () const
 {
-  I64 i = num_ / den_;
-  return i * sign_;
+  U64 i = num_ / den_;
+  return static_cast<I64> (i) * sign_;
 }
 
 Rational
 Rational::trunc_rat () const
 {
-  if (is_infinity ())
+  if (isinf (*this))
     return *this;
   return Rational ((num_ - (num_ % den_)) * sign_, den_);
 }
@@ -90,15 +89,15 @@ Rational::Rational (I64 n, I64 d)
 {
   // use sign of n when d=0
   sign_ = ::sign (n) * (std::signbit (d) ? -1 : 1);
-  num_ = ::abs (n);
-  den_ = ::abs (d);
+  num_ = static_cast<U64> (::abs (n));
+  den_ = static_cast<U64> (::abs (d));
   normalize ();
 }
 
 Rational::Rational (long long n)
 {
   sign_ = ::sign (n);
-  num_ = ::abs (n);
+  num_ = static_cast<U64> (::abs (n));
   den_ = 1;
 }
 
@@ -209,7 +208,7 @@ Rational::compare (Rational const &r, Rational const &s)
     return -1;
   else if (r.sign_ > s.sign_)
     return 1;
-  else if (r.is_infinity ()) // here s is also infinite with the same sign
+  else if (isinf (r)) // here s is also infinite with the same sign
     return 0;
   else if (r.sign_ == 0) // here s.sign_ is also zero
     return 0;
@@ -248,9 +247,9 @@ Rational::operator += (Rational r)
     ;
   else if (sign_ == 0)
     *this = r;
-  else if (is_infinity ())
+  else if (isinf (*this))
     ;
-  else if (r.is_infinity ())
+  else if (isinf (r))
     *this = r;
   else
     {
@@ -258,8 +257,8 @@ Rational::operator += (Rational r)
       I64 n = sign_ * num_ * (lcm / den_) + r.sign_ * r.num_ * (lcm / r.den_);
       I64 d = lcm;
       sign_ = ::sign (n) * ::sign (d);
-      num_ = ::abs (n);
-      den_ = ::abs (d);
+      num_ = static_cast<U64> (::abs (n));
+      den_ = static_cast<U64> (::abs (d));
       normalize ();
     }
   return *this;
@@ -315,16 +314,14 @@ Rational::Rational (double x)
 void
 Rational::invert ()
 {
-  I64 r (num_);
-  num_ = den_;
-  den_ = r;
+  std::swap (num_, den_);
 }
 
 Rational &
 Rational::operator *= (Rational r)
 {
   sign_ *= ::sign (r.sign_);
-  if (r.is_infinity ())
+  if (isinf (r))
     {
       sign_ = sign () * 2;
       goto exit_func;
@@ -361,7 +358,7 @@ Rational::operator -= (Rational r)
 string
 Rational::to_string () const
 {
-  if (is_infinity ())
+  if (isinf (*this))
     {
       return string (sign_ > 0 ? "" : "-") + "infinity";
     }
@@ -377,9 +374,3 @@ sign (Rational r)
 {
   return r.sign ();
 }
-
-bool
-Rational::is_infinity () const
-{
-  return sign_ == 2 || sign_ == -2;
-}
