@@ -41,25 +41,22 @@ using std::string;
 */
 static const int STRING_BUFFER_LEN = 1024;
 
+static char
+nibble2hex (Byte byte)
+{
+  const auto nibble = byte & 0x0f;
+  if (nibble <= 9)
+    return static_cast<char> ('0' + nibble);
+  else
+    return static_cast<char> ('a' + (nibble - 10));
+}
+
 string
 String_convert::bin2hex (Byte bin_char)
 {
   string str;
-  str += nibble2hex_byte ((Byte) (bin_char >> 4));
-  str += nibble2hex_byte (bin_char++);
-  return str;
-}
-
-string
-String_convert::bin2hex (const string &bin_string)
-{
-  string str;
-  Byte const *byte = (Byte const *)bin_string.data ();
-  for (ssize i = 0; i < bin_string.length (); i++)
-    {
-      str += nibble2hex_byte ((Byte) (*byte >> 4));
-      str += nibble2hex_byte (*byte++);
-    }
+  str += nibble2hex ((Byte) (bin_char >> 4));
+  str += nibble2hex (bin_char);
   return str;
 }
 
@@ -120,42 +117,6 @@ String_convert::hex2nibble (Byte byte)
   return -1;
 }
 
-// stupido.  Should use int_string ()
-string
-String_convert::unsigned2hex (unsigned u, size_t length, char fill_char)
-{
-  string str;
-  if (!u)
-    str = "0";
-
-  while (u)
-    {
-      str = string (1, (char) ((u % 16)["0123456789abcdef"])) + str;
-      u /= 16;
-    }
-
-  if (str.length () < length)
-    str = string (length - str.length (), fill_char) + str;
-  while ((str.length () > length) && (str[ 0 ] == 'f'))
-    str = str.substr (2);
-
-  return str;
-}
-
-string
-String_convert::int2hex (int i, size_t length_i, char fill_char)
-{
-  return unsigned2hex ((unsigned)i, length_i, fill_char);
-}
-
-Byte
-String_convert::nibble2hex_byte (Byte byte)
-{
-  if ((byte & 0x0f) <= 9)
-    return (Byte) ((byte & 0x0f) + '0');
-  else
-    return (Byte) ((byte & 0x0f) - 10 + 'a');
-}
 /**
    Convert an integer to a string
 
@@ -193,14 +154,17 @@ String_convert::vform_string (char const *format, va_list args)
 string
 String_convert::pad_to (const string &s, size_t n)
 {
-  return s + string (std::max (int (n - s.length ()), 0), ' ');
+  size_t length = s.length ();
+  if (n <= length)
+    return s;
+  return s + string (n - length, ' ');
 }
 
 string
 String_convert::to_upper (string s)
 {
   // Implicit copy of argument, no reference.
-  std::transform(s.begin (), s.end (), s.begin (), ::toupper);
+  std::transform (s.begin (), s.end (), s.begin (), ::toupper);
   return s;
 }
 
@@ -208,36 +172,36 @@ string
 String_convert::to_lower (string s)
 {
   // Implicit copy of argument, no reference.
-  std::transform(s.begin (), s.end (), s.begin (), ::tolower);
+  std::transform (s.begin (), s.end (), s.begin (), ::tolower);
   return s;
 }
 
 string
 String_convert::be_u16 (uint16_t u)
 {
-  char r[2];
+  uint8_t r[2];
   r[0] = uint8_t (u >> 8);
   r[1] = uint8_t (u);
-  return string (r, 2);
+  return string (reinterpret_cast<char*> (r), 2);
 }
 
 string
 String_convert::be_u32 (uint32_t u)
 {
-  char r[4];
+  uint8_t r[4];
   r[0] = uint8_t (u >> 24);
   r[1] = uint8_t (u >> 16);
   r[2] = uint8_t (u >> 8);
   r[3] = uint8_t (u);
-  return string (r, 4);
+  return string (reinterpret_cast<char*> (r), 4);
 }
 
 string
 String_convert::be_u24 (uint32_t u)
 {
-  char r[3];
+  uint8_t r[3];
   r[0] = uint8_t (u >> 16);
   r[1] = uint8_t (u >> 8);
   r[2] = uint8_t (u);
-  return string (r, 3);
+  return string (reinterpret_cast<char*> (r), 3);
 }
