@@ -31,8 +31,10 @@
 #include "stream-event.hh"
 #include "warn.hh"
 
+#include <algorithm>
 #include <functional>
 #include <memory>
+#include <vector>
 
 using std::unique_ptr;
 using std::vector;
@@ -191,7 +193,7 @@ acc_less (Grob *const &a, Grob *const &b)
 void
 stagger_apes (vector<unique_ptr<Accidental_placement_entry>> *apes)
 {
-  vector_sort (*apes, &ape_less);
+  std::sort (apes->begin (), apes->end (), &ape_less);
   // we do the staggering below based on size
   // this ensures that if a placement has 4 entries, it will
   // always be closer to the NoteColumn than a placement with 1
@@ -231,7 +233,7 @@ stagger_apes (vector<unique_ptr<Accidental_placement_entry>> *apes)
         }
     }
 
-  reverse (*apes);
+  std::reverse (apes->begin (), apes->end ());
 }
 
 static vector<unique_ptr<Accidental_placement_entry>>
@@ -257,7 +259,7 @@ set_ape_skylines (Accidental_placement_entry *ape,
                   Grob **common, Real padding)
 {
   vector<Grob *> accs (ape->grobs_);
-  vector_sort (accs, &acc_less);
+  std::sort (accs.begin (), accs.end (), &acc_less);
 
   /* We know that each accidental has the same note name and we assume that
      accidentals in different octaves won't collide. If two or more
@@ -337,13 +339,16 @@ extract_heads_and_stems (vector<unique_ptr<Accidental_placement_entry>> const &a
       if (has_interface<Note_collision_interface> (c))
         {
           extract_grob_set (c, "elements", columns);
-          concat (note_cols, columns);
+          note_cols.insert (note_cols.end (), columns.begin (), columns.end ());
         }
     }
 
   /* Now that we have all of the columns, grab all of the note-heads */
   for (vsize i = note_cols.size (); i--;)
-    concat (ret, extract_grob_array (note_cols[i], "note-heads"));
+    {
+      const auto &note_heads = extract_grob_array (note_cols[i], "note-heads");
+      ret.insert (ret.end (), note_heads.begin (), note_heads.end ());
+    }
 
   /* Now that we have all of the heads, grab all of the stems */
   for (vsize i = ret.size (); i--;)
