@@ -49,39 +49,44 @@ protected:
 
   void acknowledge_rest (Grob_info);
   void acknowledge_beam (Grob_info);
-  void acknowledge_bar_line (Grob_info);
   void acknowledge_breathing_sign (Grob_info);
   void acknowledge_stem (Grob_info);
   void listen_beam_forbid (Stream_event *);
 
 private:
   virtual bool test_moment (Direction, Moment, Moment);
+  bool busy () const { return beam_start_moment_ < Moment::infinity (); }
   void consider_begin (Moment, Moment);
   void consider_end (Moment, Moment);
   Spanner *create_beam ();
   void begin_beam ();
   void end_beam ();
+  void handle_current_stem (Item *stem);
   void junk_beam ();
   virtual bool is_same_grace_state (Moment, Moment);
   void recheck_beam ();
   void typeset_beam ();
-  vector<Item *> *remove_end_stems (vsize);
 
-  Stream_event *forbid_;
+  Stream_event *forbid_ = nullptr;
+  bool force_end_ = false;
+  bool considered_bar_ = false;
   /*
     shortest_mom_ is the shortest note in the beam.
   */
-  Moment shortest_mom_;
-  Spanner *finished_beam_;
-  vector<Item *> *stems_;
+  Moment shortest_mom_ {Rational (1, 4)};
+  Spanner *finished_beam_ = nullptr;
+  // This engraver is designed to operate in Voice context, so we expect only
+  // one stem per timestep.
+  Item *current_stem_ = nullptr;
+  vector<Item *> stems_;
 
-  int process_acknowledged_count_;
+  int process_acknowledged_count_ = 0;
   Moment last_add_mom_;
   /*
     Projected ending of the  beam we're working on.
   */
-  Moment extend_mom_;
-  Moment beam_start_moment_;
+  Moment extend_mom_ {-1};
+  Moment beam_start_moment_ = Moment::infinity ();
   Moment beam_start_location_;
   /*
     Handle on the starting staff keeps it alive until beam is comlete
@@ -89,38 +94,19 @@ private:
   Context_handle beam_start_context_;
 
   // We act as if beam were created, and start a grouping anyway.
-  Beaming_pattern *grouping_;
-  SCM beam_settings_;
+  Beaming_pattern *grouping_ = nullptr;
+  SCM beam_settings_ = SCM_EOL;
 
-  Beaming_pattern *finished_grouping_;
+  Beaming_pattern *finished_grouping_ = nullptr;
 
   Beaming_options beaming_options_;
   Beaming_options finished_beaming_options_;
-
-  void check_bar_property ();
 };
 
 void
 Auto_beam_engraver::derived_mark () const
 {
   scm_gc_mark (beam_settings_);
-  beaming_options_.gc_mark ();
-  finished_beaming_options_.gc_mark ();
-}
-
-void
-Auto_beam_engraver::check_bar_property ()
-{
-  /* Duplicated from process_music (), since
-     Repeat_acknowledge_engraver::process_music () may also set whichBar.  */
-
-  Moment now = now_mom ();
-  if (scm_is_string (get_property (this, "whichBar"))
-      && beam_start_moment_ < now)
-    {
-      consider_end (measure_position (context ()), shortest_mom_);
-      junk_beam ();
-    }
 }
 
 void
@@ -130,45 +116,23 @@ Auto_beam_engraver::process_music ()
   /*
     don't beam over skips
   */
-  if (stems_)
+  if (busy ())
     {
       if (extend_mom_ < now)
         end_beam ();
     }
-
-  if (scm_is_string (get_property (this, "whichBar")))
-    {
-      consider_end (measure_position (context ()), shortest_mom_);
-      junk_beam ();
-    }
-
-  if (forbid_)
-    {
-      if (stems_)
-        end_beam ();
-      else
-        junk_beam ();
-    }
 }
 
 Auto_beam_engraver::Auto_beam_engraver (Context *c)
   : Engraver (c)
 {
-  forbid_ = 0;
-  process_acknowledged_count_ = 0;
-  stems_ = 0;
-  shortest_mom_ = Moment (Rational (1, 4));
-  extend_mom_ = Moment (-1);
-  finished_beam_ = 0;
-  finished_grouping_ = 0;
-  grouping_ = 0;
-  beam_settings_ = SCM_EOL;
 }
 
 void
 Auto_beam_engraver::listen_beam_forbid (Stream_event *ev)
 {
   ASSIGN_EVENT_ONCE (forbid_, ev);
+  force_end_ = true;
 }
 
 bool
@@ -184,20 +148,18 @@ Auto_beam_engraver::test_moment (Direction dir, Moment test_mom, Moment dur)
 void
 Auto_beam_engraver::consider_begin (Moment test_mom, Moment dur)
 {
-  bool on = from_scm<bool> (get_property (this, "autoBeaming"));
-  if (!stems_ && on
-      && !forbid_)
+  if (!busy () && !forbid_
+      && from_scm<bool> (get_property (this, "autoBeaming"))
+      && test_moment (START, test_mom, dur))
     {
-      bool b = test_moment (START, test_mom, dur);
-      if (b)
-        begin_beam ();
+      begin_beam ();
     }
 }
 
 void
 Auto_beam_engraver::consider_end (Moment test_mom, Moment dur)
 {
-  if (stems_)
+  if (busy ())
     {
       /* Allow already started autobeam to end:
          don't check for autoBeaming */
@@ -213,8 +175,8 @@ Auto_beam_engraver::create_beam ()
   if (from_scm<bool> (get_property (this, "skipTypesetting")))
     return 0;
 
-  for (vsize i = 0; i < stems_->size (); i++)
-    if (Stem::get_beam ((*stems_)[i]))
+  for (const auto &stem : stems_)
+    if (Stem::get_beam (stem))
       return 0;
 
   /*
@@ -223,10 +185,10 @@ Auto_beam_engraver::create_beam ()
   */
   Spanner *beam = new Spanner (beam_settings_);
 
-  for (vsize i = 0; i < stems_->size (); i++)
-    Beam::add_stem (beam, (*stems_)[i]);
+  for (const auto &stem : stems_)
+    Beam::add_stem (beam, stem);
 
-  Grob_info i = make_grob_info (beam, (*stems_)[0]->self_scm ());
+  Grob_info i = make_grob_info (beam, stems_[0]->self_scm ());
   announce_grob (i, beam_start_context_.get_context ());
 
   return beam;
@@ -235,31 +197,31 @@ Auto_beam_engraver::create_beam ()
 void
 Auto_beam_engraver::begin_beam ()
 {
-  if (stems_ || grouping_)
+  if (busy () || grouping_)
     {
       programming_error ("already have autobeam");
       return;
     }
 
-  stems_ = new vector<Item *>;
+  stems_.clear ();
   grouping_ = new Beaming_pattern ();
   beaming_options_.from_context (context ());
   beam_settings_ = Grob_property_info (context (), ly_symbol2scm ("Beam")).updated ();
 
   beam_start_context_.set_context (context ()->get_parent ());
-  beam_start_moment_ = now_mom ();
   beam_start_location_
     = robust_scm2moment (get_property (this, "measurePosition"), Moment (0));
+  beam_start_moment_ = now_mom ();
 }
 
 void
 Auto_beam_engraver::junk_beam ()
 {
-  if (!stems_)
+  if (!busy ())
     return;
 
-  delete stems_;
-  stems_ = 0;
+  beam_start_moment_ = Moment::infinity ();
+  stems_.clear ();
   delete grouping_;
   grouping_ = 0;
   beam_settings_ = SCM_EOL;
@@ -276,7 +238,7 @@ Auto_beam_engraver::is_same_grace_state (Moment start, Moment now)
 void
 Auto_beam_engraver::end_beam ()
 {
-  if (stems_->size () < 2)
+  if (stems_.size () < 2)
     junk_beam ();
   else
     {
@@ -290,8 +252,8 @@ Auto_beam_engraver::end_beam ()
           finished_grouping_ = grouping_;
           finished_beaming_options_ = beaming_options_;
         }
-      delete stems_;
-      stems_ = 0;
+      beam_start_moment_ = Moment::infinity ();
+      stems_.clear ();
       grouping_ = 0;
       beam_settings_ = SCM_EOL;
     }
@@ -323,6 +285,7 @@ Auto_beam_engraver::stop_translation_timestep ()
   typeset_beam ();
   process_acknowledged_count_ = 0;
   forbid_ = 0;
+  considered_bar_ = false;
 }
 
 void
@@ -331,48 +294,38 @@ Auto_beam_engraver::finalize ()
   /* finished beams may be typeset */
   typeset_beam ();
   /* but unfinished may need another announce/acknowledge pass */
-  if (stems_)
+  if (busy ())
     junk_beam ();
 }
 
 void
 Auto_beam_engraver::acknowledge_beam (Grob_info /* info */)
 {
-  check_bar_property ();
-  if (stems_)
-    end_beam ();
-}
-
-void
-Auto_beam_engraver::acknowledge_bar_line (Grob_info /* info */)
-{
-  check_bar_property ();
-  if (stems_)
-    end_beam ();
+  force_end_ = true;
 }
 
 void
 Auto_beam_engraver::acknowledge_breathing_sign (Grob_info /* info */)
 {
-  check_bar_property ();
-  if (stems_)
-    end_beam ();
+  force_end_ = true;
 }
 
 void
 Auto_beam_engraver::acknowledge_rest (Grob_info /* info */)
 {
-  check_bar_property ();
-  if (stems_)
-    end_beam ();
+  force_end_ = true;
 }
 
 void
 Auto_beam_engraver::acknowledge_stem (Grob_info info)
 {
-  check_bar_property ();
-  Item *stem = dynamic_cast<Item *> (info.grob ());
-  Stream_event *ev = info.ultimate_event_cause ();
+  current_stem_ = dynamic_cast<Item *> (info.grob ());
+}
+
+void
+Auto_beam_engraver::handle_current_stem (Item *stem)
+{
+  auto *const ev = stem->ultimate_event_cause ();
   if (!ev->in_event_class ("rhythmic-event"))
     {
       programming_error ("stem must have rhythmic structure");
@@ -384,23 +337,24 @@ Auto_beam_engraver::acknowledge_stem (Grob_info info)
   */
   if (!Stem::head_count (stem))
     {
-      if (stems_)
+      if (busy ())
         end_beam ();
       return;
     }
 
   if (Stem::get_beam (stem))
     {
-      if (stems_)
+      if (busy ())
         junk_beam ();
       return;
     }
 
-  int durlog = unsmob<Duration> (get_property (ev, "duration"))->duration_log ();
+  auto *const stem_duration = unsmob<Duration> (get_property (ev, "duration"));
+  const auto durlog = stem_duration->duration_log ();
 
   if (durlog <= 2)
     {
-      if (stems_)
+      if (busy ())
         end_beam ();
       return;
     }
@@ -412,10 +366,7 @@ Auto_beam_engraver::acknowledge_stem (Grob_info info)
   if (!is_same_grace_state (beam_start_location_, now))
     return;
 
-  Duration *stem_duration = unsmob<Duration> (get_property (ev, "duration"));
   Moment dur (stem_duration->get_length ());
-
-  //Moment dur = unsmob<Duration> (get_property (ev, "duration"))->get_length ();
   Moment measure_now = measure_position (context ());
   bool recheck_needed = false;
 
@@ -431,7 +382,7 @@ Auto_beam_engraver::acknowledge_stem (Grob_info info)
   consider_end (measure_now, shortest_mom_);
   consider_begin (measure_now, dur);
 
-  if (!stems_)
+  if (!busy ())
     return;
 
   grouping_->add_stem (now - beam_start_moment_ + beam_start_location_,
@@ -439,7 +390,7 @@ Auto_beam_engraver::acknowledge_stem (Grob_info info)
                        Stem::is_invisible (stem),
                        stem_duration->factor (),
                        (from_scm<bool> (get_property (stem, "tuplet-start"))));
-  stems_->push_back (stem);
+  stems_.push_back (stem);
   last_add_mom_ = now;
   extend_mom_ = std::max (extend_mom_, now) + get_event_length (ev, now);
   if (recheck_needed)
@@ -456,13 +407,13 @@ Auto_beam_engraver::recheck_beam ()
     the last part of the beam
   */
   Beaming_pattern *new_grouping_ = 0;
-  vector<Item *> *new_stems_ = 0;
+  vector<Item *> new_stems;
   Moment temporary_shortest_mom;
   SCM temporary_beam_settings;
 
   bool found_end;
 
-  for (vsize i = 0; i < stems_->size () - 1;)
+  for (vsize i = 0; (i + 1) < stems_.size (); /*in body*/)
     {
       found_end = test_moment (STOP,
                                grouping_->end_moment (i),
@@ -481,16 +432,21 @@ Auto_beam_engraver::recheck_beam ()
           /* Eliminate (and save) the items no longer part of the first beam */
 
           new_grouping_ = grouping_->split_pattern (i);
-          new_stems_ = remove_end_stems (i);
+          new_stems.insert (new_stems.end (),
+                            std::next (stems_.begin (), i + 1),
+                            stems_.end ());
+          stems_.resize (i + 1);
 
           end_beam ();
           typeset_beam ();
 
           /* now recreate the unbeamed data structures */
-          stems_ = new_stems_;
+          stems_ = std::move (new_stems);
+          new_stems.clear ();
           grouping_ = new_grouping_;
           shortest_mom_ = temporary_shortest_mom;
           beam_settings_ = temporary_beam_settings;
+          beam_start_moment_ = now_mom ();
 
           i = 0;
         }
@@ -499,44 +455,55 @@ Auto_beam_engraver::recheck_beam ()
 
 }
 
-/*
-  Remove all stems with an index greater than split_index
-  from stems_, and return a vector containing all of the
-  removed stems
-*/
-vector <Item *> *
-Auto_beam_engraver::remove_end_stems (vsize split_index)
-{
-  vector <Item *> *removed_stems = 0;
-  removed_stems = new vector <Item *>;
-
-  for (vsize j = split_index + 1; j < stems_->size (); j++)
-    removed_stems->push_back ((*stems_).at (j));
-  for (vsize j = split_index + 1; j < stems_->size ();)
-    stems_->pop_back ();
-  return removed_stems;
-}
-
 void
 Auto_beam_engraver::process_acknowledged ()
 {
+  if (force_end_)
+    {
+      force_end_ = false;
+
+      if (busy ())
+        end_beam ();
+    }
+
+  // This engraver can't observe bar lines with acknowledge_bar_line () because
+  // the Bar_engraver operates in Staff context.  Instead, we check the
+  // whichBar property, which also controls the Bar_engraver.
+  // process_acknowledged () can be called more than once, but whichBar won't
+  // change.
+  if (!considered_bar_)
+    {
+      considered_bar_ = true;
+
+      if (busy () && scm_is_string (get_property (this, "whichBar")))
+        {
+          consider_end (measure_position (context ()), shortest_mom_);
+          junk_beam ();
+        }
+    }
+
+  if (current_stem_)
+    {
+      handle_current_stem (current_stem_);
+      current_stem_ = nullptr;
+    }
+
   Moment now = now_mom ();
   if (extend_mom_ > now)
     return;
 
-  if (!process_acknowledged_count_)
+  if (busy ())
     {
-      Moment measure_now = measure_position (context ());
-      consider_end (measure_now, shortest_mom_);
-    }
-  else if (process_acknowledged_count_ > 1)
-    {
-      if (stems_)
+      if (!process_acknowledged_count_)
+        {
+          consider_end (measure_position (context ()), shortest_mom_);
+        }
+      else if (process_acknowledged_count_ > 1)
         {
           if ((extend_mom_ < now)
               || ((extend_mom_ == now) && (last_add_mom_ != now)))
             end_beam ();
-          else if (!stems_->size ())
+          else if (stems_.empty ())
             junk_beam ();
         }
     }
@@ -549,7 +516,6 @@ Auto_beam_engraver::boot ()
 {
   ADD_LISTENER (Auto_beam_engraver, beam_forbid);
   ADD_ACKNOWLEDGER (Auto_beam_engraver, stem);
-  ADD_ACKNOWLEDGER (Auto_beam_engraver, bar_line);
   ADD_ACKNOWLEDGER (Auto_beam_engraver, beam);
   ADD_ACKNOWLEDGER (Auto_beam_engraver, breathing_sign);
   ADD_ACKNOWLEDGER (Auto_beam_engraver, rest);
@@ -643,7 +609,6 @@ Grace_auto_beam_engraver::boot ()
 {
   ADD_LISTENER (Grace_auto_beam_engraver, beam_forbid);
   ADD_ACKNOWLEDGER (Grace_auto_beam_engraver, stem);
-  ADD_ACKNOWLEDGER (Grace_auto_beam_engraver, bar_line);
   ADD_ACKNOWLEDGER (Grace_auto_beam_engraver, beam);
   ADD_ACKNOWLEDGER (Grace_auto_beam_engraver, breathing_sign);
   ADD_ACKNOWLEDGER (Grace_auto_beam_engraver, rest);
