@@ -38,7 +38,9 @@
 #include "warn.hh"
 #include "unpure-pure-container.hh"
 
+#include <algorithm>
 #include <map>
+#include <vector>
 
 using std::multimap;
 using std::pair;
@@ -92,9 +94,9 @@ Axis_group_interface::add_element (Grob *me, Grob *e)
         e->set_parent (me, a);
 
       set_object (e, (a == X_AXIS)
-                     ? ly_symbol2scm ("axis-group-parent-X")
-                     : ly_symbol2scm ("axis-group-parent-Y"),
-                     me->self_scm ());
+                  ? ly_symbol2scm ("axis-group-parent-X")
+                  : ly_symbol2scm ("axis-group-parent-Y"),
+                  me->self_scm ());
     }
 
   /* must be ordered, because Align_interface also uses
@@ -224,7 +226,7 @@ Axis_group_interface::combine_pure_heights (Grob *me, SCM measure_extents,
 {
   Paper_score *ps = get_root_system (me)->paper_score ();
   vector<vsize> const &break_ranks = ps->get_break_ranks ();
-  auto it = lower_bound (break_ranks.begin (), break_ranks.end (), start);
+  auto it = std::lower_bound (break_ranks.begin (), break_ranks.end (), start);
   vsize break_idx = it - break_ranks.begin ();
   vector<vsize> const &breaks = ps->get_break_indices ();
   vector<Paper_column *> const &cols = ps->get_columns ();
@@ -303,12 +305,12 @@ Axis_group_interface::adjacent_pure_heights (SCM smob)
       d = (d == CENTER) ? UP : d;
 
       Interval_t<vsize> rank_span (g->spanned_rank_interval ());
-      vsize first_break
-        = lower_bound (ranks, rank_span[LEFT], std::less<vsize> ());
-      if (first_break > 0 && ranks[first_break] >= rank_span[LEFT])
+      auto first_break
+        = std::lower_bound (ranks.begin (), ranks.end (), rank_span[LEFT]);
+      if (first_break != ranks.begin ())
         first_break--;
 
-      for (vsize j = first_break;
+      for (vsize j = first_break - ranks.begin ();
            j + 1 < ranks.size () && ranks[j] <= rank_span[RIGHT]; ++j)
         {
           vsize start = ranks[j];
@@ -547,7 +549,8 @@ Axis_group_interface::internal_calc_pure_relevant_grobs (Grob *me, const string
       relevant_grobs.push_back (elts[i]);
     }
 
-  vector_sort (relevant_grobs, pure_staff_priority_less);
+  std::sort (relevant_grobs.begin (), relevant_grobs.end (),
+             pure_staff_priority_less);
   SCM grobs_scm = Grob_array::make_array ();
   unsmob<Grob_array> (grobs_scm)->set_array (relevant_grobs);
 
@@ -682,10 +685,8 @@ pure_staff_priority_less (Grob *const &g1, Grob *const &g2)
         }
     }
 
-  Real priority_1 = from_scm<double> (
-    get_property (p[0], "outside-staff-priority"), -infinity_f);
-  Real priority_2 = from_scm<double> (
-    get_property (p[1], "outside-staff-priority"), -infinity_f);
+  Real priority_1 = from_scm<double> (get_property (p[0], "outside-staff-priority"), -infinity_f);
+  Real priority_2 = from_scm<double> (get_property (p[1], "outside-staff-priority"), -infinity_f);
 
   return priority_1 < priority_2;
 }
@@ -800,8 +801,8 @@ add_grobs_of_one_priority (Grob *me,
           Grob *elt = elements[i];
           Real padding
             = from_scm<double> (get_property (elt, "outside-staff-padding"),
-                                 Axis_group_interface
-                                 ::get_default_outside_staff_padding ());
+                                Axis_group_interface
+                                ::get_default_outside_staff_padding ());
           Real horizon_padding
             = from_scm<double> (get_property (elt, "outside-staff-horizontal-padding"), 0.0);
           Interval x_extent = elt->extent (x_common, X_AXIS);
@@ -893,12 +894,11 @@ Axis_group_interface::outside_staff_ancestor (Grob *me)
 Skyline_pair
 Axis_group_interface::skyline_spacing (Grob *me)
 {
-  extract_grob_set (
-    me,
-    unsmob<Grob_array> (get_object (me, "vertical-skyline-elements"))
-      ? "vertical-skyline-elements"
-      : "elements",
-    fakeelements);
+  extract_grob_set (me,
+                    unsmob<Grob_array> (get_object (me, "vertical-skyline-elements"))
+                    ? "vertical-skyline-elements"
+                    : "elements",
+                    fakeelements);
   vector<Grob *> elements (fakeelements);
   for (vsize i = 0; i < elements.size (); i++)
     /*
@@ -909,7 +909,7 @@ Axis_group_interface::skyline_spacing (Grob *me)
     if (scm_is_number (get_property (elements[i], "outside-staff-priority"))
         && outside_staff_ancestor (elements[i]))
       {
-        elements[i]->warning ("Cannot set outside-staff-priority for element and elements' Y parent.");
+        elements[i]->warning (_ ("Cannot set outside-staff-priority for element and elements' Y parent."));
         set_property (elements[i], "outside-staff-priority", SCM_BOOL_F);
       }
 
@@ -922,7 +922,7 @@ Axis_group_interface::skyline_spacing (Grob *me)
     if (scm_is_number (get_property (elements[i], "outside-staff-priority")))
       elements[i]->extent (elements[i], X_AXIS);
 
-  vector_stable_sort (elements, staff_priority_less);
+  std::stable_sort (elements.begin (), elements.end (), staff_priority_less);
   Grob *x_common = common_refpoint_of_array (elements, me, X_AXIS);
   Grob *y_common = common_refpoint_of_array (elements, me, Y_AXIS);
 
@@ -957,10 +957,8 @@ Axis_group_interface::skyline_spacing (Grob *me)
           if (maybe_pair->is_empty ())
             continue;
           inside_staff_skylines.push_back (*maybe_pair);
-          inside_staff_skylines.back ().shift (
-            elt->relative_coordinate (x_common, X_AXIS));
-          inside_staff_skylines.back ().raise (
-            elt->relative_coordinate (y_common, Y_AXIS));
+          inside_staff_skylines.back ().shift (elt->relative_coordinate (x_common, X_AXIS));
+          inside_staff_skylines.back ().raise (elt->relative_coordinate (y_common, Y_AXIS));
         }
     }
 
