@@ -18,41 +18,22 @@
 */
 
 #include "beam.hh"
-#include "context.hh"
 #include "engraver.hh"
 #include "item.hh"
 #include "note-head.hh"
 #include "pointer-group-interface.hh"
 #include "stem.hh"
 
-#include <unordered_set>
+#include <algorithm>
 #include <vector>
 
+using std::vector;
+
 class Beam_collision_engraver : public Engraver
 {
-  struct Grob_with_context
-  {
-    Grob_with_context (Grob *grob, Context const *context)
-      : grob_ (grob), context_ (context) { }
-
-    Grob *grob_;
-    Context const *context_;
-  };
-
 protected:
-  // Keep track of all stored Contexts to mark them from garbage collection.
-  std::unordered_set<Context const *> contexts_;
-  std::vector<Grob_with_context> beams_;
-  std::vector<Grob_with_context> covered_grobs_;
-
-  void derived_mark () const override
-  {
-    Engraver::derived_mark ();
-    for (const auto &context : contexts_)
-      {
-        scm_gc_mark (context->self_scm ());
-      }
-  }
+  vector<Grob_info> beams_;
+  vector<Grob_info> covered_grobs_;
 
   void acknowledge_note_head (Grob_info);
   void acknowledge_stem (Grob_info);
@@ -69,21 +50,8 @@ protected:
 private:
   bool covered_grob_has_interface (Grob *covered_grob, Grob *beam);
 
-  Grob_with_context create_grob_with_context (const Grob_info &i)
-  {
-    Context const *context = i.context ();
-    // Remember this Context so it does not get collected.
-    contexts_.insert (context);
-    return { i.grob (), context };
-  }
-
 public:
   TRANSLATOR_DECLARATIONS (Beam_collision_engraver);
-
-  static bool grob_less (const Grob_with_context &a, const Grob_with_context &b)
-  {
-    return Grob::less (a.grob_, b.grob_);
-  }
 };
 
 Beam_collision_engraver::Beam_collision_engraver (Context *c)
@@ -110,13 +78,13 @@ Beam_collision_engraver::finalize ()
   if (!covered_grobs_.size ())
     return;
 
-  vector_sort (covered_grobs_, grob_less);
-  vector_sort (beams_, grob_less);
+  std::sort (covered_grobs_.begin (), covered_grobs_.end (), Grob_info::less);
+  std::sort (beams_.begin (), beams_.end (), Grob_info::less);
   vsize start = 0;
 
   for (vsize i = 0; i < beams_.size (); i++)
     {
-      Grob *beam_grob = beams_[i].grob_;
+      Grob *beam_grob = beams_[i].grob ();
 
       extract_grob_set (beam_grob, "normal-stems", stems);
       Interval_t<int> vertical_span;
@@ -126,21 +94,22 @@ Beam_collision_engraver::finalize ()
           if (vag >= 0)
             vertical_span.add_point (vag);
         }
-      Context const *beam_context = beams_[i].context_;
+      auto *const beam_context = beams_[i].origin_engraver ()->context ();
 
       Interval_t<int> beam_spanned_rank_ = beam_grob->spanned_rank_interval ();
       // Start considering grobs at the first grob whose end falls at or after the beam's beginning.
-      while (covered_grobs_[start].grob_->spanned_rank_interval ()[RIGHT] < beam_spanned_rank_[LEFT])
+      while (covered_grobs_[start].grob ()->spanned_rank_interval ()[RIGHT] < beam_spanned_rank_[LEFT])
         start++;
 
       // Stop when the grob's beginning comes after the beam's end.
       for (vsize j = start; j < covered_grobs_.size (); j++)
         {
-          Grob *covered_grob = covered_grobs_[j].grob_;
+          Grob *covered_grob = covered_grobs_[j].grob ();
           int vag = Grob::get_vertical_axis_group_index (covered_grob);
           if (!vertical_span.contains (vag))
             continue;
-          Context const *covered_grob_context = covered_grobs_[j].context_;
+          auto *const covered_grob_context
+            = covered_grobs_[j].origin_engraver ()->context ();
 
           Interval_t<int> covered_grob_spanned_rank = covered_grob->spanned_rank_interval ();
           if (covered_grob_spanned_rank[LEFT] > beam_spanned_rank_[RIGHT])
@@ -177,58 +146,57 @@ Beam_collision_engraver::finalize ()
 void
 Beam_collision_engraver::acknowledge_note_head (Grob_info i)
 {
-  covered_grobs_.push_back (create_grob_with_context (i));
+  covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_stem (Grob_info i)
 {
-  covered_grobs_.push_back (create_grob_with_context (i));
+  covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_accidental (Grob_info i)
 {
   if (i.grob ()->internal_has_interface (ly_symbol2scm ("inline-accidental-interface")))
-    covered_grobs_.push_back (create_grob_with_context (i));
+    covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_clef (Grob_info i)
 {
-  covered_grobs_.push_back (create_grob_with_context (i));
+  covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_key_signature (Grob_info i)
 {
-  covered_grobs_.push_back (create_grob_with_context (i));
+  covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_clef_modifier (Grob_info i)
 {
-  covered_grobs_.push_back (create_grob_with_context (i));
+  covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_time_signature (Grob_info i)
 {
-  covered_grobs_.push_back (create_grob_with_context (i));
+  covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_flag (Grob_info i)
 {
-  covered_grobs_.push_back (create_grob_with_context (i));
+  covered_grobs_.push_back (i);
 }
 
 void
 Beam_collision_engraver::acknowledge_beam (Grob_info i)
 {
-  Grob_with_context gc = create_grob_with_context (i);
-  beams_.push_back (gc);
-  covered_grobs_.push_back (gc);
+  beams_.push_back (i);
+  covered_grobs_.push_back (i);
 }
 
 #include "translator.icc"
