@@ -33,7 +33,6 @@
 #include "interval-minefield.hh"
 #include "least-squares.hh"
 #include "libc-extension.hh"
-#include "main.hh"
 #include "note-head.hh"
 #include "output-def.hh"
 #include "pointer-group-interface.hh"
@@ -49,6 +48,7 @@
 #include <memory>
 #include <queue>
 #include <set>
+#include <vector>
 
 using std::set;
 using std::string;
@@ -127,10 +127,8 @@ void Beam_configuration::add (Real demerit, const string &reason)
 {
   demerits += demerit;
 
-#if DEBUG_BEAM_SCORING
   if (demerit)
     score_card_ += to_string (" %s %.2f", reason.c_str (), demerit);
-#endif
 }
 
 unique_ptr<Beam_configuration>
@@ -167,16 +165,6 @@ Beam_scoring_problem::y_at (Real x, Beam_configuration const *p) const
   entirely
 */
 
-// This is a temporary hack to see how much we can gain by using a
-// priority queue on the beams to score.
-static int score_count = 0;
-LY_DEFINE (ly_beam_score_count, "ly:beam-score-count", 0, 0, 0,
-           (),
-           "count number of beam scores.")
-{
-  return to_scm (score_count);
-}
-
 void Beam_scoring_problem::add_collision (Real x, Interval y,
                                           Real score_factor)
 {
@@ -345,7 +333,7 @@ void Beam_scoring_problem::init_instance_variables (Grob *me, Drul_array<Real> y
         }
 
       segments_ = Beam::get_beam_segments (beams[i]);
-      vector_sort (segments_, beam_segment_less);
+      std::sort (segments_.begin (), segments_.end (), beam_segment_less);
       for (vsize j = 0; j < segments_.size (); j++)
         segments_[j].horizontal_ += (x_span_ - x_pos[LEFT]);
 
@@ -823,7 +811,8 @@ Beam_scoring_problem::shift_region_to_valid ()
         }
     }
 
-  vector_sort (forbidden_intervals, Interval::left_less);
+  std::sort (forbidden_intervals.begin (), forbidden_intervals.end (),
+             Interval::left_less);
   Real beam_left_y = unquanted_y_[LEFT];
   Interval feasible_beam_placements (beam_left_y, beam_left_y);
 
@@ -931,7 +920,6 @@ Beam_scoring_problem::generate_quants (vector<unique_ptr<Beam_configuration>> *s
 
 void Beam_scoring_problem::one_scorer (Beam_configuration *config) const
 {
-  score_count++;
   switch (config->next_scorer_todo)
     {
     case SLOPE_IDEAL:
@@ -1051,7 +1039,6 @@ Beam_scoring_problem::solve () const
 
   Drul_array<Real> final_positions = best->y;
 
-#if DEBUG_BEAM_SCORING
   if (debug)
     {
       // debug quanting
@@ -1065,7 +1052,6 @@ Beam_scoring_problem::solve () const
       string card = best->score_card_ + to_string (" c%d/%zu", completed, configs.size ());
       set_property (beam_, "annotation", ly_string2scm (card));
     }
-#endif
 
   configs.clear ();
   if (align_broken_intos_)
