@@ -48,7 +48,6 @@
 #include "item.hh"
 #include "lookup.hh"
 #include "ly-scm-list.hh"
-#include "main.hh"
 #include "misc.hh"
 #include "note-head.hh"
 #include "output-def.hh"
@@ -60,13 +59,12 @@
 #include "stem.hh"
 #include "warn.hh"
 
-#if DEBUG_BEAM_SCORING
 #include "text-interface.hh" // debug output.
 #include "font-interface.hh" // debug output.
-#endif
 
 #include <algorithm>
 #include <map>
+#include <vector>
 
 using std::map;
 using std::string;
@@ -454,7 +452,7 @@ Beam::calc_beam_segments (SCM smob)
        i != stem_segments.end (); i++)
     {
       vector<Beam_stem_segment> segs = (*i).second;
-      vector_sort (segs, std::less<Beam_stem_segment> ());
+      std::sort (segs.begin (), segs.end ());
 
       Beam_segment current;
 
@@ -745,7 +743,6 @@ Beam::print (SCM grob)
 
     }
 
-#if (DEBUG_BEAM_SCORING)
   SCM annotation = get_property (me, "annotation");
   if (scm_is_string (annotation))
     {
@@ -765,8 +762,8 @@ Beam::print (SCM grob)
 
       Direction stem_dir = stems.size () ? from_scm<Direction> (get_property (stems[0], "direction")) : UP;
 
-      Stencil score = *unsmob<Stencil> (Text_interface::interpret_markup
-                                        (me->layout ()->self_scm (), properties, annotation));
+      auto score = Text_interface::interpret_markup (me->layout (),
+                                                     properties, annotation);
 
       if (!score.is_empty ())
         {
@@ -774,7 +771,6 @@ Beam::print (SCM grob)
           the_beam.add_at_edge (Y_AXIS, stem_dir, score, 1.0);
         }
     }
-#endif
 
   the_beam.translate_axis (-me->relative_coordinate (commonx, X_AXIS), X_AXIS);
   return the_beam.smobbed_copy ();
