@@ -28,8 +28,7 @@ LY_DEFINE (ly_make_book, "ly:make-book",
            "Make a @code{\\book} of @var{paper} and @var{header}"
            " (which may be @code{#f} as well) containing @code{\\scores}.")
 {
-  Output_def *odef = unsmob<Output_def> (paper);
-  LY_ASSERT_SMOB (Output_def, paper, 1);
+  auto *const odef = LY_ASSERT_SMOB (Output_def, paper, 1);
 
   Book *book = new Book;
   book->paper_ = odef;
@@ -65,19 +64,11 @@ LY_DEFINE (ly_book_process, "ly:book-process",
            "  For example, it may be a string (for file based outputs)"
            " or a socket (for network based output).")
 {
-  Book *book = unsmob<Book> (book_smob);
-
-  LY_ASSERT_SMOB (Book, book_smob, 1);
-  LY_ASSERT_SMOB (Output_def, default_paper, 2);
-  LY_ASSERT_SMOB (Output_def, default_layout, 3);
-
-  Paper_book *pb = book->process (unsmob<Output_def> (default_paper),
-                                  unsmob<Output_def> (default_layout));
-
-  // Make sure the Scheme objects are not collected while processing.
-  scm_remember_upto_here_1 (book_smob);
-  scm_remember_upto_here_2 (default_paper, default_layout);
+  auto *const book = LY_ASSERT_SMOB (Book, book_smob, 1);
+  auto *const paper = LY_ASSERT_SMOB (Output_def, default_paper, 2);
+  auto *const layout = LY_ASSERT_SMOB (Output_def, default_layout, 3);
 
+  Paper_book *pb = book->process (paper, layout);
   if (pb)
     {
       pb->output (output);
@@ -96,14 +87,11 @@ LY_DEFINE (ly_book_process_to_systems, "ly:book-process-to-systems",
            "  For example, it may be a string (for file based outputs)"
            " or a socket (for network based output).")
 {
-  LY_ASSERT_SMOB (Book, book_smob, 1);
-  LY_ASSERT_SMOB (Output_def, default_paper, 2);
-  LY_ASSERT_SMOB (Output_def, default_layout, 3);
+  auto *const book = LY_ASSERT_SMOB (Book, book_smob, 1);
+  auto *const paper = LY_ASSERT_SMOB (Output_def, default_paper, 2);
+  auto *const layout = LY_ASSERT_SMOB (Output_def, default_layout, 3);
 
-  Book *book = unsmob<Book> (book_smob);
-
-  Paper_book *pb = book->process (unsmob<Output_def> (default_paper),
-                                  unsmob<Output_def> (default_layout));
+  Paper_book *pb = book->process (paper, layout);
   if (pb)
     {
       pb->classic_output (output);
@@ -117,8 +105,7 @@ LY_DEFINE (ly_book_add_score_x, "ly:book-add-score!",
            2, 0, 0, (SCM book_smob, SCM score),
            "Add @var{score} to @var{book-smob} score list.")
 {
-  LY_ASSERT_SMOB (Book, book_smob, 1);
-  Book *book = unsmob<Book> (book_smob);
+  auto *const book = LY_ASSERT_SMOB (Book, book_smob, 1);
   book->add_score (score);
   return SCM_UNSPECIFIED;
 }
@@ -127,8 +114,7 @@ LY_DEFINE (ly_book_add_bookpart_x, "ly:book-add-bookpart!",
            2, 0, 0, (SCM book_smob, SCM book_part),
            "Add @var{book-part} to @var{book-smob} book part list.")
 {
-  LY_ASSERT_SMOB (Book, book_smob, 1);
-  Book *book = unsmob<Book> (book_smob);
+  auto *const book = LY_ASSERT_SMOB (Book, book_smob, 1);
   book->add_bookpart (book_part);
   return SCM_UNSPECIFIED;
 }
@@ -137,8 +123,7 @@ LY_DEFINE (ly_book_book_parts, "ly:book-book-parts",
            1, 0, 0, (SCM book),
            "Return book parts in @var{book}.")
 {
-  LY_ASSERT_SMOB (Book, book, 1);
-  Book *b = unsmob<Book> (book);
+  auto *const b = LY_ASSERT_SMOB (Book, book, 1);
   return b->bookparts_;
 }
 
@@ -146,8 +131,7 @@ LY_DEFINE (ly_book_paper, "ly:book-paper",
            1, 0, 0, (SCM book),
            "Return paper in @var{book}.")
 {
-  LY_ASSERT_SMOB (Book, book, 1);
-  Book *b = unsmob<Book> (book);
+  auto *const b = LY_ASSERT_SMOB (Book, book, 1);
   return b->paper_ ? b->paper_->self_scm () : SCM_BOOL_F;
 }
 
@@ -155,8 +139,7 @@ LY_DEFINE (ly_book_header, "ly:book-header",
            1, 0, 0, (SCM book),
            "Return header in @var{book}.")
 {
-  LY_ASSERT_SMOB (Book, book, 1);
-  Book *b = unsmob<Book> (book);
+  auto *const b = LY_ASSERT_SMOB (Book, book, 1);
   return ly_is_module (b->header_) ? b->header_ : SCM_BOOL_F;
 }
 
@@ -164,11 +147,10 @@ LY_DEFINE (ly_book_set_header_x, "ly:book-set-header!",
            2, 0, 0, (SCM book, SCM module),
            "Set the book header.")
 {
-  LY_ASSERT_SMOB (Book, book, 1);
+  auto *const b = LY_ASSERT_SMOB (Book, book, 1);
   SCM_ASSERT_TYPE (ly_is_module (module), module, SCM_ARG2, __FUNCTION__,
                    "module");
 
-  Book *b = unsmob<Book> (book);
   b->header_ = (module);
   return SCM_UNSPECIFIED;
 }
@@ -177,8 +159,7 @@ LY_DEFINE (ly_book_scores, "ly:book-scores",
            1, 0, 0, (SCM book),
            "Return scores in @var{book}.")
 {
-  LY_ASSERT_SMOB (Book, book, 1);
-  Book *b = unsmob<Book> (book);
+  auto *const b = LY_ASSERT_SMOB (Book, book, 1);
   return b->scores_;
 }
 
