@@ -20,7 +20,6 @@
 #include "book.hh"
 
 #include "ly-smob-list.hh"
-#include "main.hh"
 #include "music.hh"
 #include "output-def.hh"
 #include "paper-book.hh"
@@ -263,7 +262,6 @@ Book::process_score (SCM s, Paper_book *output_paper_book, Output_def *layout)
   else
     assert (0);
 
-  scm_remember_upto_here_1 (s);
 }
 
 /* Concatenate all score or book part outputs into a Paper_book
