@@ -29,12 +29,12 @@
 
 class Break_align_engraver : public Engraver
 {
-  Item *align_;
-  SCM column_alist_;
-  Item *left_edge_;
+  Item *align_ = nullptr;
+  SCM column_alist_ = SCM_EOL;
+  Item *left_edge_ = nullptr;
 
   void add_to_group (SCM, Item *);
-  void create_alignment (Grob_info);
+  void create_alignment ();
 protected:
   void stop_translation_timestep ();
   void derived_mark () const override;
@@ -49,16 +49,13 @@ Break_align_engraver::stop_translation_timestep ()
 {
   column_alist_ = SCM_EOL;
 
-  align_ = 0;
-  left_edge_ = 0;
+  align_ = nullptr;
+  left_edge_ = nullptr;
 }
 
 Break_align_engraver::Break_align_engraver (Context *c)
   : Engraver (c)
 {
-  column_alist_ = SCM_EOL;
-  left_edge_ = 0;
-  align_ = 0;
 }
 
 void
@@ -70,20 +67,21 @@ Break_align_engraver::derived_mark () const
 void
 Break_align_engraver::acknowledge_break_alignable (Grob_info inf)
 {
-  /*
-    Special case for MetronomeMark: filter out items which will be aligned
-    on note heads rather than prefatory material
-  */
-  if (!Item::is_non_musical (dynamic_cast<Item *> (inf.grob ())))
-    return;
+  if (auto *item = dynamic_cast<Item *> (inf.grob ()))
+    {
+      if (item->get_x_parent ())
+        return;
 
-  if (!align_)
-    create_alignment (inf);
+      // Handling musical items is more involved because they might need to be
+      // aligned with notation (note heads, etc.).  We currently leave that to
+      // other engravers, but maybe it could be done here.
+      if (!Item::is_non_musical (item))
+        return;
 
-  Grob *g = inf.grob ();
+      create_alignment ();
 
-  if (!g->get_x_parent ())
-    g->set_x_parent (align_);
+      item->set_x_parent (align_);
+    }
 }
 
 void
@@ -104,43 +102,42 @@ Break_align_engraver::acknowledge_break_aligned (Grob_info inf)
       if (!scm_is_symbol (align_name))
         return;
 
-      if (!align_)
-        create_alignment (inf);
+      create_alignment ();
+
+      // Create a single LeftEdge that appears to come from the same engraver
+      // as the first Clef/BarLine/etc. that we see.  This is questionable and
+      // may contribute to problems discussed in issue #5385.  Practically,
+      // this is probably fine for single-staff scores, but even in a
+      // single-staff score, break-aligned grobs might originate in different
+      // contexts; for example, by default, Clef_engraver is in Staff and
+      // Breathing_sign_engraver is in Voice.
+      if (!left_edge_)
+        {
+          left_edge_ = inf.origin_engraver ()->make_item ("LeftEdge", SCM_EOL);
+          add_to_group (get_property (left_edge_, "break-align-symbol"),
+                        left_edge_);
+        }
 
       add_to_group (align_name, item);
     }
 }
 
 void
-Break_align_engraver::create_alignment (Grob_info inf)
+Break_align_engraver::create_alignment ()
 {
-  align_ = make_item ("BreakAlignment", SCM_EOL);
-
-  Engraver *random_source = dynamic_cast<Engraver *> (inf.origin_translator ());
-  if (!random_source)
-    {
-      programming_error ("BreakAlignment from non-Engraver");
-      random_source = this;
-    }
-
-  /*
-    Make left edge appear to come from same engraver as clef/bar-line etc.
-  */
-  left_edge_ = random_source->make_item ("LeftEdge", SCM_EOL);
-  add_to_group (get_property (left_edge_, "break-align-symbol"),
-                left_edge_);
+  if (!align_)
+    align_ = make_item ("BreakAlignment", SCM_EOL);
 }
 
 void
 Break_align_engraver::add_to_group (SCM align_name, Item *item)
 {
   SCM s = ly_assoc (align_name, column_alist_);
-  Item *group = 0;
+  Item *group = nullptr;
 
   if (scm_is_true (s))
     {
-      Grob *e = unsmob<Grob> (scm_cdr (s));
-      group = dynamic_cast<Item *> (e);
+      group = unsmob<Item> (scm_cdr (s));
     }
   else
     {
