@@ -20,7 +20,6 @@
 #include "constrained-breaking.hh"
 
 #include "international.hh"
-#include "main.hh"
 #include "output-def.hh"
 #include "page-layout-problem.hh"
 #include "paper-column.hh"
@@ -29,6 +28,9 @@
 #include "system.hh"
 #include "warn.hh"
 
+#include <algorithm>
+#include <vector>
+
 using std::vector;
 
 /*
@@ -200,7 +202,7 @@ Constrained_breaking::solve (vsize start, vsize end, vsize sys_count)
                   ret.push_back (space_line (prev_brk + start_brk, brk + start_brk));
                   brk = prev_brk;
                 }
-              reverse (ret);
+              std::reverse (ret.begin (), ret.end ());
               return ret;
             }
         }
@@ -291,7 +293,7 @@ Constrained_breaking::line_details (vsize start, vsize end, vsize sys_count)
                   ret.push_back (st.at (brk, cur_sys).details_);
                   brk = prev_brk;
                 }
-              reverse (ret);
+              std::reverse (ret.begin (), ret.end ());
               return ret;
             }
         }
@@ -579,7 +581,7 @@ Line_details::Line_details (Prob *pb, Output_def *paper)
   if (scm_is_pair (footnotes))
     for (SCM s = footnotes; scm_is_pair (s); s = scm_cdr (s))
       {
-        Stencil *sten = unsmob<Stencil> (scm_caddar (s));
+        auto *sten = unsmob<const Stencil> (scm_caddar (s));
         if (!sten)
           {
             programming_error ("expecting stencil, got empty pointer");
@@ -590,7 +592,7 @@ Line_details::Line_details (Prob *pb, Output_def *paper)
 
   last_column_ = 0;
   force_ = 0;
-  Stencil *st = unsmob<Stencil> (get_property (pb, "stencil"));
+  auto *st = unsmob<const Stencil> (get_property (pb, "stencil"));
   Interval stencil_extent = st->is_empty (Y_AXIS) ? Interval (0, 0)
                             : st->extent (Y_AXIS);
   shape_ = Line_shape (stencil_extent, stencil_extent); // pretend it goes all the way across
