@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2000--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 2000--2020 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,15 +29,28 @@
 #include "translator.hh"
 #include "warn.hh"
 
+using std::set;
+using std::string;
+using std::vector;
+
+static bool
+is_instantiable (Context_def *c)
+{
+  // This looks trivial, but it has semantic value.
+  //
+  // We can instantiate any context with a definition, but if there were any
+  // properties of the definition that could prevent instantiatation, we would
+  // also want to check them here.
+  return c;
+}
+
 Context_def::Context_def ()
 {
   context_aliases_ = SCM_EOL;
   translator_group_type_ = SCM_EOL;
-  accept_mods_ = SCM_EOL;
   translator_mods_ = SCM_EOL;
   property_ops_ = SCM_EOL;
   context_name_ = SCM_EOL;
-  default_child_ = SCM_EOL;
   description_ = SCM_EOL;
   input_location_ = SCM_EOL;
 
@@ -58,19 +71,16 @@ Context_def::Context_def (Context_def const &s)
 {
   context_aliases_ = SCM_EOL;
   translator_group_type_ = SCM_EOL;
-  accept_mods_ = SCM_EOL;
   translator_mods_ = SCM_EOL;
   property_ops_ = SCM_EOL;
   context_name_ = SCM_EOL;
   description_ = SCM_EOL;
-  default_child_ = SCM_EOL;
   input_location_ = SCM_EOL;
   smobify_self ();
 
   description_ = s.description_;
   input_location_ = s.origin ()->smobbed_copy ();
-  default_child_ = s.default_child_;
-  accept_mods_ = s.accept_mods_;
+  acceptance_.assign_copy (s.acceptance_);
   property_ops_ = s.property_ops_;
   translator_mods_ = s.translator_mods_;
   context_aliases_ = s.context_aliases_;
@@ -103,11 +113,10 @@ Context_def::mark_smob () const
 
   scm_gc_mark (description_);
   scm_gc_mark (context_aliases_);
-  scm_gc_mark (accept_mods_);
+  acceptance_.gc_mark ();
   scm_gc_mark (translator_mods_);
   scm_gc_mark (property_ops_);
   scm_gc_mark (translator_group_type_);
-  scm_gc_mark (default_child_);
   scm_gc_mark (input_location_);
 
   return context_name_;
@@ -131,15 +140,16 @@ Context_def::add_context_mod (SCM mod)
     sym = scm_string_to_symbol (sym);
 
   if (scm_is_eq (tag, ly_symbol2scm ("default-child")))
-    default_child_ = sym;
+    acceptance_.accept_default (sym);
   else if (scm_is_eq (tag, ly_symbol2scm ("consists"))
            || scm_is_eq (tag, ly_symbol2scm ("remove")))
     {
       translator_mods_ = scm_cons (scm_list_2 (tag, sym), translator_mods_);
     }
-  else if (scm_is_eq (tag, ly_symbol2scm ("accepts"))
-           || scm_is_eq (tag, ly_symbol2scm ("denies")))
-    accept_mods_ = scm_cons (scm_list_2 (tag, sym), accept_mods_);
+  else if (scm_is_eq (tag, ly_symbol2scm ("accepts")))
+    acceptance_.accept (sym);
+  else if (scm_is_eq (tag, ly_symbol2scm ("denies")))
+    acceptance_.deny (sym);
   else if (scm_is_eq (tag, ly_symbol2scm ("pop"))
            || scm_is_eq (tag, ly_symbol2scm ("push"))
            || scm_is_eq (tag, ly_symbol2scm ("assign"))
@@ -156,48 +166,6 @@ Context_def::add_context_mod (SCM mod)
     programming_error ("unknown context mod tag");
 }
 
-SCM
-Context_def::get_accepted (SCM user_mod) const
-{
-  SCM mods = scm_reverse_x (scm_list_copy (accept_mods_), user_mod);
-  SCM acc = SCM_EOL;
-  for (SCM s = mods; scm_is_pair (s); s = scm_cdr (s))
-    {
-      SCM tag = scm_caar (s);
-      SCM sym = scm_cadar (s);
-      if (scm_is_eq (tag, ly_symbol2scm ("accepts")))
-        acc = scm_cons (sym, acc);
-      else if (scm_is_eq (tag, ly_symbol2scm ("denies")))
-        acc = scm_delete_x (sym, acc);
-    }
-
-  SCM def = get_default_child (user_mod);
-  if (scm_is_symbol (def))
-    {
-      acc = scm_delete_x (def, acc);
-      acc = scm_cons (def, acc);
-    }
-
-  return acc;
-}
-
-SCM
-Context_def::get_default_child (SCM user_mod) const
-{
-  SCM name = default_child_;
-  for (SCM s = user_mod; scm_is_pair (s); s = scm_cdr (s))
-    {
-      SCM entry = scm_car (s);
-      if (scm_is_eq (scm_car (entry), ly_symbol2scm ("default-child")))
-        {
-          name = scm_cadr (entry);
-          break;
-        }
-    }
-
-  return name;
-}
-
 /*
   Given a name of a context that we want to create, finds a list of context
   definitions such that:
@@ -207,44 +175,59 @@ Context_def::get_default_child (SCM user_mod) const
      of the context defined by the preceding element in the list
    - the last element in the list defines a context with the given name
 
-  The ADDITIONAL_ACCEPTS parameter is a list of additional contexts that this
-  specific context def (but not any of the child context defs) should accept.
+  The ACCEPTED parameter is the list of contexts that the caller accepts.  (The
+  caller is a Context instantiated from this Context_def, but its acceptance
+  list may have been modified from the defined default.)
 */
 vector<Context_def *>
 Context_def::path_to_acceptable_context (SCM type_sym,
                                          Output_def *odef,
-                                         SCM additional_accepts) const
+                                         SCM accepted) const
 {
   set<const Context_def *> seen;
-  return internal_path_to_acceptable_context (type_sym, odef, additional_accepts, &seen);
+  Context_def *t = unsmob<Context_def> (find_context_def (odef, type_sym));
+  return internal_path_to_acceptable_context (type_sym, is_instantiable (t),
+                                              odef, accepted, &seen);
 }
 
 /*
 The SEEN parameter is a set which keeps track of visited contexts, allowing
 contexts of the same type to be nested.
+
+When the leaf is instantiable (the usual), we ignore aliases and thereby use
+the requested context or nothing.  Example: If the caller requests a Staff, we
+do not substitute a RhythmicStaff.
+
+When the leaf is not instantiable, since there would otherwise be nothing worth
+doing, we allow substituting an instantiable context that aliases the requested
+context.  Example: The caller requests a Timing and the current context would
+accept a Score, for which Timing is an alias, so substitute a Score.
 */
 vector<Context_def *>
 Context_def::internal_path_to_acceptable_context (SCM type_sym,
+                                                  bool instantiable,
                                                   Output_def *odef,
-                                                  SCM additional_accepts,
+                                                  SCM accepted,
                                                   set<const Context_def *> *seen) const
 {
   assert (scm_is_symbol (type_sym));
 
-  SCM accepted = get_accepted (additional_accepts);
-
   vector<Context_def *> accepteds;
   for (SCM s = accepted; scm_is_pair (s); s = scm_cdr (s))
-    if (Context_def *t = unsmob<Context_def> (find_context_def (odef,
-                                                                scm_car (s))))
-      accepteds.push_back (t);
+    {
+      Context_def *t = unsmob<Context_def> (find_context_def (odef,
+                                                              scm_car (s)));
+      if (is_instantiable (t))
+        accepteds.push_back (t);
+    }
 
   vector<Context_def *> best_result;
   for (vsize i = 0; i < accepteds.size (); i++)
     {
-      /* do not check aliases, because \context Staff should not
-         create RhythmicStaff. */
-      if (ly_is_equal (accepteds[i]->get_context_name (), type_sym))
+      bool valid = instantiable
+                   ? ly_is_equal (accepteds[i]->get_context_name (), type_sym)
+                   : accepteds[i]->is_alias (type_sym);
+      if (valid)
         {
           best_result.push_back (accepteds[i]);
           return best_result;
@@ -253,14 +236,16 @@ Context_def::internal_path_to_acceptable_context (SCM type_sym,
 
   seen->insert (this);
   vsize best_depth = INT_MAX;
-  for (vsize i = 0; i < accepteds.size (); i++)
+  for (vsize i = 0; (best_depth > 1) && (i < accepteds.size ()); i++)
     {
       Context_def *g = accepteds[i];
 
       if (!seen->count (g))
         {
+          SCM acc = g->acceptance_.get_list ();
           vector<Context_def *> result
-            = g->internal_path_to_acceptable_context (type_sym, odef, SCM_EOL, seen);
+            = g->internal_path_to_acceptable_context (type_sym, instantiable,
+                                                      odef, acc, seen);
           if (result.size () && result.size () < best_depth)
             {
               best_depth = result.size ();
@@ -274,6 +259,44 @@ Context_def::internal_path_to_acceptable_context (SCM type_sym,
   return best_result;
 }
 
+vector<Context_def *>
+Context_def::path_to_bottom_context (Output_def *odef,
+                                     SCM first_child_type_sym)
+{
+  vector<Context_def *> path;
+  if (!internal_path_to_bottom_context (odef, &path, first_child_type_sym))
+    path.clear ();
+  return path;
+}
+
+bool
+Context_def::internal_path_to_bottom_context (Output_def *odef,
+                                              vector<Context_def *> *path,
+                                              SCM next_type_sym)
+{
+  if (!scm_is_symbol (next_type_sym))
+    return true; // the caller is the bottom
+
+  Context_def *t = unsmob<Context_def> (find_context_def (odef, next_type_sym));
+  if (!is_instantiable (t))
+    {
+      warning (_f ("cannot create default child context: %s",
+                   Context::diagnostic_id (next_type_sym, "").c_str ()));
+      return false;
+    }
+
+  if (std::find (path->begin (), path->end (), t) != path->end ())
+    {
+      warning (_f ("default child context begins a cycle: %s",
+                   Context::diagnostic_id (next_type_sym, "").c_str ()));
+      return false;
+    }
+
+  path->push_back (t);
+  return internal_path_to_bottom_context (odef, path,
+                                          t->acceptance_.get_default ());
+}
+
 SCM
 Context_def::get_translator_names (SCM user_mod) const
 {
@@ -306,8 +329,21 @@ Context_def::instantiate (SCM ops)
   context->definition_ = self_scm ();
   context->definition_mods_ = ops;
   context->aliases_ = context_aliases_;
-  context->accepts_list_ = get_accepted (ops);
-  context->default_child_ = get_default_child (ops);
+  context->acceptance_.assign_copy (acceptance_);
+  // TODO: Set this with "\adopts ##t" in the ly code.
+  context->adopts_ = scm_is_eq (context_name_, ly_symbol2scm ("Score"));
+
+  Acceptance_set &acc = context->acceptance_;
+  for (SCM s = ops; scm_is_pair (s); s = scm_cdr (s))
+    {
+      SCM tag = scm_caar (s);
+      if (scm_is_eq (tag, ly_symbol2scm ("accepts")))
+        acc.accept (scm_string_to_symbol (scm_cadar (s)));
+      else if (scm_is_eq (tag, ly_symbol2scm ("denies")))
+        acc.deny (scm_string_to_symbol (scm_cadar (s)));
+      else if (scm_is_eq (tag, ly_symbol2scm ("default-child")))
+        acc.accept_default (scm_string_to_symbol (scm_cadar (s)));
+    }
 
   return context;
 }
@@ -334,12 +370,13 @@ Context_def::to_alist () const
                             get_translator_names (SCM_EOL)), ell);
   ell = scm_cons (scm_cons (ly_symbol2scm ("description"), description_), ell);
   ell = scm_cons (scm_cons (ly_symbol2scm ("aliases"), context_aliases_), ell);
-  ell = scm_cons (scm_cons (ly_symbol2scm ("accepts"), get_accepted (SCM_EOL)),
-                  ell);
-  if (scm_is_symbol (default_child_))
-    ell = scm_acons (ly_symbol2scm ("default-child"), default_child_, ell);
-  ell = scm_cons (scm_cons (ly_symbol2scm ("accepts"), get_accepted (SCM_EOL)),
+  ell = scm_cons (scm_cons (ly_symbol2scm ("accepts"), acceptance_.get_list ()),
                   ell);
+  if (acceptance_.has_default ())
+    {
+      ell = scm_acons (ly_symbol2scm ("default-child"),
+                       acceptance_.get_default (), ell);
+    }
   ell = scm_cons (scm_cons (ly_symbol2scm ("property-ops"), property_ops_),
                   ell);
   ell = scm_cons (scm_cons (ly_symbol2scm ("context-name"), context_name_),
@@ -355,7 +392,7 @@ SCM
 Context_def::lookup (SCM sym) const
 {
   if (scm_is_eq (ly_symbol2scm ("default-child"), sym))
-    return default_child_;
+    return acceptance_.get_default ();
   else if (scm_is_eq (ly_symbol2scm ("consists"), sym))
     return get_translator_names (SCM_EOL);
   else if (scm_is_eq (ly_symbol2scm ("description"), sym))
@@ -363,7 +400,7 @@ Context_def::lookup (SCM sym) const
   else if (scm_is_eq (ly_symbol2scm ("aliases"), sym))
     return context_aliases_;
   else if (scm_is_eq (ly_symbol2scm ("accepts"), sym))
-    return get_accepted (SCM_EOL);
+    return acceptance_.get_list ();
   else if (scm_is_eq (ly_symbol2scm ("property-ops"), sym))
     return property_ops_;
   else if (scm_is_eq (ly_symbol2scm ("context-name"), sym))
@@ -377,7 +414,7 @@ bool
 Context_def::is_alias (SCM sym) const
 {
   if (scm_is_eq (sym, ly_symbol2scm ("Bottom")))
-    return !scm_is_symbol (get_default_child (SCM_EOL));
+    return !acceptance_.has_default ();
 
   if (scm_is_eq (sym, get_context_name ()))
     return true;
@@ -394,8 +431,7 @@ LY_DEFINE (ly_context_def_lookup, "ly:context-def-lookup",
            " @samp{description}, @samp{aliases}, @samp{accepts},"
            " @samp{property-ops}, @samp{context-name}, @samp{group-type}.")
 {
-  LY_ASSERT_SMOB (Context_def, def, 1);
-  Context_def *cd = unsmob<Context_def> (def);
+  auto *const cd = LY_ASSERT_SMOB (Context_def, def, 1);
   LY_ASSERT_TYPE (ly_is_symbol, sym, 2);
 
   SCM res = cd->lookup (sym);
@@ -416,12 +452,12 @@ LY_DEFINE (ly_context_def_modify, "ly:context-def-modify",
            "Return the result of applying the context-mod @var{mod} to"
            " the context definition @var{def}.  Does not change @var{def}.")
 {
-  LY_ASSERT_SMOB (Context_def, def, 1);
-  LY_ASSERT_SMOB (Context_mod, mod, 2);
+  auto *const orig_cd = LY_ASSERT_SMOB (Context_def, def, 1);
+  auto *const cm = LY_ASSERT_SMOB (Context_mod, mod, 2);
 
-  Context_def *cd = unsmob<Context_def> (def)->clone ();
+  auto *cd = orig_cd->clone ();
 
-  for (SCM s = unsmob<Context_mod> (mod)->get_mods ();
+  for (SCM s = cm->get_mods ();
        scm_is_pair (s);
        s = scm_cdr (s))
     cd->add_context_mod (scm_car (s));
