@@ -30,11 +30,8 @@ LY_DEFINE (ly_connect_dispatchers, "ly:connect-dispatchers",
            2, 0, 0, (SCM to, SCM from),
            "Make the dispatcher @var{to} listen to events from @var{from}.")
 {
-  Dispatcher *t = unsmob<Dispatcher> (to);
-  Dispatcher *f = unsmob<Dispatcher> (from);
-
-  LY_ASSERT_SMOB (Dispatcher, to, 1);
-  LY_ASSERT_SMOB (Dispatcher, from, 2);
+  auto *const t = LY_ASSERT_SMOB (Dispatcher, to, 1);
+  auto *const f = LY_ASSERT_SMOB (Dispatcher, from, 2);
 
   t->register_as_listener (f);
 
@@ -45,11 +42,8 @@ LY_DEFINE (ly_disconnect_dispatchers, "ly:disconnect-dispatchers",
            2, 0, 0, (SCM to, SCM from),
            "Stop the dispatcher @var{to} listening to events from @var{from}.")
 {
-  Dispatcher *t = unsmob<Dispatcher> (to);
-  Dispatcher *f = unsmob<Dispatcher> (from);
-
-  LY_ASSERT_SMOB (Dispatcher, to, 1);
-  LY_ASSERT_SMOB (Dispatcher, from, 2);
+  auto *const t = LY_ASSERT_SMOB (Dispatcher, to, 1);
+  auto *const f = LY_ASSERT_SMOB (Dispatcher, from, 2);
 
   t->unregister_as_listener (f);
 
@@ -62,10 +56,8 @@ LY_DEFINE (ly_add_listener, "ly:add-listener",
            " to the dispatcher @var{disp}.  Whenever @var{disp} hears"
            " an event of class @var{cl}, it calls @var{callback} with it.")
 {
-  Dispatcher *d = unsmob<Dispatcher> (disp);
-
   LY_ASSERT_TYPE (ly_is_procedure, callback, 1);
-  LY_ASSERT_SMOB (Dispatcher, disp, 2);
+  auto *const d = LY_ASSERT_SMOB (Dispatcher, disp, 2);
 
   for (int arg = SCM_ARG3; scm_is_pair (cl); cl = scm_cdr (cl), arg++)
     {
@@ -82,9 +74,9 @@ LY_DEFINE (ly_listened_event_types, "ly:listened-event-types",
            "Return a list of all event types that @var{disp} listens"
            " to.")
 {
-  LY_ASSERT_SMOB (Dispatcher, disp, 1);
+  auto *const d = LY_ASSERT_SMOB (Dispatcher, disp, 1);
 
-  SCM result = unsmob<Dispatcher> (disp)->listened_types ();
+  SCM result = d->listened_types ();
 
   scm_remember_upto_here_1 (disp);
 
@@ -96,10 +88,10 @@ LY_DEFINE (ly_listened_event_class_p, "ly:listened-event-class?",
            "Does @var{disp} listen to any event type in the list"
            " @var{cl}?")
 {
-  LY_ASSERT_SMOB (Dispatcher, disp, 1);
+  auto *const d = LY_ASSERT_SMOB (Dispatcher, disp, 1);
   LY_ASSERT_TYPE (scm_is_pair, cl, 2);
 
-  bool result = unsmob<Dispatcher> (disp)->is_listened_class (cl);
+  bool result = d->is_listened_class (cl);
 
   scm_remember_upto_here_1 (disp);
 
@@ -110,12 +102,9 @@ LY_DEFINE (ly_broadcast, "ly:broadcast",
            2, 0, 0, (SCM disp, SCM ev),
            "Send the stream event @var{ev} to the dispatcher @var{disp}.")
 {
-  Dispatcher *d = unsmob<Dispatcher> (disp);
-  Stream_event *e = unsmob<Stream_event> (ev);
+  auto *const d = LY_ASSERT_SMOB (Dispatcher, disp, 1);
+  auto *const e = LY_ASSERT_SMOB (Stream_event, ev, 2);
 
-  LY_ASSERT_SMOB (Dispatcher, disp, 1);
-
-  LY_ASSERT_SMOB (Stream_event, ev, 2);
   d->broadcast (e);
   return SCM_UNSPECIFIED;
 }
