@@ -98,7 +98,7 @@ Engraver_group::announce_grob (Grob_info info, Direction dir,
   announce_infos_.push_back (Announce_grob_info (info, dir));
 
   Context *dad_con = reroute_context ? reroute_context
-                     : context_->get_parent_context ();
+                     : context_->get_parent ();
 
   Engraver_group *dad_eng
     = dad_con
@@ -117,6 +117,7 @@ Engraver_group::acknowledge_grobs ()
 
   SCM name_sym = ly_symbol2scm ("name");
 
+  // N.B. announce_infos_ can grow during this loop.
   for (vsize j = 0; j < announce_infos_.size (); j++)
     {
       Announce_grob_info info = announce_infos_[j];
