@@ -25,9 +25,10 @@
 #include "item.hh"
 #include "paper-column.hh"
 
-using std::vector;
+#include <algorithm>
+#include <vector>
 
-#define EPS 1e-5
+using std::vector;
 
 struct Fingering_and_offset
 {
@@ -85,7 +86,7 @@ Fingering_column::do_y_positioning (Grob *me)
   Real padding = from_scm<double> (get_property (me, "padding"), 0.2);
 
   // order the fingerings from bottom to top
-  vector_sort (fingerings, pure_position_less);
+  std::sort (fingerings.begin (), fingerings.end (), pure_position_less);
 
   vector<Real> shift (fingerings.size ());
 
@@ -134,12 +135,13 @@ Fingering_column::do_x_positioning (Grob *me)
   for (vsize i = 0; i < fingerings.size (); i++)
     fos.push_back (Fingering_and_offset (fingerings[i], fingerings[i]->relative_coordinate (common_x, X_AXIS)));
 
-  vector_sort (fos, fingering_and_offset_less);
+  std::sort (fos.begin (), fos.end (), fingering_and_offset_less);
   Direction dir = get_grob_direction (fingerings[0]);
   if (dir == RIGHT)
-    reverse (fos);
+    std::reverse (fos.begin (), fos.end ());
 
   Real prev = infinity_f * dir;
+  Real EPS = 1.0e-5;
   for (vsize i = 0; i < fos.size (); i++)
     {
       if ((fabs (fos[i].offset_ - prev) < snap)
