@@ -17,9 +17,6 @@
   along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <cstring>
-#include <map>
-
 #include "std-string.hh"
 #include "lily-guile.hh"
 #include "warn.hh"
@@ -35,15 +32,19 @@
 #include "protected-scm.hh"
 #include "spanner.hh"
 #include "stream-event.hh"
+#include "transform.hh"
 #include "unpure-pure-container.hh"
 
+#include <cstring>
+#include <map>
+
 using std::map;
 using std::string;
 
 static Protected_scm doc_hash_table;
 
 void
-ly_check_name (const string &cxx, const string &scm_name)
+ly_check_name (const char *cxx, const char *scm_name)
 {
   string mangle = mangle_cxx_identifier (cxx);
   if (mangle != scm_name)
@@ -54,11 +55,12 @@ ly_check_name (const string &cxx, const string &scm_name)
 
 void
 ly_add_function_documentation (SCM func,
-                               const string &fname,
-                               const string &varlist,
-                               const string &doc)
+                               const char *fname,
+                               const char *varlist,
+                               const char *doc)
 {
-  if (doc == "")
+  // doc is a null-terminated character string, so check if it is empty.
+  if (*doc == 0)
     return;
 
   if (!doc_hash_table.is_bound ())
@@ -70,7 +72,7 @@ ly_add_function_documentation (SCM func,
   scm_set_procedure_property_x (func, ly_symbol2scm ("documentation"),
                                 ly_string2scm (s));
   SCM entry = scm_cons (ly_string2scm (varlist), ly_string2scm (doc));
-  scm_hashq_set_x (doc_hash_table, ly_symbol2scm (fname.c_str ()), entry);
+  scm_hashq_set_x (doc_hash_table, ly_symbol2scm (fname), entry);
 }
 
 LY_DEFINE (ly_get_all_function_documentation, "ly:get-all-function-documentation",
@@ -84,9 +86,9 @@ map<void *, string> type_names;
 
 void
 ly_add_type_predicate (void *ptr,
-                       const string &name)
+                       const char *name)
 {
-  type_names[ptr] = name;
+  type_names[ptr] = std::string (name);
 }
 
 string
@@ -104,13 +106,15 @@ predicate_to_typename (void *ptr)
 void
 init_func_doc ()
 {
-  ly_add_type_predicate ((void *) &is_direction, "direction");
+  ly_add_type_predicate ((void *) &is_scm<Direction>, "direction");
+  ly_add_type_predicate ((void *) &scm_is_real, "real number");
+  ly_add_type_predicate ((void *) &is_scm<Offset>, "pair of reals");
   ly_add_type_predicate ((void *) &ly_is_port, "port");
   ly_add_type_predicate ((void *) &ly_cheap_is_list, "list");
   ly_add_type_predicate ((void *) &unsmob<Global_context>, "Global_context");
   ly_add_type_predicate ((void *) &unsmob<Paper_score>, "Paper_score");
   ly_add_type_predicate ((void *) &unsmob<Performance>, "Performance");
-  ly_add_type_predicate ((void *) &is_axis, "axis");
+  ly_add_type_predicate ((void *) &is_scm<Axis>, "axis");
   ly_add_type_predicate ((void *) &is_number_pair, "number pair");
   ly_add_type_predicate ((void *) &ly_is_list, "list");
   ly_add_type_predicate ((void *) &ly_is_procedure, "procedure");
@@ -121,6 +125,7 @@ init_func_doc ()
   ly_add_type_predicate ((void *) &scm_is_pair, "pair");
   ly_add_type_predicate ((void *) &scm_is_rational, "rational");
   ly_add_type_predicate ((void *) &scm_is_string, "string");
+  ly_add_type_predicate ((void *) &unsmob<Transform>, "coordinate transform");
   ly_add_type_predicate ((void *) &scm_is_vector, "vector");
   ly_add_type_predicate ((void *) &unsmob<Item>, "Item");
   ly_add_type_predicate ((void *) &unsmob<Music>, "Music");
