@@ -29,6 +29,7 @@
 #include "misc.hh"
 #include "program-option.hh"
 #include "relocate.hh"
+#include "std-vector.hh"
 #include "string-convert.hh"
 #include "version.hh"
 #include "warn.hh"
@@ -49,24 +50,6 @@ using std::vector;
 /* Declaration of log function(s) */
 SCM ly_progress (SCM, SCM);
 
-LY_DEFINE (ly_start_environment, "ly:start-environment",
-           0, 0, 0, (),
-           "Return the environment (a list of strings) that was in"
-           " effect at program start.")
-{
-  SCM l = SCM_EOL;
-  SCM *tail = &l;
-
-  for (vsize i = 0; i < start_environment_global.size (); i++)
-    {
-      *tail = scm_cons (ly_string2scm (start_environment_global[i]),
-                        SCM_EOL);
-      tail = SCM_CDRLOC (*tail);
-    }
-
-  return l;
-}
-
 LY_DEFINE (ly_find_file, "ly:find-file",
            1, 0, 0, (SCM name),
            "Return the absolute file name of @var{name},"
@@ -137,6 +120,25 @@ LY_DEFINE (ly_gulp_file, "ly:gulp-file",
   return scm_from_latin1_stringn (contents.c_str (), contents.length ());
 }
 
+LY_DEFINE (ly_gulp_file_utf8, "ly:gulp-file-utf8",
+           1, 1, 0, (SCM name, SCM size),
+           "Read @var{size} characters from the file @var{name},"
+           " and return its contents in a string decoded from UTF-8."
+           "  If @var{size} is undefined, the entire file is read."
+           "  The file is looked up using the search path.")
+{
+  LY_ASSERT_TYPE (scm_is_string, name, 1);
+  int sz = INT_MAX;
+  if (!SCM_UNBNDP (size))
+    {
+      LY_ASSERT_TYPE (scm_is_number, size, 2);
+      sz = scm_to_int (size);
+    }
+
+  string contents = gulp_file_to_string (ly_scm2string (name), true, sz);
+  return scm_from_utf8_stringn (contents.c_str (), contents.length ());
+}
+
 LY_DEFINE (ly_dir_p, "ly:dir?",
            1, 0, 0, (SCM s),
            "Is @var{s} a direction?  Valid directions are @w{@code{-1}},"
@@ -417,19 +419,28 @@ LY_DEFINE (ly_chain_assoc_get, "ly:chain-assoc-get",
 }
 
 LY_DEFINE (ly_stderr_redirect, "ly:stderr-redirect",
-           1, 1, 0, (SCM file_name, SCM mode),
-           "Redirect stderr to @var{file-name}, opened with @var{mode}.")
+           1, 1, 0, (SCM fd_or_file_name, SCM mode),
+           "Redirect stderr to @var{fd} if the first parameter is an integer,"
+           " or to @var{file-name}, opened with @var{mode}.")
 {
-  LY_ASSERT_TYPE (scm_is_string, file_name, 1);
+  fflush (stderr);
+
+  if (scm_is_integer (fd_or_file_name)) {
+    // If passed a file descriptor, just replace the error stream (fd 2) by
+    // calling dup2.
+    int fd = scm_to_int (fd_or_file_name);
+    if (dup2 (fd, 2) == -1)
+      error (_ ("failed redirecting stderr"));
+    return SCM_UNSPECIFIED;
+  }
+
+  LY_ASSERT_TYPE (scm_is_string, fd_or_file_name, 1);
 
   string m = "w";
-  string f = ly_scm2string (file_name);
+  string f = ly_scm2string (fd_or_file_name);
   FILE *stderrfile;
   if (scm_is_string (mode))
     m = ly_scm2string (mode);
-  /* dup2 and (fileno (current-error-port)) do not work with mingw'c
-     gcc -mwindows.  */
-  fflush (stderr);
   stderrfile = freopen (f.c_str (), m.c_str (), stderr);
   if (!stderrfile)
     error (_f ("failed redirecting stderr to `%s'", f.c_str ()));
@@ -469,37 +480,6 @@ LY_DEFINE (ly_camel_case_2_lisp_identifier, "ly:camel-case->lisp-identifier",
   return ly_symbol2scm (result.c_str ());
 }
 
-LY_DEFINE (ly_expand_environment, "ly:expand-environment",
-           1, 0, 0, (SCM str),
-           "Expand @code{$VAR} and @code{$@{VAR@}} in @var{str}.")
-{
-  LY_ASSERT_TYPE (scm_is_string, str, 1);
-
-  return ly_string2scm (expand_environment_variables (ly_scm2string (str)));
-}
-
-LY_DEFINE (ly_truncate_list_x, "ly:truncate-list!",
-           2, 0, 0, (SCM lst, SCM i),
-           "Take at most the first @var{i} of list @var{lst}.")
-{
-  LY_ASSERT_TYPE (scm_is_integer, i, 1);
-
-  int k = scm_to_int (i);
-  if (k == 0)
-    lst = SCM_EOL;
-  else
-    {
-      SCM s = lst;
-      k--;
-      for (; scm_is_pair (s) && k--; s = scm_cdr (s))
-        ;
-
-      if (scm_is_pair (s))
-        scm_set_cdr_x (s, SCM_EOL);
-    }
-  return lst;
-}
-
 string
 format_single_argument (SCM arg, int precision, bool escape = false)
 {
