@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1999--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1999--2020 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,7 +19,9 @@
 
 #include "global-ctor.hh"
 
-#include "std-vector.hh"
+#include <vector>
+
+using std::vector;
 
 static vector<Global_ctor> *ctor_global_statics_;
 
@@ -34,6 +36,6 @@ add_constructor (Global_ctor c)
 void
 call_constructors ()
 {
-  for (vsize i = 0; i < ctor_global_statics_->size (); i++)
-    (ctor_global_statics_->at (i)) ();
+  for (auto &ctor : *ctor_global_statics_)
+    ctor ();
 }
