@@ -18,7 +18,6 @@
 */
 
 #include "file-path.hh"
-#include "main.hh"
 
 using std::string;
 using std::vector;
@@ -56,5 +55,3 @@ File_path global_path;
    LILYPOND_DATADIR = /usr/share/lilypond
 */
 string lilypond_datadir;
-
-vector<string> start_environment_global;
