@@ -96,12 +96,12 @@ void fix_prefix_set (int *current_set, int min_set, int max_set, Grob *primitive
   fix_prefix ("pes_or_flexa", LINEA, current_set, min_set, max_set, primitive);
 }
 
-void check_and_fix_all_prefixes (vector<Grob_info> const &primitives)
+void check_and_fix_all_prefixes (vector<Grob_info_t<Item>> const &primitives)
 {
   /* Check for invalid head modifier combinations */
-  for (vsize i = 0; i < primitives.size (); i++)
+  for (const auto &info : primitives)
     {
-      Grob *primitive = primitives[i].grob ();
+      auto *const primitive = info.grob ();
 
       /* compute head prefix set by inspecting primitive grob properties */
       int prefix_set
@@ -207,7 +207,7 @@ void check_and_fix_all_prefixes (vector<Grob_info> const &primitives)
  * Marks those heads that participate in a pes or flexa.
  */
 void
-provide_context_info (vector<Grob_info> const &primitives)
+provide_context_info (vector<Grob_info_t<Item>> const &primitives)
 {
   Grob *prev_primitive = 0;
   int prev_prefix_set = 0;
@@ -255,8 +255,9 @@ provide_context_info (vector<Grob_info> const &primitives)
 }
 
 void
-Gregorian_ligature_engraver::build_ligature (Spanner *ligature,
-                                             vector<Grob_info> const &primitives)
+Gregorian_ligature_engraver::build_ligature
+(Spanner *ligature,
+ vector<Grob_info_t<Item>> const &primitives)
 {
   // apply style-independent checking and transformation
   check_and_fix_all_prefixes (primitives);
