@@ -26,6 +26,9 @@
 #include "spanner.hh"
 #include "warn.hh"
 
+#include <algorithm>
+#include <vector>
+
 using std::vector;
 
 MAKE_SCHEME_CALLBACK (Hara_kiri_group_spanner, y_extent, 1);
@@ -123,11 +126,12 @@ Hara_kiri_group_spanner::request_suicide_alone (Grob *me, vsize start, vsize end
           for (int j = iv[LEFT]; j <= iv[RIGHT]; j++)
             ranks.push_back (j);
         }
-      vector_sort (ranks, std::less<int> ());
-      uniq (ranks);
+      std::sort (ranks.begin (), ranks.end ());
+      auto last = std::unique (ranks.begin (), ranks.end ());
+      vsize vector_size = last - ranks.begin ();
 
-      SCM scm_vec = scm_c_make_vector (ranks.size (), SCM_EOL);
-      for (vsize i = 0; i < ranks.size (); i++)
+      SCM scm_vec = scm_c_make_vector (vector_size, SCM_EOL);
+      for (vsize i = 0; i < vector_size; i++)
         scm_c_vector_set_x (scm_vec, i, to_scm (ranks[i]));
       set_property (me, "important-column-ranks", scm_vec);
 
