@@ -27,9 +27,7 @@ LY_DEFINE (ly_input_warning, "ly:input-warning", 2, 0, 1, (SCM sip, SCM msg, SCM
            " to the location in @var{sip}.  @var{msg} is interpreted"
            " similar to @code{format}'s argument, using @var{rest}.")
 {
-  Input *ip = unsmob<Input> (sip);
-
-  LY_ASSERT_SMOB (Input, sip, 1);
+  auto *const ip = LY_ASSERT_SMOB (Input, sip, 1);
   LY_ASSERT_TYPE (scm_is_string, msg, 2);
 
   msg = scm_simple_format (SCM_BOOL_F, msg, rest);
@@ -45,9 +43,7 @@ LY_DEFINE (ly_input_message, "ly:input-message", 2, 0, 1, (SCM sip, SCM msg, SCM
            " to the location in @var{sip}.  @var{msg} is interpreted"
            " similar to @code{format}'s argument, using @var{rest}.")
 {
-  Input *ip = unsmob<Input> (sip);
-
-  LY_ASSERT_SMOB (Input, sip, 1);
+  auto *const ip = LY_ASSERT_SMOB (Input, sip, 1);
   LY_ASSERT_TYPE (scm_is_string, msg, 2);
 
   msg = scm_simple_format (SCM_BOOL_F, msg, rest);
@@ -64,8 +60,7 @@ LY_DEFINE (ly_input_file_line_char_column,
            "Return input location in @var{sip} as"
            " @code{(file-name line char column)}.")
 {
-  LY_ASSERT_SMOB (Input, sip, 1);
-  Input *ip = unsmob<Input> (sip);
+  auto *const ip = LY_ASSERT_SMOB (Input, sip, 1);
 
   ssize_t l, ch, col, offset = 0;
   ip->get_counts (&l, &ch, &col, &offset);
@@ -82,8 +77,7 @@ LY_DEFINE (ly_input_both_locations,
            " @code{(file-name first-line first-column last-line last-column)}.")
 {
 
-  LY_ASSERT_SMOB (Input, sip, 1);
-  Input *ip = unsmob<Input> (sip);
+  auto *const ip = LY_ASSERT_SMOB (Input, sip, 1);
 
   return scm_list_5 (ly_string2scm (ip->file_string ()),
                      scm_from_ssize_t (ip->line_number ()),
