@@ -25,7 +25,6 @@
 #include "pointer-group-interface.hh"
 #include "paper-column.hh"
 #include "interval-set.hh"
-#include "std-vector.hh"
 
 #include <map>
 
@@ -153,6 +152,7 @@ struct Head_data
   Interval accidental_extent_;
   Head_data ()
   {
+    position_ = 0;
     head_extent_.set_empty ();
     ledger_extent_.set_empty ();
     accidental_extent_.set_empty ();
