@@ -24,6 +24,8 @@ namespace Guile_user
 Scm_module module ("guile-user");
 
 Variable apply ("apply");
+Variable equal ("=");
+Variable less ("<");
 Variable plus ("+");
 Variable make_module ("make-module");
 #if GUILEV2
@@ -49,7 +51,6 @@ Scm_module module ("lily");
 
 Variable all_music_font_encodings ("all-music-font-encodings");
 Variable alterations_in_key ("alterations-in-key");
-Variable backend_testing ("backend-testing");
 Variable base_length ("base-length");
 Variable beam_exceptions ("beam-exceptions");
 Variable beat_structure ("beat-structure");
@@ -97,7 +98,6 @@ Variable f_parser ("%parser");
 Variable percussion_p ("percussion?");
 Variable pitchnames ("pitchnames");
 Variable pure_chain_offset_callback ("pure-chain-offset-callback");
-Variable remove_stencil_warnings ("remove-stencil-warnings");
 Variable scale_p ("scale?");
 Variable scale_to_factor ("scale->factor");
 Variable scale_layout ("scale-layout");
@@ -107,12 +107,20 @@ Variable score_markup ("score-markup");
 Variable scorify_music ("scorify-music");
 Variable stencil_whiteout ("stencil-whiteout");
 Variable symbol_list_p ("symbol-list?");
-Variable tremolo_get_music_list ("tremolo::get-music-list");
 Variable type_name ("type-name");
 Variable volta_bracket_calc_hook_visibility ("volta-bracket::calc-hook-visibility");
 Variable write_performances_midis ("write-performances-midis");
 }
 
+namespace Srfi_1
+{
+Scm_module module ("srfi srfi-1");
+
+Variable append_reverse ("append-reverse");
+Variable delete_duplicates ("delete-duplicates");
+Variable lset_union ("lset-union");
+}
+
 namespace Syntax
 {
 Scm_module module ("scm ly-syntax-constructors");
