@@ -20,7 +20,6 @@
 #include "lily-guile.hh"
 #include "ly-module.hh"
 #include "warn.hh"
-#include "main.hh"
 #include "protected-scm.hh"
 #include "lily-imports.hh"
 
@@ -78,6 +77,18 @@ ly_use_module (SCM mod, SCM used)
                                    Guile_user::module_public_interface (used));
 }
 
+bool
+is_module_internal_symbol (SCM key)
+{
+  // The public interface of a module is another module stored under
+  // the symbol %module-public-interface. Copying its binding about
+  // leads to sharing of public interfaces, with confusing
+  // consequences. For example, exporting 'sym from one module, will
+  // export it from other modules too (with potentially the same
+  // value!)
+  return key == ly_symbol2scm ("%module-public-interface");
+}
+
 #define FUNC_NAME __FUNCTION__
 
 SCM
@@ -86,7 +97,14 @@ ly_module_symbols (SCM mod)
   SCM_VALIDATE_MODULE (1, mod);
 
   SCM obarr = SCM_MODULE_OBARRAY (mod);
-  return ly_hash_table_keys (obarr);
+  SCM syms = ly_hash_table_keys (obarr);
+  SCM filtered = SCM_EOL;
+  for (SCM s = syms; scm_is_pair (s); s = scm_cdr (s))
+    {
+      if (!is_module_internal_symbol (scm_car (s)))
+        filtered = scm_cons (scm_car (s), filtered);
+    }
+  return filtered;
 }
 
 static SCM
