@@ -48,6 +48,7 @@
 #include "output-def.hh"
 #include "program-option.hh"
 #include "relocate.hh"
+#include "std-vector.hh"
 #include "string-convert.hh"
 #include "warn.hh"
 #include "lily-imports.hh"
@@ -151,8 +152,15 @@ static Long_option_init options_static[]
   },
   {
     _i ("SYM[=VAL]"), "define-default", 'd',
-    _i ("set Scheme option SYM to VAL (default: #t);\n"
-        "use -dhelp for help")
+    _i ("set Scheme option SYM to VAL (default: '#t')")
+  },
+  {
+    _i ("no-SYM"), "define-default", 'd',
+    _i ("set Scheme option SYM to '#f'")
+  },
+  {
+    _i ("help"), "define-default", 'd',
+    _i ("show help for Scheme options")
   },
   {
     _i ("EXPR"), "evaluate", 'e',
@@ -881,23 +889,15 @@ setup_guile_env ()
 #endif
 }
 
-//vector<string> start_environment_global;
-
 int
-main (int argc, char **argv, char **envp)
+main (int argc, char **argv)
 /*
  * Main entry-point for LilyPond executable image
  * Parameters:
  * argc:   Count of arguments on the command line
  * argv:   Vector of string arguments on command line
- * envp:   Point to vector of OS environment variables
  */
 {
-  /*
-    Process environment variables
-  */
-  for (char **p = envp; *p; p++)
-    start_environment_global.push_back (*p);
   /*
     Handle old-style environment equivalent to
     old-style -V or --verbose command arguments.
