@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 2007--2015 Han-Wen Nienhuys <hanwen@lilypond.org>
+  Copyright (C) 2007--2020 Han-Wen Nienhuys <hanwen@lilypond.org>
 
 
   LilyPond is free software: you can redistribute it and/or modify
@@ -24,6 +24,9 @@
 #include "std-string.hh"
 #include "string-convert.hh"
 
+using std::string;
+using std::vector;
+
 Midi_track::Midi_track (int number, bool port)
   : number_ (number)
 {
@@ -57,9 +60,9 @@ Midi_track::Midi_track (int number, bool port)
 
   if (port)
     {
-      string port = "00" "ff" "21" "01"
-                    + String_convert::int2hex (number_, 2, '0');
-      data_string += String_convert::hex2bin (port);
+      uint8_t num = uint8_t (number_);
+      uint8_t out[5] = {0x00, 0xff, 0x21, 0x01, num};
+      data_string += string ((char *) out, sizeof (out));
     }
 
   set ("MTrk", data_string, "");
@@ -138,7 +141,8 @@ Midi_track::data_string () const
 
 Midi_track::~Midi_track ()
 {
-  junk_pointers (events_);
+  for (auto *event : events_)
+    delete event;
 }
 
 /****************************************************************
@@ -163,17 +167,9 @@ Midi_event::to_string () const
 
 Midi_header::Midi_header (int format, int tracks, int clocks_per_4)
 {
-  string str;
-
-  string format_string = String_convert::int2hex (format, 4, '0');
-  str += String_convert::hex2bin (format_string);
-
-  string tracks_string = String_convert::int2hex (tracks, 4, '0');
-  str += String_convert::hex2bin (tracks_string);
-
-  string tempo_string = String_convert::int2hex (clocks_per_4, 4, '0');
-  str += String_convert::hex2bin (tempo_string);
-
+  string str = String_convert::be_u16 (uint16_t (format))
+               + String_convert::be_u16 (uint16_t (tracks))
+               + String_convert::be_u16 (uint16_t (clocks_per_4));
   set ("MThd", str, "");
 }
 
@@ -204,14 +200,10 @@ Midi_chunk::to_string () const
 {
   string str = header_string_;
   string dat = data_string ();
-  string length_string = String_convert::int2hex (dat.length ()
-                                                  + footer_string_.length (), 8, '0');
-  length_string = String_convert::hex2bin (length_string);
-
-  str += length_string;
+  uint32_t total = uint32_t (dat.length () + footer_string_.length ());
+  str += String_convert::be_u32 (total);
   str += dat;
   str += footer_string_;
 
   return str;
 }
-
