@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2020 Han-Wen Nienhuys <hanwen@xs4all.nl>
   Jan Nieuwenhuizen <janneke@gnu.org>
 
   LilyPond is free software: you can redistribute it and/or modify
@@ -27,6 +27,8 @@
 #include "midi-stream.hh"
 #include "warn.hh"
 
+#include <algorithm>
+
 Midi_note_event::Midi_note_event ()
 {
   ignore_ = false;
@@ -57,7 +59,7 @@ Midi_walker::Midi_walker (Audio_staff *audio_staff, Midi_track *track, int start
   track_ = track;
   index_ = 0;
   items_ = audio_staff->audio_items_;
-  vector_stable_sort (items_, audio_item_less);
+  std::stable_sort (items_.begin (), items_.end (), audio_item_less);
   //Scores that begin with grace notes start at negative times. This
   //is OK - MIDI output doesn't use absolute ticks, only differences.
   last_tick_ = start_tick;
@@ -67,7 +69,8 @@ Midi_walker::Midi_walker (Audio_staff *audio_staff, Midi_track *track, int start
 
 Midi_walker::~Midi_walker ()
 {
-  junk_pointers (midi_events_);
+  for (auto *event : midi_events_)
+    delete event;
 }
 
 void
@@ -87,8 +90,9 @@ Midi_walker::do_start_note (Midi_note *note)
   Audio_item *ptr = items_[index_];
   assert (note->audio_ == ptr);
   int now_ticks = ptr->audio_column_->ticks ();
-  int stop_ticks = int (moment_to_real (note->audio_->length_mom_) *
-                        Real (384 * 4)) + now_ticks;
+  int stop_ticks = int (moment_to_real (note->audio_->length_mom_)
+                        * static_cast<Real> (384 * 4))
+                   + now_ticks;
   for (vsize i = 0; i < stop_note_queue.size (); i++)
     {
       /* if this pitch already in queue, and is not already ignored */
@@ -190,7 +194,7 @@ Midi_walker::process ()
     {
       if (Midi_note *note = dynamic_cast<Midi_note *> (midi))
         {
-          if (note->audio_->length_mom_.to_bool ())
+          if (note->audio_->length_mom_)
             do_start_note (note);
         }
       else
