@@ -23,28 +23,6 @@
 
 using std::string;
 
-Moment::Moment ()
-{
-}
-
-Moment::Moment (int m)
-{
-  main_part_ = Rational (m);
-  grace_part_ = Rational (0);
-}
-
-Moment::Moment (Rational m, Rational g)
-{
-  main_part_ = m;
-  grace_part_ = g;
-}
-
-Moment::Moment (Rational m)
-{
-  main_part_ = m;
-  grace_part_ = Rational (0);
-}
-
 const char *const Moment::type_p_name_ = "ly:moment?";
 
 int
@@ -83,67 +61,44 @@ Moment::compare (Moment const &a, Moment const &b)
   return Rational::compare (a.grace_part_, b.grace_part_);
 }
 
-void
+Moment &
 Moment::operator += (Moment const &src)
 {
   main_part_ += src.main_part_;
   grace_part_ += src.grace_part_;
+  return *this;
 }
 
-void
+Moment &
 Moment::operator -= (Moment const &src)
 {
   main_part_ -= src.main_part_;
   grace_part_ -= src.grace_part_;
+  return *this;
 }
 
-/* Only take the main part of SRC for multiplication.  */
-void
-Moment::operator *= (Moment const &src)
+Moment &
+Moment::operator *= (Rational const &r)
 {
-  main_part_ *= src.main_part_;
-  grace_part_ *= src.main_part_;
+  main_part_ *= r;
+  grace_part_ *= r;
+  return *this;
 }
 
-/* Only take the main part of SRC for division.  */
-void
-Moment::operator /= (Moment const &src)
+Moment &
+Moment::operator /= (Rational const &r)
 {
-  main_part_ /= src.main_part_;
-  grace_part_ /= src.main_part_;
+  main_part_ /= r;
+  grace_part_ /= r;
+  return *this;
 }
 
-/* Only take the main part of SRC for division.  */
-void
-Moment::operator %= (Moment const &src)
+Moment &
+Moment::operator %= (Rational const &r)
 {
-  main_part_ %= src.main_part_;
-  grace_part_ %= src.main_part_;
-}
-
-I64
-Moment::den () const
-{
-  /* TODO: ensure MSB == 0 here */
-  return main_part_.den ();
-}
-
-I64
-Moment::num () const
-{
-  return main_part_.num ();
-}
-
-bool
-Moment::to_bool () const
-{
-  return main_part_ || grace_part_;
-}
-
-void
-Moment::set_infinite (int k)
-{
-  main_part_.set_infinite (k);
+  main_part_ %= r;
+  grace_part_ %= r;
+  return *this;
 }
 
 string
