@@ -24,7 +24,6 @@
 #include "duration.hh"
 #include "input.hh"
 #include "international.hh"
-#include "main.hh"
 #include "music-sequence.hh"
 #include "score.hh"
 #include "warn.hh"
@@ -91,8 +90,8 @@ Moment
 Music::get_length () const
 {
   SCM lst = get_property (this, "length");
-  if (unsmob<Moment> (lst))
-    return *unsmob<Moment> (lst);
+  if (auto *mom = unsmob<Moment> (lst))
+    return *mom;
 
   if (ly_is_procedure (length_callback_))
     {
@@ -148,8 +147,8 @@ Music::generic_to_relative_octave (Pitch last)
                               new_pit.get_notename (),
                               new_pit.get_alteration ());
           warning (_f ("octave check failed; expected \"%s\", found: \"%s\"",
-                                  expected_pit.to_string (),
-                                  new_pit.to_string ()));
+                       expected_pit.to_string (),
+                       new_pit.to_string ()));
           new_pit = expected_pit;
         }
 
@@ -268,7 +267,7 @@ Music::to_event () const
   (Lily::ly_make_event_class (class_name),
    mutable_property_alist_);
   Moment length = get_length ();
-  if (length.to_bool ())
+  if (length)
     set_property (e, "length", length.smobbed_copy ());
 
   // articulations as events.
