@@ -26,8 +26,7 @@ LY_DEFINE (ly_note_head__stem_attachment, "ly:note-head::stem-attachment",
            "Get attachment in @var{font-metric} for attaching a stem to"
            " notehead @var{glyph-name}.")
 {
-  LY_ASSERT_SMOB (Font_metric, font_metric, 1);
-  Font_metric *fm = unsmob<Font_metric> (font_metric);
+  auto *const fm = LY_ASSERT_SMOB (Font_metric, font_metric, 1);
   LY_ASSERT_TYPE (scm_is_string, glyph_name, 2);
 
   return to_scm (Note_head::get_stem_attachment (fm, ly_scm2string (glyph_name)));
