@@ -143,6 +143,10 @@
 #include "system.hh"
 #include "warn.hh"
 
+#include <algorithm>
+#include <utility>
+#include <vector>
+
 using std::pair;
 using std::vector;
 
@@ -577,7 +581,7 @@ Page_breaking::draw_page (SCM systems, SCM configuration, int page_num, bool las
   set_property (p, "lines", paper_systems);
   set_property (p, "configuration", configuration);
 
-  Stencil *foot_p = unsmob<Stencil> (get_property (p, "foot-stencil"));
+  auto *foot_p = unsmob<const Stencil> (get_property (p, "foot-stencil"));
   Stencil foot = foot_p ? *foot_p : Stencil ();
 
   SCM footnotes = Page_layout_problem::get_footnotes_from_lines (systems);
@@ -947,7 +951,7 @@ Page_breaking::set_current_breakpoints (vsize start,
 
           dems_and_indices.push_back (pair<Real, vsize> (dem, i));
         }
-      vector_sort (dems_and_indices, std::less<pair<Real, vsize> > ());
+      std::sort (dems_and_indices.begin (), dems_and_indices.end ());
 
       vector<Line_division> best_5_configurations;
       for (vsize i = 0; i < 5; i++)
