@@ -39,13 +39,6 @@ using std::string;
 Paper_column_engraver::Paper_column_engraver (Context *c)
   : Engraver (c)
 {
-  last_moment_.main_part_ = Rational (-1, 1);
-  command_column_ = 0;
-  musical_column_ = 0;
-  breaks_ = 0;
-  system_ = 0;
-  first_ = true;
-  made_columns_ = false;
 }
 
 void
@@ -54,46 +47,31 @@ Paper_column_engraver::finalize ()
   if (! (breaks_ % 8))
     progress_indication ("[" + std::to_string (breaks_) + "]");
 
-  if (!made_columns_)
+  // At the end of the score, allow page breaks and turns by default, but...
+  set_property (command_column_,
+                "page-break-permission", ly_symbol2scm ("allow"));
+  set_property (command_column_,
+                "page-turn-permission", ly_symbol2scm ("allow"));
+
+  // ...allow the user to override them.
+  handle_manual_breaks (true);
+
+  // On the other hand, line breaks are always allowed at the end of a score,
+  // even if they try to stop us.
+  if (!scm_is_symbol (get_property (command_column_, "line-break-permission")))
     {
-      make_columns ();
-      SCM m = now_mom ().smobbed_copy ();
-      set_property (command_column_, "when", m);
-      set_property (musical_column_, "when", m);
+      set_property (command_column_,
+                    "line-break-permission", ly_symbol2scm ("allow"));
     }
 
-  if (command_column_)
-    {
-      // At the end of the score, allow page breaks and turns by default, but...
-      set_property (command_column_, "page-break-permission", ly_symbol2scm ("allow"));
-      set_property (command_column_, "page-turn-permission", ly_symbol2scm ("allow"));
-
-      // ...allow the user to override them.
-      handle_manual_breaks (true);
-
-      // On the other hand, line breaks are always allowed at the end of a score,
-      // even if they try to stop us.
-      if (!scm_is_symbol (get_property (command_column_, "line-break-permission")))
-        set_property (command_column_, "line-break-permission", ly_symbol2scm ("allow"));
-
-      system_->set_bound (RIGHT, command_column_);
-    }
+  system_->set_bound (RIGHT, command_column_);
 }
 
 void
 Paper_column_engraver::make_columns ()
 {
-  /*
-    ugh.
-  */
   Paper_column *p1 = make_paper_column ("NonMusicalPaperColumn");
   Paper_column *p2 = make_paper_column ("PaperColumn");
-  /*
-     The columns are timestamped with now_mom () in
-     stop_translation_timestep. Cannot happen now, because the
-     first column is sometimes created before now_mom is initialised.
-  */
-
   set_columns (p1, p2);
 }
 
@@ -108,9 +86,9 @@ Paper_column_engraver::initialize ()
 }
 
 void
-Paper_column_engraver::acknowledge_item (Grob_info gi)
+Paper_column_engraver::acknowledge_item (Grob_info_t<Item> gi)
 {
-  items_.push_back (dynamic_cast<Item *> (gi.grob ()));
+  items_.push_back (gi.grob ());
 }
 
 void
@@ -160,10 +138,10 @@ Paper_column_engraver::listen_label (Stream_event *ev)
 void
 Paper_column_engraver::handle_manual_breaks (bool only_do_permissions)
 {
-  for (vsize i = 0; i < break_events_.size (); i++)
+  for (auto *const break_event : break_events_)
     {
       string prefix;
-      SCM name_sym = scm_car (get_property (break_events_[i], "class"));
+      SCM name_sym = scm_car (get_property (break_event, "class"));
       string name = ly_symbol2string (name_sym);
       size_t end = name.rfind ("-event");
       if (end)
@@ -178,8 +156,8 @@ Paper_column_engraver::handle_manual_breaks (bool only_do_permissions)
       string pen_str = prefix + "-penalty";
 
       SCM cur_pen = get_property (command_column_, pen_str.c_str ());
-      SCM pen = get_property (break_events_[i], "break-penalty");
-      SCM perm = get_property (break_events_[i], "break-permission");
+      SCM pen = get_property (break_event, "break-penalty");
+      SCM perm = get_property (break_event, "break-permission");
 
       if (!only_do_permissions && scm_is_number (pen))
         {
@@ -197,21 +175,18 @@ Paper_column_engraver::process_music ()
 {
   handle_manual_breaks (false);
 
-  for (vsize i = 0; i < label_events_.size (); i++)
+  for (auto *const label_event : label_events_)
     {
-      SCM label = get_property (label_events_[i], "page-label");
+      SCM label = get_property (label_event, "page-label");
       SCM labels = get_property (command_column_, "labels");
       set_property (command_column_, "labels", scm_cons (label, labels));
     }
 
-  bool start_of_measure = (last_moment_.main_part_ != now_mom ().main_part_
-                           && !measure_position (context ()).main_part_);
-
   /*
     We can't do this in start_translation_timestep (), since time sig
     changes won't have happened by then.
   */
-  if (start_of_measure)
+  if (!measure_position (context ()).main_part_)
     {
       Moment mlen = Moment (measure_length (context ()));
       Grob *column = unsmob<Grob> (get_property (this, "currentCommandColumn"));
@@ -228,6 +203,7 @@ Paper_column_engraver::stop_translation_timestep ()
   if (from_scm<bool> (get_property (this, "skipTypesetting")))
     return;
 
+  // It would be safe to set "when" earlier, but there is no obvious need.
   SCM m = now_mom ().smobbed_copy ();
   set_property (command_column_, "when", m);
   set_property (musical_column_, "when", m);
@@ -244,9 +220,8 @@ Paper_column_engraver::stop_translation_timestep ()
       set_property (musical_column_, "rhythmic-location", where);
     }
 
-  for (vsize i = 0; i < items_.size (); i++)
+  for (auto *const elem : items_)
     {
-      Item *elem = items_[i];
       Grob *col = Item::is_non_musical (elem) ? command_column_ : musical_column_;
 
       if (!elem->get_x_parent ())
@@ -268,9 +243,9 @@ Paper_column_engraver::stop_translation_timestep ()
       set_property (command_column_, "page-turn-permission", SCM_EOL);
       set_property (command_column_, "page-break-permission", SCM_EOL);
       set_property (command_column_, "line-break-permission", SCM_EOL);
-      for (vsize i = 0; i < break_events_.size (); i++)
+      for (auto *const break_event : break_events_)
         {
-          SCM perm = get_property (break_events_[i], "break-permission");
+          SCM perm = get_property (break_event, "break-permission");
           if (scm_is_eq (perm, ly_symbol2scm ("force"))
               || scm_is_eq (perm, ly_symbol2scm ("allow")))
             warning (_ ("forced break was overridden by some other event, "
@@ -287,7 +262,6 @@ Paper_column_engraver::stop_translation_timestep ()
 
   find_score_context ()->unset_property (ly_symbol2scm ("forbidBreak"));
 
-  first_ = false;
   label_events_.clear ();
 }
 
@@ -295,11 +269,8 @@ void
 Paper_column_engraver::start_translation_timestep ()
 {
   break_events_.clear ();
-  if (!first_ && !from_scm<bool> (get_property (this, "skipTypesetting")))
-    {
-      make_columns ();
-      made_columns_ = true;
-    }
+  if (!from_scm<bool> (get_property (this, "skipTypesetting")))
+    make_columns ();
 }
 
 void
