@@ -215,11 +215,11 @@ LY_DEFINE (ly_paper_column__break_align_width, "ly:paper-column::break-align-wid
            " single @code{break-align-symbol} or a list of such"
            " symbols.")
 {
-  LY_ASSERT_SMOB (Grob, col, 1);
+  auto *const me = LY_ASSERT_SMOB (Grob, col, 1);
   SCM_ASSERT_TYPE (scm_is_symbol (align_syms) || ly_is_list (align_syms),
                    align_syms, SCM_ARG2, __FUNCTION__, "symbol or list");
 
-  Interval ext = Paper_column::break_align_width (unsmob<Grob> (col), align_syms);
+  Interval ext = Paper_column::break_align_width (me, align_syms);
   return to_scm (ext);
 }
 
@@ -272,15 +272,14 @@ Paper_column::print (SCM p)
 
   Font_metric *musfont = Font_interface::get_default_font (me);
   SCM properties = Font_interface::text_font_alist_chain (me);
-  SCM scm_mol = Text_interface::interpret_markup (me->layout ()->self_scm (),
-                                                  properties,
-                                                  ly_string2scm (r));
-  SCM when_mol = Text_interface::interpret_markup (me->layout ()->self_scm (),
-                                                   properties,
-                                                   ly_string2scm (when));
-  Stencil t = *unsmob<Stencil> (scm_mol);
+  auto t = Text_interface::interpret_markup (me->layout (),
+                                             properties,
+                                             ly_string2scm (r));
+  auto when_mol = Text_interface::interpret_markup (me->layout (),
+                                                    properties,
+                                                    ly_string2scm (when));
   t.scale (1.2, 1.4);
-  t.add_at_edge (Y_AXIS, DOWN, *unsmob<Stencil> (when_mol), 0.1);
+  t.add_at_edge (Y_AXIS, DOWN, when_mol, 0.1);
   t.align_to (X_AXIS, LEFT);
   // compensate for font serifs and half letter-distance
   t.translate (Offset (-0.1, 0));
@@ -310,14 +309,16 @@ Paper_column::print (SCM p)
       arrowhead.scale (1, 1.66);
       Real head_len = arrowhead.extent (X_AXIS).length ();
 
-      SCM stil = Text_interface::interpret_markup (me->layout ()->self_scm (),
-                                                   properties,
-                                                   ly_string2scm (String_convert::form_string ("%5.2lf", sp->distance ())));
-      Stencil *number_stc = unsmob<Stencil> (stil);
-      number_stc->scale (1, 1.1);
-      Real num_height = number_stc->extent (Y_AXIS).length ();
-      Real num_len = number_stc->extent (X_AXIS).length ();
-      number_stc->align_to (Y_AXIS, DOWN);
+      SCM number_markup
+        = ly_string2scm (String_convert::form_string ("%5.2lf",
+                                                      sp->distance ()));
+      auto number_stc = Text_interface::interpret_markup (me->layout (),
+                                                          properties,
+                                                          number_markup);
+      number_stc.scale (1, 1.1);
+      Real num_height = number_stc.extent (Y_AXIS).length ();
+      Real num_len = number_stc.extent (X_AXIS).length ();
+      number_stc.align_to (Y_AXIS, DOWN);
 
       // arrow's y-coord relative to the top of l stencil:
       Real y = -2.5;
@@ -334,7 +335,7 @@ Paper_column::print (SCM p)
 
       Stencil id_stencil = Lookup::points_to_line_stencil (0.1, pts);
       id_stencil.add_stencil (arrowhead.translated (p2));
-      id_stencil.add_stencil (number_stc->translated (num_off));
+      id_stencil.add_stencil (number_stc.translated (num_off));
       // use a lighter shade of blue so it will remain legible on black background.
       id_stencil = id_stencil.in_color (0.2, 0.4, 1.0);
       l.add_stencil (id_stencil);
@@ -355,14 +356,15 @@ Paper_column::print (SCM p)
       arrowhead.scale (1, 1.66);
       Real head_len = arrowhead.extent (X_AXIS).length ();
 
-      SCM stil = Text_interface::interpret_markup (me->layout ()->self_scm (),
-                                                   properties,
-                                                   ly_string2scm (String_convert::form_string ("%5.2lf", dist)));
-      Stencil *number_stc = unsmob<Stencil> (stil);
-      number_stc->scale (1, 1.1);
-      Real num_height = number_stc->extent (Y_AXIS).length ();
-      Real num_len = number_stc->extent (X_AXIS).length ();
-      number_stc->align_to (Y_AXIS, UP);
+      SCM number_markup
+        = ly_string2scm (String_convert::form_string ("%5.2lf", dist));
+      auto number_stc = Text_interface::interpret_markup (me->layout (),
+                                                          properties,
+                                                          number_markup);
+      number_stc.scale (1, 1.1);
+      Real num_height = number_stc.extent (Y_AXIS).length ();
+      Real num_len = number_stc.extent (X_AXIS).length ();
+      number_stc.align_to (Y_AXIS, UP);
 
       // arrow's y-coord relative to the top of l stencil:
       Real y = -3;
@@ -379,7 +381,7 @@ Paper_column::print (SCM p)
 
       Stencil id_stencil = Lookup::points_to_line_stencil (0.1, pts);
       id_stencil.add_stencil (arrowhead.translated (p2));
-      id_stencil.add_stencil (number_stc->translated (num_off));
+      id_stencil.add_stencil (number_stc.translated (num_off));
       // use a lighter shade of red so it will remain legible on black background.
       id_stencil = id_stencil.in_color (1.0, 0.25, 0.25);
       l.add_stencil (id_stencil);
