@@ -22,7 +22,6 @@
 #include "all-font-metrics.hh"
 #include "book.hh"
 #include "international.hh"
-#include "main.hh"
 #include "misc.hh"
 #include "output-def.hh"
 #include "paper-book.hh"
@@ -117,7 +116,7 @@ Paper_score::calc_breaking ()
 
   message (_ ("Calculating line breaks...") + " ");
 
-  int system_count = robust_scm2int (layout ()->c_variable ("system-count"), 0);
+  int system_count = from_scm (layout ()->c_variable ("system-count"), 0);
   if (system_count)
     return algorithm.solve (0, VPOS, system_count);
 
