@@ -43,7 +43,7 @@ Performer_group::announce_element (Audio_element_info info)
 {
   announce_infos_.push_back (info);
   Translator_group *t
-    = context ()->get_parent_context ()->implementation ();
+    = context ()->get_parent ()->implementation ();
 
   if (Performer_group *eg = dynamic_cast<Performer_group *> (t))
     eg->announce_element (info);
@@ -66,17 +66,6 @@ Performer_group::acknowledge_audio_elements ()
     }
 }
 
-void
-performer_each (SCM list, Performer_method method)
-{
-  for (SCM p = list; scm_is_pair (p); p = scm_cdr (p))
-    {
-      Performer *e = unsmob<Performer> (scm_car (p));
-      if (e)
-        (e->*method) ();
-    }
-}
-
 void
 Performer_group::do_announces ()
 {
@@ -92,9 +81,6 @@ Performer_group::do_announces ()
 
   while (1)
     {
-      performer_each (get_simple_trans_list (),
-                      &Performer::create_audio_elements);
-
       if (!announce_infos_.size ())
         break;
 
