@@ -21,6 +21,7 @@
   along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "piano-pedal.hh"
 #include "engraver.hh"
 
 #include "axis-group-interface.hh"
@@ -50,15 +51,6 @@ using std::string;
   * Try to use same engraver for dynamics.
 */
 
-/* Ugh: This declaration is duplicated in piano-pedal-performer */
-enum Pedal_type
-{
-  SOSTENUTO,
-  SUSTAIN,
-  UNA_CORDA,
-  NUM_PEDAL_TYPES
-};
-
 /*
   Static precalculated data (symbols and strings) for the different
   pedal types
@@ -129,30 +121,47 @@ private:
   void typeset_all (Pedal_info *p);
 };
 
+const char * pedal_type_name (int t)
+{
+  switch (t)
+    {
+    case SOSTENUTO:
+      return "Sostenuto";
+    case SUSTAIN:
+      return "Sustain";
+    case UNA_CORDA:
+      return "UnaCorda";
+    default:
+      programming_error ("Unknown pedal type");
+      return 0;
+    }
+}
+
+const char * pedal_type_ident (int t)
+{
+  switch (t)
+    {
+    case SOSTENUTO:
+      return "sostenuto";
+    case SUSTAIN:
+      return "sustain";
+    case UNA_CORDA:
+      return "una-corda";
+    default:
+      programming_error ("Unknown pedal type");
+      return 0;
+    }
+}
+
 static void
 init_pedal_types ()
 {
-  const char *names [NUM_PEDAL_TYPES];
-  names[SOSTENUTO] = "Sostenuto";
-  names[SUSTAIN] = "Sustain";
-  names[UNA_CORDA] = "UnaCorda";
-
   for (int i = 0; i < NUM_PEDAL_TYPES; i++)
     {
-      const char *name = names[i];
       /* FooBar */
-      string base_name = name;
+      string base_name = pedal_type_name (i);
       /* foo-bar */
-      string base_ident = "";
-      int prev_pos = 0;
-      int cur_pos;
-      for (cur_pos = 1; name[cur_pos]; cur_pos++)
-        if (isupper (name[cur_pos]))
-          {
-            base_ident = base_ident + String_convert::to_lower (string (name, prev_pos, cur_pos - prev_pos)) + "-";
-            prev_pos = cur_pos;
-          }
-      base_ident += String_convert::to_lower (string (name, prev_pos, cur_pos - prev_pos));
+      string base_ident = pedal_type_ident (i);
 
       /*
         be careful, as we don't want to loose references to the _sym_ members.
@@ -162,7 +171,7 @@ init_pedal_types ()
       info.style_sym_ = scm_from_ascii_symbol (("pedal" + base_name + "Style").c_str ());
       info.strings_sym_ = scm_from_ascii_symbol (("pedal" + base_name + "Strings").c_str ());
 
-      info.base_name_ = name;
+      info.base_name_ = base_name;
       info.pedal_str_ = base_name + "Pedal";
 
       info.protect ();
@@ -201,21 +210,21 @@ Piano_pedal_engraver::initialize ()
 void
 Piano_pedal_engraver::listen_sostenuto (Stream_event *ev)
 {
-  Direction d = to_dir (ev->get_property ("span-direction"));
+  Direction d = from_scm<Direction> (get_property (ev, "span-direction"));
   ASSIGN_EVENT_ONCE (info_list_[SOSTENUTO].event_drul_[d], ev);
 }
 
 void
 Piano_pedal_engraver::listen_sustain (Stream_event *ev)
 {
-  Direction d = to_dir (ev->get_property ("span-direction"));
+  Direction d = from_scm<Direction> (get_property (ev, "span-direction"));
   ASSIGN_EVENT_ONCE (info_list_[SUSTAIN].event_drul_[d], ev);
 }
 
 void
 Piano_pedal_engraver::listen_una_corda (Stream_event *ev)
 {
-  Direction d = to_dir (ev->get_property ("span-direction"));
+  Direction d = from_scm<Direction> (get_property (ev, "span-direction"));
   ASSIGN_EVENT_ONCE (info_list_[UNA_CORDA].event_drul_[d], ev);
 }
 
@@ -239,7 +248,7 @@ Piano_pedal_engraver::process_music ()
             mixed:   Ped. _____/\____|
           */
 
-          SCM style = get_property (p->type_->style_sym_);
+          SCM style = get_property (this, p->type_->style_sym_);
 
           bool mixed = scm_is_eq (style, ly_symbol2scm ("mixed"));
           bool bracket = (mixed
@@ -259,7 +268,7 @@ void
 Piano_pedal_engraver::create_text_grobs (Pedal_info *p, bool mixed)
 {
   SCM s = SCM_EOL;
-  SCM strings = get_property (p->type_->strings_sym_);
+  SCM strings = get_property (this, p->type_->strings_sym_);
 
   if (scm_ilength (strings) < 3)
     {
@@ -269,7 +278,7 @@ Piano_pedal_engraver::create_text_grobs (Pedal_info *p, bool mixed)
       string msg = _f ("expect 3 strings for piano pedals, found: %ld",
                        scm_ilength (strings));
       if (m)
-        m->origin ()->warning (msg);
+        m->warning (msg);
       else
         warning (msg);
 
@@ -281,7 +290,7 @@ Piano_pedal_engraver::create_text_grobs (Pedal_info *p, bool mixed)
       if (!mixed)
         {
           if (!p->start_ev_)
-            p->event_drul_[STOP]->origin ()->warning (_f ("cannot find start of piano pedal: `%s'", p->type_->base_name_.c_str ()));
+            p->event_drul_[STOP]->warning (_f ("cannot find start of piano pedal: `%s'", p->type_->base_name_.c_str ()));
           else
             s = scm_cadr (strings);
           p->start_ev_ = p->event_drul_[START];
@@ -292,7 +301,7 @@ Piano_pedal_engraver::create_text_grobs (Pedal_info *p, bool mixed)
       if (!mixed)
         {
           if (!p->start_ev_)
-            p->event_drul_[STOP]->origin ()->warning (_f ("cannot find start of piano pedal: `%s'", p->type_->base_name_.c_str ()));
+            p->event_drul_[STOP]->warning (_f ("cannot find start of piano pedal: `%s'", p->type_->base_name_.c_str ()));
           else
             s = scm_caddr (strings);
           p->start_ev_ = 0;
@@ -311,7 +320,7 @@ Piano_pedal_engraver::create_text_grobs (Pedal_info *p, bool mixed)
                              ? p->event_drul_[START]
                              : p->event_drul_[STOP])->self_scm ());
 
-      p->item_->set_property ("text", s);
+      set_property (p->item_, "text", s);
     }
 
   if (!mixed)
@@ -327,7 +336,7 @@ Piano_pedal_engraver::create_bracket_grobs (Pedal_info *p, bool mixed)
   if (!p->bracket_ && p->event_drul_[STOP])
     {
       string msg = _f ("cannot find start of piano pedal bracket: `%s'", p->type_->base_name_.c_str ());
-      p->event_drul_[STOP]->origin ()->warning (msg);
+      p->event_drul_[STOP]->warning (msg);
       p->event_drul_[STOP] = 0;
     }
 
@@ -335,7 +344,7 @@ Piano_pedal_engraver::create_bracket_grobs (Pedal_info *p, bool mixed)
     {
       assert (!p->finished_bracket_);
 
-      Grob *cmc = unsmob<Grob> (get_property ("currentMusicalColumn"));
+      Grob *cmc = unsmob<Grob> (get_property (this, "currentMusicalColumn"));
       p->bracket_->set_bound (RIGHT, cmc);
 
       /*
@@ -345,10 +354,10 @@ Piano_pedal_engraver::create_bracket_grobs (Pedal_info *p, bool mixed)
 
       if (!p->event_drul_[START])
         {
-          SCM flare = p->bracket_->get_property ("bracket-flare");
+          SCM flare = get_property (p->bracket_, "bracket-flare");
           if (scm_is_pair (flare))
-            p->bracket_->set_property ("bracket-flare", scm_cons (scm_car (flare),
-                                                                  scm_from_double (0)));
+            set_property (p->bracket_, "bracket-flare", scm_cons (scm_car (flare),
+                                                                  to_scm (0)));
         }
 
       p->finished_bracket_ = p->bracket_;
@@ -373,8 +382,8 @@ Piano_pedal_engraver::create_bracket_grobs (Pedal_info *p, bool mixed)
 
       if (!p->finished_bracket_)
         {
-          SCM flare = p->bracket_->get_property ("bracket-flare");
-          p->bracket_->set_property ("bracket-flare", scm_cons (scm_from_double (0), scm_cdr (flare)));
+          SCM flare = get_property (p->bracket_, "bracket-flare");
+          set_property (p->bracket_, "bracket-flare", scm_cons (to_scm (0), scm_cdr (flare)));
         }
 
       /* Set this property for 'mixed style' pedals,    Ped._______/\ ,
@@ -393,7 +402,7 @@ Piano_pedal_engraver::create_bracket_grobs (Pedal_info *p, bool mixed)
             WTF is pedal-text not the bound of the object? --hwn
           */
           if (p->item_)
-            p->bracket_->set_object ("pedal-text", p->item_->self_scm ());
+            set_object (p->bracket_, "pedal-text", p->item_->self_scm ());
         }
     }
 
@@ -412,7 +421,7 @@ Piano_pedal_engraver::finalize ()
 
       if (p->bracket_)
         {
-          SCM cc = get_property ("currentCommandColumn");
+          SCM cc = get_property (this, "currentCommandColumn");
           Item *c = unsmob<Item> (cc);
           p->bracket_->set_bound (RIGHT, c);
 
@@ -433,7 +442,7 @@ Piano_pedal_engraver::stop_translation_timestep ()
       typeset_all (p);
       if (p->bracket_ && !p->bracket_->get_bound (LEFT))
         {
-          Grob *cmc = unsmob<Grob> (get_property ("currentMusicalColumn"));
+          Grob *cmc = unsmob<Grob> (get_property (this, "currentMusicalColumn"));
           p->bracket_->set_bound (LEFT, cmc);
         }
     }
@@ -462,7 +471,7 @@ Piano_pedal_engraver::typeset_all (Pedal_info *p)
     {
       Grob *r = p->finished_bracket_->get_bound (RIGHT);
       if (!r)
-        p->finished_bracket_->set_bound (RIGHT, unsmob<Grob> (get_property ("currentMusicalColumn")));
+        p->finished_bracket_->set_bound (RIGHT, unsmob<Grob> (get_property (this, "currentMusicalColumn")));
 
       p->finished_bracket_ = 0;
     }
