@@ -24,13 +24,11 @@ LY_DEFINE (ly_pointer_group_interface__add_grob, "ly:pointer-group-interface::ad
            3, 0, 0, (SCM grob, SCM sym, SCM grob_element),
            "Add @var{grob-element} to @var{grob}'s @var{sym} grob array.")
 {
-  LY_ASSERT_SMOB (Grob, grob, 1);
+  auto *const g = LY_ASSERT_SMOB (Grob, grob, 1);
   LY_ASSERT_TYPE (ly_is_symbol, sym, 2);
-  LY_ASSERT_SMOB (Grob, grob_element, 3);
+  auto *const elem = LY_ASSERT_SMOB (Grob, grob_element, 3);
 
-  Pointer_group_interface::add_grob (unsmob<Grob> (grob),
-                                     sym,
-                                     unsmob<Grob> (grob_element));
+  Pointer_group_interface::add_grob (g, sym, elem);
   return SCM_UNSPECIFIED;
 }
 
