@@ -27,19 +27,19 @@
 
 #include <algorithm>
 #include <map>
+#include <vector>
 
 using std::vector;
 
 class Pure_from_neighbor_engraver : public Engraver
 {
-  vector<Grob *> pure_relevants_;
-  vector<Grob *> need_pure_heights_from_neighbors_;
+  vector<Item *> pure_relevants_;
+  vector<Item *> need_pure_heights_from_neighbors_;
 
 public:
   TRANSLATOR_DECLARATIONS (Pure_from_neighbor_engraver);
 protected:
-  void acknowledge_pure_from_neighbor (Grob_info);
-  void acknowledge_item (Grob_info);
+  void acknowledge_item (Grob_info_t<Item>);
   void finalize () override;
 };
 
@@ -49,13 +49,13 @@ Pure_from_neighbor_engraver::Pure_from_neighbor_engraver (Context *c)
 }
 
 void
-Pure_from_neighbor_engraver::acknowledge_item (Grob_info i)
+Pure_from_neighbor_engraver::acknowledge_item (Grob_info_t<Item> info)
 {
-  if (Item *item = dynamic_cast<Item *> (i.grob ()))
-    {
-      if (!has_interface<Pure_from_neighbor_interface> (item))
-        pure_relevants_.push_back (item);
-    }
+  auto *const item = info.grob ();
+  if (has_interface<Pure_from_neighbor_interface> (item))
+    need_pure_heights_from_neighbors_.push_back (item);
+  else
+    pure_relevants_.push_back (item);
 }
 
 bool
@@ -69,21 +69,15 @@ in_same_column (Grob *g1, Grob *g2)
              == g1->spanned_rank_interval ()[RIGHT]);
 }
 
-void
-Pure_from_neighbor_engraver::acknowledge_pure_from_neighbor (Grob_info i)
-{
-  Item *item = dynamic_cast<Item *> (i.grob ());
-  need_pure_heights_from_neighbors_.push_back (item);
-}
-
 void
 Pure_from_neighbor_engraver::finalize ()
 {
   if (!need_pure_heights_from_neighbors_.size ())
     return;
 
-  vector_sort (need_pure_heights_from_neighbors_, Grob::less);
-  vector_sort (pure_relevants_, Grob::less);
+  std::sort (need_pure_heights_from_neighbors_.begin (),
+             need_pure_heights_from_neighbors_.end (), Grob::less);
+  std::sort (pure_relevants_.begin (), pure_relevants_.end (), Grob::less);
 
   /*
     first, clump need_pure_heights_from_neighbors into
@@ -147,7 +141,6 @@ void
 Pure_from_neighbor_engraver::boot ()
 {
   ADD_ACKNOWLEDGER (Pure_from_neighbor_engraver, item);
-  ADD_ACKNOWLEDGER (Pure_from_neighbor_engraver, pure_from_neighbor);
 }
 
 ADD_TRANSLATOR (Pure_from_neighbor_engraver,
