@@ -20,7 +20,6 @@
 #include "engraver.hh"
 #include "translator-group.hh"
 #include "context.hh"
-#include "repeated-music.hh"
 
 #include "translator.icc"
 
@@ -42,9 +41,15 @@ public:
 
   TRANSLATOR_DECLARATIONS (Repeat_acknowledge_engraver);
 protected:
+  void listen_volta_span (Stream_event *);
   void start_translation_timestep ();
+  void stop_translation_timestep ();
   void process_music ();
   void initialize () override;
+
+private:
+  bool first_time_ = true;
+  bool heard_volta_span_ = false;
 };
 
 void
@@ -67,6 +72,14 @@ Repeat_acknowledge_engraver::start_translation_timestep ()
     tr = context ();
 
   set_property (tr, "repeatCommands", SCM_EOL);
+
+  heard_volta_span_ = false;
+}
+
+void
+Repeat_acknowledge_engraver::listen_volta_span (Stream_event *)
+{
+  heard_volta_span_ = true;
 }
 
 void
@@ -75,7 +88,7 @@ Repeat_acknowledge_engraver::process_music ()
   /*
     At the start of a piece, we don't print any repeat bars.
   */
-  if (!now_mom ().main_part_)
+  if (first_time_)
     return;
 
   SCM cs = get_property (this, "repeatCommands");
@@ -84,7 +97,7 @@ Repeat_acknowledge_engraver::process_music ()
   bool start = false;
   bool end = false;
   bool segno = false;
-  bool volta_found = false;
+  bool volta_found = heard_volta_span_;
   while (scm_is_pair (cs))
     {
       SCM command = scm_car (cs);
@@ -138,10 +151,16 @@ Repeat_acknowledge_engraver::process_music ()
     }
 }
 
+void
+Repeat_acknowledge_engraver::stop_translation_timestep ()
+{
+  first_time_ = false;
+}
+
 void
 Repeat_acknowledge_engraver::boot ()
 {
-
+  ADD_LISTENER (Repeat_acknowledge_engraver, volta_span);
 }
 
 ADD_TRANSLATOR (Repeat_acknowledge_engraver,
