@@ -19,8 +19,6 @@
 
 #include "rest-collision.hh"
 
-#include <cmath>                // ceil.
-
 #include "directional-element-interface.hh"
 #include "duration.hh"
 #include "international.hh"
@@ -37,6 +35,10 @@
 #include "warn.hh"
 #include "lily-imports.hh"
 
+#include <algorithm>
+#include <cmath> // ceil.
+#include <vector>
+
 using std::vector;
 
 MAKE_SCHEME_CALLBACK_WITH_OPTARGS (Rest_collision, force_shift_callback_rest, 2, 1, "");
@@ -44,7 +46,7 @@ SCM
 Rest_collision::force_shift_callback_rest (SCM rest, SCM offset)
 {
   Grob *rest_grob = unsmob<Grob> (rest);
-  Grob *parent = rest_grob->get_parent (X_AXIS);
+  Grob *parent = rest_grob->get_x_parent ();
 
   /*
     translate REST; we need the result of this translation later on,
@@ -55,13 +57,13 @@ Rest_collision::force_shift_callback_rest (SCM rest, SCM offset)
 
   if (has_interface<Note_column> (parent) && Note_column::has_rests (parent))
     {
-      Grob *collision = unsmob<Grob> (parent->get_object ("rest-collision"));
+      Grob *collision = unsmob<Grob> (get_object (parent, "rest-collision"));
 
       if (collision)
-        (void) collision->get_property ("positioning-done");
+        (void) get_property (collision, "positioning-done");
     }
 
-  return scm_from_double (0.0);
+  return to_scm (0.0);
 }
 
 void
@@ -69,9 +71,9 @@ Rest_collision::add_column (Grob *me, Grob *p)
 {
   Pointer_group_interface::add_grob (me, ly_symbol2scm ("elements"), p);
 
-  p->set_object ("rest-collision", me->self_scm ());
+  set_object (p, "rest-collision", me->self_scm ());
 
-  Grob *rest = unsmob<Grob> (p->get_object ("rest"));
+  Grob *rest = unsmob<Grob> (get_object (p, "rest"));
   if (rest)
     {
       chain_offset_callback (rest,
@@ -85,8 +87,8 @@ Rest_collision::add_column (Grob *me, Grob *p)
 static bool
 rest_shift_less (Grob *const &r1, Grob *const &r2)
 {
-  Grob *col1 = r1->get_parent (X_AXIS);
-  Grob *col2 = r2->get_parent (X_AXIS);
+  Grob *col1 = r1->get_x_parent ();
+  Grob *col2 = r2->get_x_parent ();
   return Note_column::shift_less (col1, col2);
 }
 
@@ -100,7 +102,7 @@ Rest_collision::calc_positioning_done (SCM smob)
 {
   Grob *me = unsmob<Grob> (smob);
 
-  me->set_property ("positioning-done", SCM_BOOL_T);
+  set_property (me, "positioning-done", SCM_BOOL_T);
 
   extract_grob_set (me, "elements", elts);
 
@@ -112,7 +114,7 @@ Rest_collision::calc_positioning_done (SCM smob)
       Grob *e = elts[i];
       if (has_interface<Note_column> (e))
         {
-          if (unsmob<Grob> (e->get_object ("rest")))
+          if (unsmob<Grob> (get_object (e, "rest")))
             rests.push_back (e);
           else
             notes.push_back (e);
@@ -156,7 +158,8 @@ Rest_collision::calc_positioning_done (SCM smob)
         }
 
       for (LEFT_and_RIGHT (d))
-        vector_sort (ordered_rests[d], rest_shift_less);
+        std::sort (ordered_rests[d].begin (), ordered_rests[d].end (),
+                   rest_shift_less);
 
       for (LEFT_and_RIGHT (d))
         {
@@ -219,7 +222,7 @@ Rest_collision::calc_positioning_done (SCM smob)
 
           // Do not compute a translation for pre-positioned rests,
           //  nor count them for the "too many colliding rests" warning
-          if (scm_is_number (rest->get_property ("staff-position")))
+          if (scm_is_number (get_property (rest, "staff-position")))
             continue;
 
           Grob *common = common_refpoint_of_array (notes, rcol, Y_AXIS);
@@ -228,7 +231,7 @@ Rest_collision::calc_positioning_done (SCM smob)
             continue;
 
           Real staff_space = Staff_symbol_referencer::staff_space (rcol);
-          Real minimum_dist = robust_scm2double (me->get_property ("minimum-distance"), 1.0) * staff_space;
+          Real minimum_dist = from_scm<double> (get_property (me, "minimum-distance"), 1.0) * staff_space;
 
           Interval notedim;
           for (vsize i = 0; i < notes.size (); i++)
@@ -287,4 +290,3 @@ ADD_INTERFACE (Rest_collision,
                "positioning-done "
                "elements "
               );
-
