@@ -94,7 +94,8 @@ Script_column::row_before_line_breaking (SCM smob)
       vector<Grob *> grobs = (*i).second;
 
       // this isn't right in all cases, but in general a safe assumption.
-      concat (grobs, affect_all_grobs);
+      grobs.insert (grobs.end(), affect_all_grobs.begin (),
+                    affect_all_grobs.end ());
       order_grobs (grobs);
     }
 
@@ -172,7 +173,7 @@ Script_column::order_grobs (vector<Grob *> grobs)
                        || (fabs (scm_to_double (initial_outside_staff)
                                  - from_scm<double> (last_initial_outside_staff, 0)) < 0.001))
                 set_property (g, "outside-staff-priority",
-                                 to_scm (scm_to_double (last_outside_staff) + 0.1));
+                              to_scm (scm_to_double (last_outside_staff) + 0.1));
             }
         }
     }
