@@ -43,6 +43,7 @@ ADD_INTERFACE (Semi_tie,
                "@end table\n",
 
                /* properties */
+               "annotation "
                "control-points "
                "direction "
                "details "
@@ -56,7 +57,7 @@ MAKE_SCHEME_CALLBACK (Semi_tie, calc_control_points, 1)
 SCM
 Semi_tie::calc_control_points (SCM smob)
 {
-  Item *me = LY_ASSERT_SMOB (Item, smob, 1);
+  auto *const me = LY_ASSERT_SMOB (Item, smob, 1);
 
   (void) get_property (me, "direction");
 
