@@ -30,7 +30,6 @@
 #include "pointer-group-interface.hh"
 #include "lookup.hh"
 #include "ly-scm-list.hh"
-#include "main.hh"              // DEBUG_SLUR_SCORING
 #include "note-column.hh"
 #include "output-def.hh"
 #include "skyline-pair.hh"
@@ -141,7 +140,7 @@ Slur::height (SCM smob)
   Grob *me = unsmob<Grob> (smob);
 
   // FIXME uncached
-  Stencil *m = me->get_stencil ();
+  auto *m = me->get_stencil ();
   return m ? to_scm (m->extent (Y_AXIS))
          : to_scm (Interval ());
 }
@@ -173,7 +172,6 @@ Slur::print (SCM smob)
                     line_thick,
                     dash_definition);
 
-#if DEBUG_SLUR_SCORING
   SCM annotation = get_property (me, "annotation");
   if (scm_is_string (annotation))
     {
@@ -184,12 +182,11 @@ Slur::print (SCM smob)
         properties = scm_cons (scm_acons (ly_symbol2scm ("font-size"), to_scm (-6), SCM_EOL),
                                properties);
 
-      Stencil tm = *unsmob<Stencil> (Text_interface::interpret_markup
-                                     (me->layout ()->self_scm (), properties,
-                                      annotation));
+      auto tm = Text_interface::interpret_markup (me->layout (),
+                                                  properties,
+                                                  annotation);
       a.add_at_edge (Y_AXIS, get_grob_direction (me), tm, 1.0);
     }
-#endif
 
   return a.smobbed_copy ();
 }
