@@ -1,7 +1,7 @@
 /*
   This file is part of LilyPond, the GNU music typesetter.
 
-  Copyright (C) 1997--2015 Han-Wen Nienhuys <hanwen@xs4all.nl>
+  Copyright (C) 1997--2020 Han-Wen Nienhuys <hanwen@xs4all.nl>
 
   LilyPond is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@
 #include "file-name.hh"
 #include "file-path.hh"
 
+using std::string;
+using std::vector;
+
 Sources::Sources ()
 {
   path_ = 0;
@@ -48,23 +51,12 @@ Sources::get_file (string file_string, string const &current_dir)
 {
   if (file_string != "-")
     {
-      // First, check for a path relative to the directory of the
-      // file currently being parsed.
-      if (current_dir.length ()
-          && file_string.length ()
-          && !File_name (file_string).is_absolute ()
-          && is_file (current_dir + DIRSEP + file_string))
-        file_string = current_dir + DIRSEP + file_string;
+      file_string = find_full_path (file_string, current_dir);
+    }
 
-      // Otherwise, check the rest of the path.
-      else if (path_)
-        {
-          string file_string_o = path_->find (file_string);
-          if ((file_string_o == "") && (file_string != ""))
-            return 0;
-
-          file_string = file_string_o;
-        }
+  if (file_string.empty ())
+    {
+      return nullptr;
     }
 
   Source_file *f = new Source_file (file_string);
@@ -72,6 +64,30 @@ Sources::get_file (string file_string, string const &current_dir)
   return f;
 }
 
+string
+Sources::find_full_path (string file_string, string const &current_dir) const
+{
+  // First, check for a path relative to the directory of the
+  // file currently being parsed.
+  if (current_dir.length ()
+      && file_string.length ()
+      && !File_name (file_string).is_absolute ()
+      && is_file (current_dir + DIRSEP + file_string))
+    file_string = current_dir + DIRSEP + file_string;
+
+  // Otherwise, check the rest of the path.
+  else if (path_)
+    {
+      return path_->find (file_string);
+    }
+  return file_string;
+}
+
+string Sources::search_path () const
+{
+  return path_->to_string ();
+}
+
 void
 Sources::add (Source_file *sourcefile)
 {
@@ -93,13 +109,13 @@ Sources::~Sources ()
 
 LY_DEFINE (ly_source_files, "ly:source-files", 0, 1, 0,
            (SCM parser_smob),
-           "A list of LilyPond files being processed;"
+           "A list of input files that have been opened up to here, "
+           "including the files that have been closed already. "
            "a PARSER may optionally be specified.")
 {
-
   if (SCM_UNBNDP (parser_smob))
     parser_smob = scm_fluid_ref (Lily::f_parser);
-  Lily_parser *parser = LY_ASSERT_SMOB (Lily_parser, parser_smob, 1);
+  auto *const parser = LY_ASSERT_SMOB (Lily_parser, parser_smob, 1);
   Includable_lexer *lex = parser->lexer_;
 
   SCM lst = SCM_EOL;
