@@ -36,14 +36,8 @@ struct Rhythmic_tuple
   Grob_info info_;
   Moment end_;
 
-  Rhythmic_tuple ()
-  {
-  }
-  Rhythmic_tuple (Grob_info i, Moment m)
-  {
-    info_ = i;
-    end_ = m;
-  }
+  Rhythmic_tuple (Grob_info i, Moment m) : info_ (i), end_ (m) {}
+
   static int time_compare (Rhythmic_tuple const &, Rhythmic_tuple const &);
 };
 
@@ -221,7 +215,7 @@ Spacing_engraver::stop_translation_timestep ()
       return;
     }
 
-  Moment shortest_playing (Rational::infinity ());
+  auto shortest_playing = Moment::infinity ();
   for (vsize i = 0; i < playing_durations_.size (); i++)
     {
       Stream_event *ev = playing_durations_[i].info_.event_cause ();
@@ -231,12 +225,12 @@ Spacing_engraver::stop_translation_timestep ()
           shortest_playing = std::min (shortest_playing, m);
         }
     }
-  Moment starter (Rational::infinity ());
+  auto starter = Moment::infinity ();
 
   for (vsize i = 0; i < now_durations_.size (); i++)
     {
       Moment m = get_event_length (now_durations_[i].info_.event_cause ());
-      if (m.to_bool ())
+      if (m)
         {
           starter = std::min (starter, m);
           playing_durations_.insert (now_durations_[i]);
@@ -246,7 +240,7 @@ Spacing_engraver::stop_translation_timestep ()
 
   shortest_playing = std::min (shortest_playing, starter);
 
-  assert (starter.to_bool ());
+  assert (starter);
   SCM sh = shortest_playing.smobbed_copy ();
   SCM st = starter.smobbed_copy ();
 
