@@ -21,7 +21,6 @@
 
 #include "spacing-options.hh"
 #include "international.hh"
-#include "main.hh"
 #include "moment.hh"
 #include "note-spacing.hh"
 #include "output-def.hh"
@@ -121,10 +120,10 @@ Spacing_spanner::calc_common_shortest_duration (SCM grob)
 
           SCM st = get_property (cols[i], "shortest-starter-duration");
           Moment this_shortest = *unsmob<Moment> (st);
-          assert (this_shortest.to_bool ());
+          assert (this_shortest);
           shortest_in_measure = std::min (shortest_in_measure, this_shortest.main_part_);
         }
-      else if (!shortest_in_measure.is_infinity ()
+      else if (!isinf (shortest_in_measure)
                && Paper_column::is_breakable (cols[i]))
         {
           vsize j = 0;
