@@ -44,10 +44,9 @@ LY_DEFINE (ly_spring_set_inverse_compress_strength_x, "ly:spring-set-inverse-com
            2, 0, 0, (SCM spring, SCM strength),
            "Set the inverse compress @var{strength} of @var{spring}.")
 {
-  LY_ASSERT_SMOB (Spring, spring, 1);
+  auto *const s = LY_ASSERT_SMOB (Spring, spring, 1);
   LY_ASSERT_TYPE (scm_is_number, strength, 2);
 
-  Spring *s = unsmob<Spring> (spring);
   s->set_inverse_compress_strength (scm_to_double (strength));
   return s->smobbed_copy ();
 }
@@ -56,10 +55,9 @@ LY_DEFINE (ly_spring_set_inverse_stretch_strength_x, "ly:spring-set-inverse-stre
            2, 0, 0, (SCM spring, SCM strength),
            "Set the inverse stretch @var{strength} of @var{spring}.")
 {
-  LY_ASSERT_SMOB (Spring, spring, 1);
+  auto *const s = LY_ASSERT_SMOB (Spring, spring, 1);
   LY_ASSERT_TYPE (scm_is_number, strength, 2);
 
-  Spring *s = unsmob<Spring> (spring);
   s->set_inverse_stretch_strength (scm_to_double (strength));
   return s->smobbed_copy ();
 }
