@@ -30,8 +30,7 @@ LY_DEFINE (ly_grob_staff_position, "ly:grob-staff-position",
            1, 0, 0, (SCM sg),
            "Return the Y-position of @var{sg} relative to the staff.")
 {
-  LY_ASSERT_SMOB (Grob, sg, 1);
-  Grob *g = unsmob<Grob> (sg);
+  auto *const g = LY_ASSERT_SMOB (Grob, sg, 1);
   Real pos = Staff_symbol_referencer::get_position (g);
 
   if (fabs (rint (pos) - pos) < 1e-6) // ugh.
@@ -45,9 +44,8 @@ LY_DEFINE (ly_position_on_line_p, "ly:position-on-line?",
            "Return whether @var{spos} is on a line of the staff associated"
            " with the grob @var{sg} (even on an extender line).")
 {
-  LY_ASSERT_SMOB (Grob, sg, 1);
+  auto *const g = LY_ASSERT_SMOB (Grob, sg, 1);
   LY_ASSERT_TYPE (scm_is_number, spos, 2);
-  Grob *g = unsmob<Grob> (sg);
   Grob *st = Staff_symbol_referencer::get_staff_symbol (g);
   int pos = scm_to_int (spos);
   bool on_line = st ? Staff_symbol::on_line (g, pos) : false;
@@ -60,8 +58,7 @@ LY_DEFINE (ly_staff_symbol_line_thickness, "ly:staff-symbol-line-thickness",
            " associated with @var{grob}, expressed as a multiple of the"
            " current staff-space height.")
 {
-  LY_ASSERT_SMOB (Grob, grob, 1);
-  Grob *g = unsmob<Grob> (grob);
+  auto *const g = LY_ASSERT_SMOB (Grob, grob, 1);
   Real thickness = Staff_symbol_referencer::line_thickness (g);
   return to_scm (thickness);
 }
@@ -73,8 +70,7 @@ LY_DEFINE (ly_staff_symbol_staff_space, "ly:staff-symbol-staff-space",
            " default height of a staff-space in the traditional"
            " five-line staff.")
 {
-  LY_ASSERT_SMOB (Grob, grob, 1);
-  Grob *g = unsmob<Grob> (grob);
+  auto *const g = LY_ASSERT_SMOB (Grob, grob, 1);
   Real staff_space = Staff_symbol_referencer::staff_space (g);
   return to_scm (staff_space);
 }
@@ -84,8 +80,7 @@ LY_DEFINE (ly_staff_symbol_staff_radius, "ly:staff-symbol-staff-radius",
            "Returns the radius of the staff associated with"
            " @var{grob}.")
 {
-  LY_ASSERT_SMOB (Grob, grob, 1);
-  Grob *g = unsmob<Grob> (grob);
+  auto *const g = LY_ASSERT_SMOB (Grob, grob, 1);
   Real staff_radius = Staff_symbol_referencer::staff_radius (g);
   return to_scm (staff_radius);
 }
