@@ -58,7 +58,9 @@
 #include "stem-tremolo.hh"
 #include "warn.hh"
 
+#include <algorithm>
 #include <cmath> // rint
+#include <vector>
 
 using std::string;
 using std::vector;
@@ -268,7 +270,7 @@ Stem::note_head_positions (Grob *me, bool filter)
       ps.push_back (p);
     }
 
-  vector_sort (ps, std::less<int> ());
+  std::sort (ps.begin (), ps.end ());
   return ps;
 }
 
@@ -525,11 +527,11 @@ Stem::calc_positioning_done (SCM smob)
 
   extract_grob_set (me, "note-heads", ro_heads);
   vector<Grob *> heads (ro_heads);
-  vector_sort (heads, position_less);
+  std::sort (heads.begin (), heads.end (), position_less);
   Direction dir = get_grob_direction (me);
 
   if (dir < 0)
-    reverse (heads);
+    std::reverse (heads.begin (), heads.end ());
 
   Real thick = thickness (me);
 
@@ -737,7 +739,7 @@ Stem::internal_height (Grob *me, bool calc_beam)
     If there is a beam but no stem, slope calculations depend on this
     routine to return where the stem end /would/ be.
   */
-  if (calc_beam && !beam && !unsmob<Stencil> (get_property (me, "stencil")))
+  if (calc_beam && !beam && !unsmob<const Stencil> (get_property (me, "stencil")))
     return Interval ();
 
   Real y1 = from_scm<double> ((calc_beam
