@@ -111,20 +111,15 @@ LY_DEFINE (ly_stencil_translate_axis, "ly:stencil-translate-axis",
            "Return a copy of @var{stil} but translated by @var{amount}"
            " in @var{axis} direction.")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto s = *LY_ASSERT_SMOB (const Stencil, stil, 1);
   LY_ASSERT_TYPE (scm_is_number, amount, 2);
 
   LY_ASSERT_TYPE (is_scm<Axis>, axis, 3);
 
   Real real_amount = scm_to_double (amount);
 
-  SCM new_s = s->smobbed_copy ();
-  scm_remember_upto_here_1 (stil);
-
-  Stencil *q = unsmob<Stencil> (new_s);
-  q->translate_axis (real_amount, Axis (scm_to_int (axis)));
-  return new_s;
+  s.translate_axis (real_amount, Axis (scm_to_int (axis)));
+  return s.smobbed_copy ();
 }
 
 LY_DEFINE (ly_stencil_translate, "ly:stencil-translate",
@@ -132,25 +127,19 @@ LY_DEFINE (ly_stencil_translate, "ly:stencil-translate",
            "Return a @var{stil}, but translated by @var{offset}"
            " (a pair of numbers).")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto s = *LY_ASSERT_SMOB (const Stencil, stil, 1);
   LY_ASSERT_TYPE (is_number_pair, offset, 2);
   Offset o = from_scm<Offset> (offset);
 
-  SCM new_s = s->smobbed_copy ();
-  scm_remember_upto_here_1 (stil);
-
-  Stencil *q = unsmob<Stencil> (new_s);
-  q->translate (o);
-  return new_s;
+  s.translate (o);
+  return s.smobbed_copy ();
 }
 
 LY_DEFINE (ly_stencil_expr, "ly:stencil-expr",
            1, 0, 0, (SCM stil),
            "Return the expression of @var{stil}.")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto *const s = LY_ASSERT_SMOB (const Stencil, stil, 1);
   return s->expr ();
 }
 
@@ -160,8 +149,7 @@ LY_DEFINE (ly_stencil_extent, "ly:stencil-extent",
            " @var{axis} direction (@code{0} or @code{1} for x and"
            " y@tie{}axis, respectively).")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto *const s = LY_ASSERT_SMOB (const Stencil, stil, 1);
   LY_ASSERT_TYPE (is_scm<Axis>, axis, 2);
 
   return to_scm (s->extent (Axis (scm_to_int (axis))));
@@ -173,8 +161,7 @@ LY_DEFINE (ly_stencil_empty_p, "ly:stencil-empty?",
            " @var{axis} is supplied, the emptiness check is"
            " restricted to that axis.")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto *const s = LY_ASSERT_SMOB (const Stencil, stil, 1);
   if (SCM_UNBNDP (axis))
     return scm_from_bool (s->is_empty ());
   LY_ASSERT_TYPE (is_scm<Axis>, axis, 2);
@@ -192,8 +179,8 @@ LY_DEFINE (ly_stencil_combine_at_edge, "ly:stencil-combine-at-edge",
            " space.  @var{first} and @var{second} may also be @code{'()} or"
            " @code{#f}.")
 {
-  Stencil *s1 = unsmob<Stencil> (first);
-  Stencil *s2 = unsmob<Stencil> (second);
+  auto *const s1 = unsmob<const Stencil> (first);
+  auto *const s2 = unsmob<const Stencil> (second);
   Stencil result;
 
   SCM_ASSERT_TYPE (s1 || scm_is_false (first) || scm_is_null (first),
@@ -239,8 +226,8 @@ LY_DEFINE (ly_stencil_stack, "ly:stencil-stack",
            " apart at least by this distance.  If either of the stencils"
            " is spacing, @var{padding} and @var{mindist} do not apply.")
 {
-  Stencil *s1 = unsmob<Stencil> (first);
-  Stencil *s2 = unsmob<Stencil> (second);
+  auto *const s1 = unsmob<const Stencil> (first);
+  auto *const s2 = unsmob<const Stencil> (second);
   Stencil result;
 
   SCM_ASSERT_TYPE (s1 || scm_is_false (first) || scm_is_null (first),
@@ -290,7 +277,7 @@ LY_DEFINE (ly_stencil_add, "ly:stencil-add",
 
   for (SCM scm_s : as_ly_scm_list (args))
     {
-      Stencil *s = unsmob<Stencil> (scm_s);
+      auto *const s = unsmob<const Stencil> (scm_s);
       if (!s)
         SCM_ASSERT_TYPE (s, scm_s, SCM_ARGn, __FUNCTION__, "Stencil");
 
@@ -354,12 +341,10 @@ LY_DEFINE (ly_stencil_aligned_to, "ly:stencil-aligned-to",
            "  @w{@code{-1}} and @code{1} are left and right, respectively."
            "  Other values are interpolated (so @code{0} means the center).")
 {
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto target = *LY_ASSERT_SMOB (const Stencil, stil, 1);
   LY_ASSERT_TYPE (is_scm<Axis>, axis, 2);
   LY_ASSERT_TYPE (scm_is_number, dir, 3);
 
-  Stencil target = *unsmob<Stencil> (stil);
-
   target.align_to ((Axis)scm_to_int (axis),
                    scm_to_double (dir));
   return target.smobbed_copy ();
@@ -372,8 +357,7 @@ LY_DEFINE (ly_stencil_in_color, "ly:stencil-in-color",
            "@var{g}, @var{b} and an optional value"
            "for @var{a}, or a single CSS-like string.")
 {
-  LY_ASSERT_SMOB (Stencil, stc, 1);
-  Stencil *stil = unsmob<Stencil> (stc);
+  auto *const stil = LY_ASSERT_SMOB (const Stencil, stc, 1);
   SCM color;
   if (SCM_UNBNDP (g) && scm_is_string (r))
     color = r;
@@ -416,8 +400,7 @@ LY_DEFINE (ly_stencil_rotate, "ly:stencil-rotate",
            " the relative offset (@var{x}, @var{y}).  E.g., an offset of"
            " (-1, 1) will rotate the stencil around the left upper corner.")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto s = *LY_ASSERT_SMOB (const Stencil, stil, 1);
   LY_ASSERT_TYPE (scm_is_number, angle, 2);
   LY_ASSERT_TYPE (scm_is_number, x, 3);
   LY_ASSERT_TYPE (scm_is_number, y, 4);
@@ -425,10 +408,8 @@ LY_DEFINE (ly_stencil_rotate, "ly:stencil-rotate",
   Real x_off = scm_to_double (x);
   Real y_off = scm_to_double (y);
 
-  SCM new_s = s->smobbed_copy ();
-  Stencil *q = unsmob<Stencil> (new_s);
-  q->rotate_degrees (a, Offset (x_off, y_off));
-  return new_s;
+  s.rotate_degrees (a, Offset (x_off, y_off));
+  return s.smobbed_copy ();
 }
 
 LY_DEFINE (ly_stencil_rotate_absolute, "ly:stencil-rotate-absolute",
@@ -436,8 +417,7 @@ LY_DEFINE (ly_stencil_rotate_absolute, "ly:stencil-rotate-absolute",
            "Return a stencil @var{stil} rotated @var{angle} degrees around"
            " point (@var{x}, @var{y}), given in absolute coordinates.")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto s = *LY_ASSERT_SMOB (const Stencil, stil, 1);
   LY_ASSERT_TYPE (scm_is_number, angle, 2);
   LY_ASSERT_TYPE (scm_is_number, x, 3);
   LY_ASSERT_TYPE (scm_is_number, y, 4);
@@ -445,10 +425,8 @@ LY_DEFINE (ly_stencil_rotate_absolute, "ly:stencil-rotate-absolute",
   Real x_off = scm_to_double (x);
   Real y_off = scm_to_double (y);
 
-  SCM new_s = s->smobbed_copy ();
-  Stencil *q = unsmob<Stencil> (new_s);
-  q->rotate_degrees_absolute (a, Offset (x_off, y_off));
-  return new_s;
+  s.rotate_degrees_absolute (a, Offset (x_off, y_off));
+  return s.smobbed_copy ();
 }
 
 LY_DEFINE (ly_round_filled_box, "ly:round-filled-box",
@@ -524,16 +502,12 @@ LY_DEFINE (ly_stencil_scale, "ly:stencil-scale",
            " flip or mirror @var{stil} without changing its origin;"
            " this may result in collisions unless it is repositioned.")
 {
-  Stencil *s = unsmob<Stencil> (stil);
-  LY_ASSERT_SMOB (Stencil, stil, 1);
+  auto s = *LY_ASSERT_SMOB (const Stencil, stil, 1);
   LY_ASSERT_TYPE (scm_is_number, x, 2);
   LY_ASSERT_TYPE (scm_is_number, y, 3);
 
-  SCM new_s = s->smobbed_copy ();
-  Stencil *q = unsmob<Stencil> (new_s);
-
-  q->scale (scm_to_double (x), scm_to_double (y));
-  return new_s;
+  s.scale (scm_to_double (x), scm_to_double (y));
+  return s.smobbed_copy ();
 }
 
 LY_DEFINE (ly_stencil_outline, "ly:stencil-outline",
@@ -542,7 +516,7 @@ LY_DEFINE (ly_stencil_outline, "ly:stencil-outline",
            " of stencil @var{stil} but with outline and dimensions"
            " from stencil @var{outline}.")
 {
-  Stencil s = *LY_ASSERT_SMOB (Stencil, stil, 1);
-  Stencil o = *LY_ASSERT_SMOB (Stencil, outline, 2);
-  return s.with_outline (o).smobbed_copy ();
+  auto s = *LY_ASSERT_SMOB (const Stencil, stil, 1);
+  auto *const o = LY_ASSERT_SMOB (const Stencil, outline, 2);
+  return s.with_outline (*o).smobbed_copy ();
 }
