@@ -27,7 +27,6 @@
 #include "hara-kiri-group-spanner.hh"
 #include "international.hh"
 #include "lookup.hh"
-#include "main.hh"
 #include "output-def.hh"
 #include "page-layout-problem.hh"
 #include "paper-column.hh"
@@ -44,6 +43,7 @@
 
 #include <algorithm>
 #include <limits>
+#include <vector>
 
 using std::vector;
 
@@ -334,11 +334,9 @@ System::internal_get_note_heights_in_range (vsize start, vsize end, bool foot)
       SCM props
         = Lily::layout_extract_page_properties (pscore_->layout ()->self_scm ());
 
-      SCM footnote_stl = Text_interface::interpret_markup (pscore_->layout ()->self_scm (),
-                                                           props, footnote_markup);
-
-      Stencil *footnote_stencil = unsmob<Stencil> (footnote_stl);
-      out.push_back (footnote_stencil->extent (Y_AXIS).length ());
+      auto stencil = Text_interface::interpret_markup (pscore_->layout (),
+                                                       props, footnote_markup);
+      out.push_back (stencil.extent (Y_AXIS).length ());
     }
 
   return out;
@@ -402,7 +400,7 @@ System::footnotes_after_line_breaking (SCM smob)
   System *sys = dynamic_cast<System *> (sys_span);
   Interval_t<int> sri = sys->spanned_rank_interval ();
   vector<Grob *> footnote_grobs = sys->get_footnote_grobs_in_range (sri[LEFT], sri[RIGHT]);
-  vector_sort (footnote_grobs, grob_2D_less);
+  std::sort (footnote_grobs.begin (), footnote_grobs.end (), grob_2D_less);
 
   SCM grobs_scm = Grob_array::make_array ();
   unsmob<Grob_array> (grobs_scm)->set_array (footnote_grobs);
@@ -608,7 +606,7 @@ System::get_paper_system ()
       entries.push_back (e);
     }
 
-  vector_sort (entries, std::less<Layer_entry> ());
+  std::sort (entries.begin (), entries.end ());
   for (vsize j = 0; j < entries.size (); j++)
     {
       Grob *g = entries[j].grob_;
@@ -634,7 +632,7 @@ System::get_paper_system ()
       tail = SCM_CDRLOC (*tail);
     }
 
-  if (Stencil *me = get_stencil ())
+  if (auto *me = get_stencil ())
     exprs = scm_cons (me->expr (), exprs);
 
   Interval x (extent (this, X_AXIS));
