@@ -25,7 +25,6 @@
 #include "config.hh"
 #include "font-interface.hh"
 #include "grob.hh"
-#include "main.hh"
 #include "misc.hh"
 #include "modified-font-metric.hh"
 #include "output-def.hh"
@@ -35,28 +34,26 @@
 #include "warn.hh"
 #include "lily-imports.hh"
 
-#include <unordered_map>
-#include <vector>
+#include <map>
 
 using std::string;
-using std::unordered_map;
-using std::vector;
 
 // This is a little bit ugly, but the replacement alist is setup in
 // the layout block so it'll be the same across invocations.
 
-// size S-1 => {orig of size S => replacement}
-std::vector<unordered_map<string, string>> replacement_cache_;
-Protected_scm replacement_cache_alist_key_;
+std::map<string, string> replacement_cache;
+vsize replacement_max;
+Protected_scm replacement_cache_alist_key;
 
 static void
 populate_cache (SCM alist)
 {
-  if (alist == replacement_cache_alist_key_)
+  if (scm_is_eq (alist, static_cast<SCM> (replacement_cache_alist_key)))
     return;
 
-  replacement_cache_.clear ();
-  replacement_cache_alist_key_ = alist;
+  replacement_cache.clear ();
+  replacement_max = 0;
+  replacement_cache_alist_key = alist;
   for (SCM h = alist; scm_is_pair (h); h = scm_cdr (h))
     {
       SCM k = scm_caar (h);
@@ -70,9 +67,10 @@ populate_cache (SCM alist)
 
       string dest = ly_scm2string (v);
 
-      if (replacement_cache_.size () < orig.length ())
-        replacement_cache_.resize (orig.length ());
-      replacement_cache_[orig.length () - 1][orig] = dest;
+      // If an alist has duplicate key entries, only the first must be
+      // considered.
+      if (replacement_cache.insert ({orig, dest}).second)
+        replacement_max = std::max (replacement_max, orig.size ());
     }
 }
 
@@ -92,31 +90,46 @@ replace_special_characters (string &str, SCM props)
 
   populate_cache (replacement_alist);
 
-  vsize max_length = replacement_cache_.size ();
   for (vsize i = 0; i < str.size (); i++)
     {
-      /* Don't match in mid-UTF-8 */
-      if ((str[i] & 0xc0) == 0x80)
-        continue;
-      for (vsize j = max_length; j > 0; j--)
+      do
         {
-          if (j > str.size () - i)
-            continue;
-          // TODO: It could make sense to skip if not at the end of a UTF-8
-          // glyph. However that requires finding the start of the last glyph
-          // (not necessarily at str[i] - the longest replacement could match
-          // multiple glyphs) to get the glyph's length which is not trivial.
-          // So for now just continue checking all substrings that could be
-          // valid UTF-8 (see check for str[i] not in mid-UTF-8 above).
-          auto const &map = replacement_cache_[j - 1];
-          if (map.empty ())
-            continue;
+          // replacement loop while consecutive replacements happen
+          // We break out when this is not the case
 
-          string orig = str.substr (i, j);
-          auto it = map.find (orig);
-          if (it != map.end ())
-            str.replace (i, j, it->second);
+          /* Don't match in mid-UTF-8 */
+          if ((str[i] & 0xc0) == 0x80)
+            break;
+
+          // Using a C++17 string_view here instead of substr would
+          // obviate the need for maintaining replacement_max in order
+          // to keep complexity from becoming quadratic in string
+          // length.
+          auto it = replacement_cache.upper_bound (str.substr (i, replacement_max));
+          if (it == replacement_cache.begin ())
+            break;
+
+          --it;
+          // The iterator it now points to largest key smaller or equal
+          // to string tail.  In the case of several keys matching for
+          // their respective entire length, the longest matching key
+          // will be taken, being the lexicographically largest one.
+
+          const string &key = it->first;
+          vsize j = key.length ();
+          // Make sure that entire key is present in the source string
+          if (str.compare (i, j, key) != 0)
+            break;
+
+          const string &replacement = it->second;
+          str.replace (i, j, replacement);
+          // Stop doing replacements at this position and advance in the
+          // string up to just after the text we replaced with. This
+          // ensures that the result of a replacement is never processed
+          // itself for replacements.
+          i += replacement.length ();
         }
+      while (i < str.size ());
     }
 }
 
@@ -126,11 +139,10 @@ Text_interface::interpret_string (SCM layout_smob,
                                   SCM props,
                                   SCM markup)
 {
-  LY_ASSERT_SMOB (Output_def, layout_smob, 1);
+  auto *const layout = LY_ASSERT_SMOB (Output_def, layout_smob, 1);
   LY_ASSERT_TYPE (scm_is_string, markup, 3);
 
   string str = ly_scm2string (markup);
-  Output_def *layout = unsmob<Output_def> (layout_smob);
   Font_metric *fm = select_encoded_font (layout, props);
 
   replace_special_characters (str, props);
@@ -201,6 +213,25 @@ MAKE_SCHEME_CALLBACK_WITH_OPTARGS (Text_interface, interpret_markup, 3, 0,
                                    "  @var{markup} is the markup text to be processed.");
 SCM
 Text_interface::interpret_markup (SCM layout_smob, SCM props, SCM markup)
+{
+  auto *const layout = LY_ASSERT_SMOB (Output_def, layout_smob, 1);
+
+  return internal_interpret_markup (layout, props, markup);
+}
+
+Stencil
+Text_interface::interpret_markup (Output_def *layout, SCM props, SCM markup)
+{
+  Stencil result;
+  SCM st_scm = internal_interpret_markup (layout, props, markup);
+  if (auto *st = unsmob<const Stencil> (st_scm))
+    result = *st;
+  return result;
+}
+
+SCM
+Text_interface::internal_interpret_markup (Output_def *layout,
+                                           SCM props, SCM markup)
 {
   if (scm_is_string (markup))
     {
@@ -212,7 +243,7 @@ Text_interface::interpret_markup (SCM layout_smob, SCM props, SCM markup)
       if (scm_is_true (scm_string_null_p (markup)))
         return Stencil ().smobbed_copy ();
       else
-        return interpret_string (layout_smob, props, markup);
+        return interpret_string (to_scm (layout), props, markup);
     }
   else if (is_markup (markup))
     {
@@ -241,7 +272,7 @@ Text_interface::interpret_markup (SCM layout_smob, SCM props, SCM markup)
           return Stencil ().smobbed_copy ();
         }
 
-      SCM retval = scm_apply_2 (func, layout_smob, props, args);
+      SCM retval = scm_apply_2 (func, to_scm (layout), props, args);
       scm_dynwind_end ();
       return retval;
     }
@@ -260,8 +291,24 @@ MAKE_SCHEME_CALLBACK (Text_interface, print, 1);
 SCM
 Text_interface::print (SCM grob)
 {
-  Grob *me = unsmob<Grob> (grob);
+  auto *const me = LY_ASSERT_SMOB (Grob, grob, 1);
 
+  return internal_print (me);
+}
+
+Stencil
+Text_interface::print (Grob *me)
+{
+  Stencil result;
+  SCM st_scm = internal_print (me);
+  if (auto *st = unsmob<const Stencil> (st_scm))
+    result = *st;
+  return result;
+}
+
+SCM
+Text_interface::internal_print (Grob *me)
+{
   SCM t = get_property (me, "text");
   SCM chain = Font_interface::text_font_alist_chain (me);
   return interpret_markup (me->layout ()->self_scm (), chain, t);
