@@ -38,6 +38,7 @@
 #include "pointer-group-interface.hh"
 #include "output-def.hh"
 
+#include <algorithm>
 #include <array>
 #include <cmath>
 #include <cstdio>
@@ -50,6 +51,14 @@ using std::set;
 using std::string;
 using std::vector;
 
+template<typename T>
+T const &
+boundary (std::vector<T> const &v, int dir, vsize i)
+{
+  assert (dir);
+  return v[dir == -1 ? i : v.size () - 1 - i];
+}
+
 void
 Tie_formatting_problem::print_ties_configuration (Ties_configuration const *ties)
 {
@@ -290,19 +299,19 @@ Tie_formatting_problem::set_chord_outline (vector<Item *> bounds,
   for (vsize i = 0; i < bounds.size (); i++)
     ranks.push_back (bounds[i]->get_column ()->get_rank ());
 
-  vector_sort (ranks, std::less<int> ());
-  uniq (ranks);
+  std::sort (ranks.begin (), ranks.end ());
+  auto last = std::unique (ranks.begin (), ranks.end ());
 
-  for (vsize i = 0; i < ranks.size (); i++)
+  for (auto it = ranks.begin (); it != last; ++it)
     {
       vector<Item *> col_items;
       for (vsize j = 0; j < bounds.size (); j++)
         {
-          if (bounds[j]->get_column ()->get_rank () == ranks[i])
+          if (bounds[j]->get_column ()->get_rank () == *it)
             col_items.push_back (bounds[j]);
         }
 
-      set_column_chord_outline (col_items, dir, ranks[i]);
+      set_column_chord_outline (col_items, dir, *it);
     }
 }
 
@@ -1231,7 +1240,6 @@ Tie_formatting_problem::set_manual_tie_configuration (SCM manual_configs)
 void
 Tie_formatting_problem::set_debug_scoring (Ties_configuration const &base)
 {
-#if DEBUG_TIE_SCORING
   if (from_scm<bool> (x_refpoint_->layout ()
                       ->lookup_variable (ly_symbol2scm ("debug-tie-scoring"))))
     {
@@ -1242,5 +1250,4 @@ Tie_formatting_problem::set_debug_scoring (Ties_configuration const &base)
                         ly_string2scm (card));
         }
     }
-#endif
 }
