@@ -19,7 +19,6 @@
 
 #include "tie.hh"
 
-#include "main.hh"
 #include "bezier.hh"
 #include "directional-element-interface.hh"
 #include "font-interface.hh"
@@ -215,7 +214,7 @@ MAKE_SCHEME_CALLBACK (Tie, calc_control_points, 1);
 SCM
 Tie::calc_control_points (SCM smob)
 {
-  Spanner *me = LY_ASSERT_SMOB (Spanner, smob, 1);
+  auto *const me = LY_ASSERT_SMOB (Spanner, smob, 1);
 
   Grob *yparent = me->get_y_parent ();
   if ((has_interface<Tie_column> (yparent)
@@ -275,7 +274,6 @@ Tie::print (SCM smob)
                     line_thick,
                     dash_definition);
 
-#if DEBUG_TIE_SCORING
   SCM annotation = get_property (me, "annotation");
   if (scm_is_string (annotation))
     {
@@ -287,9 +285,8 @@ Tie::print (SCM smob)
                                           to_scm (-6), SCM_EOL),
                                properties);
 
-      Stencil tm = *unsmob<Stencil> (Text_interface::interpret_markup
-                                     (me->layout ()->self_scm (), properties,
-                                      annotation));
+      auto tm = Text_interface::interpret_markup (me->layout (), properties,
+                                                  annotation);
       tm.translate (Offset (b.control_[3][X_AXIS] + 0.5,
                             b.control_[0][Y_AXIS] * 2));
       tm = tm.in_color (1.0, 0.0, 0.0);
@@ -300,7 +297,6 @@ Tie::print (SCM smob)
       */
       a.add_stencil (tm);
     }
-#endif
 
   return a.smobbed_copy ();
 }
