@@ -25,6 +25,88 @@
 #include "moment.hh"
 #include "lily-imports.hh"
 
+void
+Timing_translator::derived_mark () const
+{
+  if (alt_event_)
+    scm_gc_mark (alt_event_->self_scm ());
+}
+
+void
+Timing_translator::listen_alternative (Stream_event *ev)
+{
+  // It is common to have the same repeat structure in multiple voices, so we
+  // ignore simultaneous events; but it might not be a bad thing to add some
+  // consistency checks here if they could catch some kinds of user error.
+  if (alt_event_)
+    return;
+
+  alt_event_ = ev;
+}
+
+void
+Timing_translator::process_music ()
+{
+  if (alt_event_)
+    {
+      // Which alternative is this?
+      // LEFT: starting the first alternative
+      // CENTER: starting a latter alternative
+      // RIGHT: ending the last alternative
+      const auto alt_dir
+        = from_scm (get_property (alt_event_, "alternative-dir"), CENTER);
+
+      switch (alt_dir)
+        {
+        case LEFT:
+          {
+            // Use a consistent numbering algorithm for the full set of
+            // alternatives by changing it only on the first alternative.
+            alt_reset_enabled_
+              = !scm_is_null (get_property (this, "alternativeNumberingStyle"));
+            if (alt_reset_enabled_)
+              {
+                alt_starting_bar_number_
+                  = from_scm (get_property (this, "currentBarNumber"), 0);
+              }
+
+            alt_number_ = 1;
+            break;
+          }
+
+        case CENTER:
+          if (alt_reset_enabled_)
+            {
+              set_property (context (), "currentBarNumber",
+                            to_scm (alt_starting_bar_number_));
+            }
+          alt_number_ += alt_number_increment_;
+          break;
+
+        default:
+          assert (false);
+        // fallthrough
+
+        case RIGHT:
+          alt_number_ = 0;
+          break;
+        }
+
+      if (alt_dir < RIGHT)
+        {
+          set_property (context (), "alternativeNumber", to_scm (alt_number_));
+          // will need to add this on the next alternative
+          alt_number_increment_
+            = from_scm (get_property (alt_event_, "alternative-increment"), 1);
+        }
+      else
+        {
+          set_property (context (), "alternativeNumber", SCM_EOL);
+        }
+
+    }
+}
+
 void
 Timing_translator::stop_translation_timestep ()
 {
@@ -41,6 +123,10 @@ Timing_translator::stop_translation_timestep ()
           find_global_context ()->add_moment_to_process (nextmom);
         }
     }
+
+  set_property (context (), "measureStartNow", SCM_EOL);
+
+  alt_event_ = nullptr;
 }
 
 void
@@ -156,42 +242,50 @@ Timing_translator::start_translation_timestep ()
       programming_error ("moving backwards in time");
       dt = 0;
     }
-  else if (dt.main_part_.is_infinity ())
+  else if (isinf (dt.main_part_))
     {
       programming_error ("moving infinitely to future");
       dt = 0;
     }
 
-  if (!dt.to_bool ())
+  if (!dt)
     return;
 
-  Moment measposp;
+  Rational mp;
+  {
+    auto mom = robust_scm2moment (get_property (this, "measurePosition"), now);
+    mp = mom.main_part_;
+  }
 
-  SCM s = get_property (this, "measurePosition");
-  if (unsmob<Moment> (s))
-    measposp = *unsmob<Moment> (s);
-  else
-    {
-      measposp = now;
-    }
-
-  int current_barnumber = from_scm (get_property (this, "currentBarNumber"), 0);
-  int internal_barnumber = from_scm (get_property (this, "internalBarNumber"), 0);
-
-  SCM cad = get_property (this, "timing");
-  bool c = from_scm<bool> (cad);
-
-  if (c)
+  if (from_scm<bool> (get_property (this, "timing")))
     {
       Rational len = measure_length ();
 
-      measposp += dt;
+      mp += dt.main_part_;
 
-      while (measposp.main_part_ >= len)
+      if (mp >= len)
         {
-          measposp.main_part_ -= len;
-          current_barnumber++;
-          internal_barnumber++;
+          auto cbn = from_scm (get_property (this, "currentBarNumber"), 0);
+          auto ibn = from_scm (get_property (this, "internalBarNumber"), 0);
+
+          do
+            {
+              mp -= len;
+              cbn++;
+              ibn++;
+            }
+          while (mp >= len);
+
+          set_property (context (), "currentBarNumber", to_scm (cbn));
+          set_property (context (), "internalBarNumber", to_scm (ibn));
+          measure_started_ = false;
+        }
+
+      if (!measure_started_ && !mp && dt.main_part_)
+        {
+          // We have arrived at zero (as opposed to revisiting it).
+          measure_started_ = true;
+          set_property (context (), "measureStartNow", SCM_BOOL_T);
         }
     }
 
@@ -207,11 +301,8 @@ Timing_translator::start_translation_timestep ()
   // still of.  Maybe we should keep measurePosition.grace_part_
   // constantly at zero anyway?
 
-  measposp.grace_part_ = now.grace_part_;
-
-  set_property (context (), "currentBarNumber", to_scm (current_barnumber));
-  set_property (context (), "internalBarNumber", to_scm (internal_barnumber));
-  set_property (context (), "measurePosition", measposp.smobbed_copy ());
+  set_property (context (), "measurePosition",
+                Moment (mp, now.grace_part_).smobbed_copy ());
 }
 
 #include "translator.icc"
@@ -219,7 +310,7 @@ Timing_translator::start_translation_timestep ()
 void
 Timing_translator::boot ()
 {
-
+  ADD_LISTENER (Timing_translator, alternative);
 }
 
 ADD_TRANSLATOR (Timing_translator,
@@ -234,6 +325,7 @@ ADD_TRANSLATOR (Timing_translator,
                 "",
 
                 /* read */
+                "alternativeNumberingStyle "
                 "baseMoment "
                 "currentBarNumber "
                 "internalBarNumber "
@@ -242,10 +334,12 @@ ADD_TRANSLATOR (Timing_translator,
                 "timeSignatureFraction ",
 
                 /* write */
+                "alternativeNumber "
                 "baseMoment "
                 "currentBarNumber "
                 "internalBarNumber "
                 "measureLength "
                 "measurePosition "
+                "measureStartNow "
                 "timeSignatureFraction "
                );
