@@ -80,7 +80,7 @@ get_x_bound_item (Grob *me_grob, Direction hdir, Direction my_dir)
     {
       Item *s = Note_column::get_stem (g);
       if (!Stem::is_invisible (s)
-          && unsmob<Stencil> (get_property (s, "stencil")))
+          && unsmob<const Stencil> (get_property (s, "stencil")))
         g = s;
     }
 
@@ -434,14 +434,11 @@ Tuplet_bracket::print (SCM smob)
                       SCM text = index_get_cell (edge_text, d);
                       if (Text_interface::is_markup (text))
                         {
-                          SCM t
-                            = Text_interface::interpret_markup (pap->self_scm (),
-                                                                properties, text);
-
-                          Stencil *edge_text = unsmob<Stencil> (t);
-                          edge_text->translate_axis (x_span[d] - x_span[LEFT],
-                                                     X_AXIS);
-                          edge_stencils[d] = *edge_text;
+                          auto &es = edge_stencils[d];
+                          es = Text_interface::interpret_markup (pap,
+                                                                 properties,
+                                                                 text);
+                          es.translate_axis (x_span[d] - x_span[LEFT], X_AXIS);
                         }
                     }
                 }
