@@ -224,13 +224,12 @@ Tuplet_number::print (SCM smob)
       return SCM_EOL;
     }
 
-  SCM stc_scm = Text_interface::print (smob);
-  Stencil *stc = unsmob<Stencil> (stc_scm);
+  auto stc = Text_interface::print (me);
 
-  stc->align_to (X_AXIS, CENTER);
-  stc->align_to (Y_AXIS, CENTER);
+  stc.align_to (X_AXIS, CENTER);
+  stc.align_to (Y_AXIS, CENTER);
 
-  return stc->smobbed_copy ();
+  return stc.smobbed_copy ();
 }
 
 /*
