@@ -17,8 +17,6 @@
   along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <cstring>
-
 #include "warn.hh"
 #include "font-interface.hh"
 #include "line-interface.hh"
@@ -33,6 +31,8 @@
 #include "bracket.hh"
 #include "lily-imports.hh"
 
+#include <cstring>
+
 using std::string;
 
 /*
@@ -67,7 +67,7 @@ Volta_bracket_interface::print (SCM smob)
       left = pc->break_align_width (pc, ly_symbol2scm ("break-alignment"))[RIGHT]
              // For some reason, break_align_width is relative to
              // the x-parent of the column.
-             - bound->relative_coordinate (pc->get_parent (X_AXIS), X_AXIS);
+             - bound->relative_coordinate (pc->get_x_parent (), X_AXIS);
     }
   else
     {
@@ -81,12 +81,12 @@ Volta_bracket_interface::print (SCM smob)
   if (!me->is_live ())
     return SCM_EOL;
 
-  Drul_array<Real> edge_height = robust_scm2interval (me->get_property ("edge-height"),
-                                                      Interval (1.0, 1.0));
-  Drul_array<Real> flare = robust_scm2interval (me->get_property ("bracket-flare"),
-                                                Interval (0, 0));
-  Drul_array<Real> shorten = robust_scm2interval (me->get_property ("shorten-pair"),
-                                                  Interval (0, 0));
+  Drul_array<Real> edge_height = from_scm (get_property (me, "edge-height"),
+                                           Drul_array<Real> (1.0, 1.0));
+  Drul_array<Real> flare = from_scm (get_property (me, "bracket-flare"),
+                                     Drul_array<Real> (0.0, 0.0));
+  Drul_array<Real> shorten = from_scm (get_property (me, "shorten-pair"),
+                                       Drul_array<Real> (0.0, 0.0));
 
   scale_drul (&edge_height, -static_cast<Real> (get_grob_direction (me)));
 
@@ -100,11 +100,9 @@ Volta_bracket_interface::print (SCM smob)
 
   if (!orig_span || broken_first_bracket)
     {
-      SCM text = me->get_property ("text");
+      SCM text = get_property (me, "text");
       SCM properties = me->get_property_alist_chain (SCM_EOL);
-      SCM snum = Text_interface::interpret_markup (layout->self_scm (),
-                                                   properties, text);
-      Stencil num = *unsmob<Stencil> (snum);
+      auto num = Text_interface::interpret_markup (layout, properties, text);
       num.align_to (Y_AXIS, UP);
       num.translate_axis (-0.5, Y_AXIS);
       total.add_at_edge (X_AXIS, LEFT, num, - num.extent (X_AXIS).length ()
@@ -127,7 +125,7 @@ Volta_bracket_interface::modify_edge_height (Spanner *me)
 
   extract_grob_set (me, "bars", bars);
   Grob *endbar = bars.size () ? bars.back () : 0;
-  SCM glyph = endbar ? endbar->get_property ("glyph-name") : SCM_EOL;
+  SCM glyph = endbar ? get_property (endbar, "glyph-name") : SCM_EOL;
 
   string str;
   if (scm_is_string (glyph))
@@ -140,15 +138,15 @@ Volta_bracket_interface::modify_edge_height (Spanner *me)
 
   if (no_vertical_end || no_vertical_start)
     {
-      Drul_array<Real> edge_height = robust_scm2interval (me->get_property ("edge-height"),
-                                                          Interval (1.0, 1.0));
+      Drul_array<Real> edge_height = from_scm (get_property (me, "edge-height"),
+                                               Drul_array<Real> (1.0, 1.0));
       if (no_vertical_start)
         edge_height[LEFT] = 0.0;
 
       if (no_vertical_end)
         edge_height[RIGHT] = 0.0;
 
-      me->set_property ("edge-height", ly_interval2scm (edge_height));
+      set_property (me, "edge-height", to_scm (edge_height));
     }
 
   if (broken_last_bracket && no_vertical_end && no_vertical_start
