@@ -46,9 +46,6 @@
   (let*
       ((tmp (make-tmpfile #f))
        (tmp-name (port-filename tmp)))
-    (cond-expand
-     (guile-2 (set-port-encoding! tmp "UTF-8"))
-     (else))
     (ly:debug (_ "Preparing Ghostscript command to `~a': ~a")
               tmp-name run-str)
     (display run-str tmp)
@@ -66,6 +63,7 @@
            "-dNODISPLAY"
            ;; see function gs-safe-run below where we use .setsafe instead
            "-dNOSAFER"
+           "-dALLOWPSTRANSPARENCY"
            "-dNOPAUSE"
            "-dBATCH"
            (if (and is-eps (not fit-page)) "-dEPSCrop")
@@ -442,6 +440,9 @@ definition."
             (display (list pango-font font-name)))
         (define-pango-pf pango-pf font-name scaling)))
 
+    ;; sort entries (which come from a hash) for reproducibility
     (string-append
-     (string-concatenate (map font-load-command other-fonts))
-     (string-concatenate (map pango-font-load-command pango-only-fonts)))))
+     (string-concatenate
+      (sort (map font-load-command other-fonts) string<?))
+     (string-concatenate
+      (sort (map pango-font-load-command pango-only-fonts) string<?)))))
