@@ -41,21 +41,24 @@
                     spacing-section-event layout-instruction-event
                     time-signature-event
                     completize-extender-event break-span-event alternative-event
-                    vowel-transition-event))
+                    vowel-transition-event
+                    duration-line-event))
 
     (layout-instruction-event . (apply-output-event))
     (script-event . (articulation-event text-script-event))
     (part-combine-event . (solo-one-event solo-two-event unisono-event))
     (break-event . (line-break-event page-break-event page-turn-event))
     (dynamic-event . (absolute-dynamic-event))
-    (span-event . (span-dynamic-event
-                   beam-event episema-event ligature-event
+    (span-event . (bend-span-event
+                   beam-event episema-event finger-glide-event
+                   ligature-event
                    measure-spanner-event
                    measure-counter-event pedal-event
                    phrasing-slur-event slur-event
+                   span-dynamic-event
                    staff-span-event text-span-event
                    trill-span-event tremolo-span-event
-                   tuplet-span-event))
+                   tuplet-span-event volta-span-event))
     (span-dynamic-event . (decrescendo-event crescendo-event))
     (break-span-event . (break-dynamic-span-event))
     (pedal-event . (sostenuto-event sustain-event una-corda-event))
