@@ -78,6 +78,59 @@ found in @file{scm/bar-line.scm}.
  '(delta-position
    thickness))
 
+(ly:add-interface
+  'bend-interface
+  "The (curved) line representing a bent string.\n
+Available for the @code{'style} property are @code{'hold}, @code{'pre-bend} and
+@code{'pre-bend-hold}.\n
+The following properties may be set in the details list.\n
+
+@table @code\n
+@item arrow-stencil\n
+The stencil procedure for the @code{BendSpanner} arrow head.\n
+@item curvature-factor\n
+Determines the horizontal part of a bend arrow as percentage of the total
+horizontal extent, usually between 0 and@tie{}1.\n
+@item bend-arrowhead-height\n
+The height of the arrow head.\n
+@item bend-arrowhead-width\n
+The width of the arrow head.\n
+@item bend-amount-strings\n
+An alist with entries for @code{'quarter}, @code{'half}, @code{'three-quarter}
+and @code{'full}, which are used to print how much a string is bent.\n
+@item curve-x-padding-line-end\n
+For a broken @code{BendSpanner}, set the padding at the line end to subsequent
+objects like changed @code{Clef}, etc.\n
+@item curve-y-padding-line-end\n
+For a broken @code{BendSpanner} started from a chord the curves don't match;
+there is a certain vertical gap specified by this value.\n
+@item dashed-line-settings\n
+List of three numeric values representing on, off and phase of a dashed line.\n
+@item head-text-break-visibility\n
+A vector of three booleans to set visibility of the arrow head and the text at
+a line break.  This is important for @code{'style} set to @code{'hold},
+@code{'pre-bend} or @code{'pre-bend-hold}.\n
+@item horizontal-left-padding\n
+The amount of horizontal free space between a @code{TabNoteHead} and the
+starting @code{BendSpanner}.\n
+@item successive-level\n
+An integer used as a factor determining the vertical coordinate of the starting
+@code{BendSpanner}.  If @code{successive-level} is@tie{}1, the
+@code{BendSpanner} starts at the @code{TabNoteHead}.  If consecutive
+@code{BendSpanner}s are set this value should be set to an appropriate value for
+the first one; later on, this value is maintained by the engraver.\n
+@item target-visibility\n
+A boolean to decide whether the target @code{TabNoteHead} should be visible.
+For up-pointing bends this is usually true.\n
+@item y-distance-from-tabstaff-to-arrow-tip\n
+This numeric value determines the distance between the @code{TabStaff} and the
+arrow head of the @code{BendSpanner}.\n
+@end table\n"
+  '(details
+    style
+    direction
+    bend-me))
+
 (ly:add-interface
  'clef-modifier-interface
  "The number describing transposition of the clef, placed below
@@ -115,6 +168,48 @@ or 15 (two octaves), but LilyPond allows any integer here."
  "An episema line."
  '())
 
+(ly:add-interface
+ 'finger-glide-interface
+ "The line between @code{Fingering} grobs indicating a glide with that finger.
+
+The property @code{style} may take the following symbols.
+
+@table @code
+@item line
+A simple connecting line.
+@item dashed-line
+Print a dashed line.  Customizable with settings for @code{dash-fraction} and
+@code{dash-period}.
+@item dotted-line
+Print a dotted line.
+@item stub-right
+The printed line is limited to a certain amount right before its right bound.
+This amount is configurable by a suitable setting for
+@code{bound-details.right.right-stub-length}.
+@item stub-left
+The printed line is limited to a certain amount right after its left bound.
+The amount is configurable by a suitable setting for
+@code{bound-details.right.left-stub-length}.
+@item stub-both
+The printed line combines the settings of @code{stub-left} and
+@code{stub-right}.
+@item zigzag
+A zigzag line, configurable with suitable settings for @code{zigzag-width} and
+@code{zigzag-length}.
+@item trill
+A trill style line.
+@item bow
+A bow style line.  The orientation of the bow may be tweaked with a suitable
+setting of @code{details.bow-direction}.
+@end table"
+
+ '(dash-fraction
+   dash-period
+   details
+   style
+   zigzag-length
+   zigzag-width))
+
 (ly:add-interface
  'finger-interface
  "A fingering instruction."
@@ -222,6 +317,11 @@ accidentals)."
  "Multi measure rest, and the text or number that is printed over it."
  '(bound-padding))
 
+(ly:add-interface
+ 'multi-measure-rest-number-interface
+ "Multi measure rest number that is printed over a rest."
+ '())
+
 (ly:add-interface
  'note-name-interface
  "Note names."
