@@ -111,6 +111,7 @@ smaller.")
 beamlet, as a proportion of the distance between two adjacent stems.")
      (before-line-breaking ,boolean? "Dummy property, used to trigger
 a callback function.")
+     (bend-me ,boolean? "Decide whether this grob is bent.")
      (between-cols ,pair? "Where to attach a loose column to.")
      (bound-details ,list? "An alist of properties for determining
 attachments of spanners to edges.")
@@ -807,9 +808,9 @@ parentheses widen to include any child Grobs with type among
 'parenthesis-friends.")
      (parenthesized ,boolean? "Parenthesize this grob.")
      (positions ,number-pair? "Pair of staff coordinates
-@code{(@var{left} . @var{right})}, where both @var{left} and
-@var{right} are in @code{staff-space} units of the current staff.  For
-slurs, this value selects which slur candidate to use; if extreme
+@code{(@var{start} . @var{end})}, where @var{start} and
+@var{end} are vertical positions in @code{staff-space} units of the current
+staff.  For slurs, this value selects which slur candidate to use; if extreme
 positions are requested, the closest one is taken.")
      (prefer-dotted-right ,boolean? "For note collisions, prefer to
 shift dotted up-note to the right, rather than shifting just the
@@ -1012,7 +1013,8 @@ bounds (i.e., clefs, key signatures and time signatures) using the following
 override:
 
 @example
-\\override MultiMeasureRest.spacing-pair = #'(staff-bar . staff-bar)
+\\override MultiMeasureRest.spacing-pair =
+             #'(staff-bar . staff-bar)
 @end example")
      (spanner-id ,key? "An identifier to distinguish concurrent spanners.")
      (springs-and-rods ,boolean? "Dummy variable for triggering
