@@ -14,6 +14,9 @@
 ;;;
 ;;; Scheme forms
 ;;;
+(define (number-list->lily-string scm-arg)
+  (string-join (map number->string scm-arg) ","))
+
 (define (scheme-expr->lily-string scm-arg)
   (cond ((or (number? scm-arg)
              (string? scm-arg)
@@ -33,6 +36,7 @@
                  (with-output-to-string
                    (lambda ()
                      (display-scheme-music scm-arg)))))))
+
 ;;;
 ;;; Markups
 ;;;
@@ -147,6 +151,10 @@ expression."
   " __")
 (define-display-method TieEvent (event)
   " ~")
+(define-display-method DurationLineEvent (event)
+  "\\-")
+(define-display-method BendSpanEvent (event)
+  "\\^")
 (define-display-method BeamForbidEvent (event)
   "\\noBeam")
 (define-display-method StringNumberEvent (event)
@@ -203,6 +211,7 @@ expression."
 (define-post-event-display-method BendAfterEvent (event) #f
   (format #f "\\bendAfter #~a " (ly:music-property event 'delta-step)))
 
+(define-post-event-display-method FingerGlideEvent (event) #f "\\glide")
 (define-post-event-display-method HarmonicEvent (event) #f "\\harmonic")
 (define-post-event-display-method GlissandoEvent (event) #f "\\glissando")
 (define-post-event-display-method ArpeggioEvent (event) #f "\\arpeggio")
@@ -702,6 +711,15 @@ expression."
 (define-display-method TremoloRepeatedMusic (expr)
   (repeat->lily-string expr "tremolo"))
 
+(define-display-method UnfoldedSpeccedMusic (m)
+  (format #f "\\unfolded ~a"
+          (music->lily-string (ly:music-property m 'element))))
+
+(define-display-method VoltaSpeccedMusic (m)
+  (format #f "\\volta ~a ~a"
+          (number-list->lily-string (ly:music-property m 'volta-numbers))
+          (music->lily-string (ly:music-property m 'element))))
+
 ;;;
 ;;; Contexts
 ;;;
