@@ -113,6 +113,11 @@ Syntax for manual control: @code{c8-[ c c-] c8}")
         (types . (post-event event beam-forbid-event))
         ))
 
+    (BendSpanEvent
+     . ((description . "Used to signal where a bend spanner starts and stops.")
+        (types . (bend-span-event post-event span-event event))
+        ))
+
     (BreakDynamicSpanEvent
      . ((description . "End an alignment spanner for dynamics here.")
         (types . (post-event break-span-event break-dynamic-span-event event))
@@ -232,6 +237,14 @@ duration stored in @code{duration}.")
         (types . (post-event fingering-event event))
         ))
 
+    (FingerGlideEvent
+     . ((description . "Initiate a line connecting two equal fingerings.
+This line represents a finger gliding on a string.
+
+Syntax: @var{note}@code{\\glide}@code{-}@var{finger}")
+        (types . (finger-glide-event post-event event))
+        ))
+
     (FootnoteEvent
      . ((description . "Footnote a grob.")
         (types . (event footnote-event))
@@ -294,7 +307,7 @@ Syntax: @var{note}@code{\\laissezVibrer}")
      . ((description . "Align lyrics to the start of notes.
 
 Syntax: @code{\\lyricsto} @var{voicename} @var{lyrics}")
-        (length . ,ZERO-MOMENT)
+        (length . ,INF-MOMENT)
         (types . (lyric-combine-music))
         (iterator-ctor . ,ly:lyric-combine-music-iterator::constructor)
         ))
@@ -441,8 +454,9 @@ as separate voices.")
     (PercentRepeatedMusic
      . ((description . "Repeats encoded by percents and slashes.")
         (iterator-ctor . ,ly:percent-repeat-iterator::constructor)
-        (start-callback .  ,ly:repeated-music::first-start)
-        (length-callback . ,ly:repeated-music::unfolded-music-length)
+        (elements-callback . ,make-percent-set)
+        (start-callback .  ,ly:calculated-sequential-music::start)
+        (length-callback . ,ly:calculated-sequential-music::length)
         (types . (repeated-music percent-repeated-music))
         ))
 
@@ -705,9 +719,10 @@ Syntax: @code{\\times @var{fraction} @var{music}}, e.g.,
 
     (TremoloRepeatedMusic
      . ((description . "Repeated notes denoted by tremolo beams.")
-        (iterator-ctor . ,ly:chord-tremolo-iterator::constructor)
-        (start-callback .  ,ly:repeated-music::first-start)
-        (length-callback . ,ly:repeated-music::unfolded-music-length)
+        (iterator-ctor . ,ly:sequential-iterator::constructor)
+        (elements-callback . ,make-tremolo-set)
+        (start-callback .  ,ly:calculated-sequential-music::start)
+        (length-callback . ,ly:calculated-sequential-music::length)
         (types . (repeated-music tremolo-repeated-music))
         ))
 
@@ -737,9 +752,19 @@ brackets start and stop.")
 played) out.")
         (iterator-ctor . ,ly:sequential-iterator::constructor)
         (elements-callback . ,make-unfolded-set)
-        (start-callback .  ,ly:repeated-music::first-start)
+        (start-callback .  ,ly:calculated-sequential-music::start)
+        (length-callback . ,ly:calculated-sequential-music::length)
         (types . (repeated-music unfolded-repeated-music))
-        (length-callback . ,ly:repeated-music::unfolded-music-length)
+        ))
+
+    (UnfoldedSpeccedMusic
+     . ((description . "Music that appears once repeated music is unfolded.")
+        ;; We never want to iterate music that is thus wrapped.  If
+        ;; repeats are unfolded, this wrapper is removed and the
+        ;; unwrapped music is iterated according to its type.
+        (iterator-ctor . ,ly:music-iterator::constructor)
+        (length . ,ZERO-MOMENT)
+        (types . (unfolded-specification music-wrapper-music))
         ))
 
     (UnisonoEvent
@@ -768,10 +793,24 @@ Syntax: @code{\\\\}")
      . ((description . "Repeats with alternatives placed sequentially.")
         (iterator-ctor . ,ly:volta-repeat-iterator::constructor)
         (elements-callback . ,make-volta-set)
-        (start-callback .  ,ly:repeated-music::first-start)
-        (length-callback . ,ly:repeated-music::volta-music-length)
+        (start-callback .  ,ly:calculated-sequential-music::start)
+        (length-callback . ,ly:calculated-sequential-music::length)
         (types . (repeated-music volta-repeated-music))
         ))
+
+    (VoltaSpanEvent
+     . ((description . "Used internally to signal where volta
+brackets start and stop.")
+        (types . (volta-span-event span-event event post-event))
+        ))
+
+    (VoltaSpeccedMusic
+     . ((description . "Music for a specific volta within repeated music.")
+        (iterator-ctor . ,ly:volta-specced-music-iterator::constructor)
+        (length-callback . ,ly:music-wrapper::length-callback)
+        (start-callback . ,ly:music-wrapper::start-callback)
+        (types . (volta-specification music-wrapper-music))
+        ))
     ))
 
 (set! music-descriptions
