@@ -109,6 +109,14 @@
    (string-append
     (format #f "%%Page: ~a ~a\n" page-number page-number)
     "%%BeginPageSetup\n"
+    "<< /PageUsesTransparency true\n"
+    "   /CompatibilityLevel 1.4\n"
+    "   /PageSpotColors 0\n"
+    ">> setpagedevice\n"
+    "0 .pushpdf14devicefilter\n"
+    "<< >> clippath pathbbox newpath .begintransparencygroup\n"
+    "1.0 .setfillconstantalpha\n"
+    "1.0 .setstrokeconstantalpha\n"
     (if landscape?
         "page-width output-scale lily-output-units mul mul 0 translate 90 rotate\n"
         "")
@@ -116,6 +124,7 @@
     "\n"
     "gsave 0 paper-height translate set-ps-scale-to-lily-scale\n"))
   (ly:outputter-dump-stencil outputter page-stencil)
+  (ly:outputter-dump-string outputter ".endtransparencygroup\n.poppdf14devicefilter\n")
   (ly:outputter-dump-string outputter "stroke grestore\nshowpage\n"))
 
 (define (supplies-or-needs paper load-fonts?)
@@ -345,8 +354,8 @@
                                    (ly:get-option 'datadir)
                                    "" file-name))
                   (format #f
-                    "lilypond-datadir (~a) concatstrings (r) file .loadfont\n"
-                    file-name))
+                          "lilypond-datadir (~a) concatstrings (r) file .loadfont\n"
+                          file-name))
                 (format #f "(~a) (r) file .loadfont\n" file-name)))
           (format #f "% cannot find font file: ~a\n" file-name)))
 
@@ -625,6 +634,18 @@
   (display (setup-variables paper) port)
 
   ;; adobe note 5002: should initialize variables before loading routines.
+  (display "systemdict /.setalphaisshape known not
+{
+  /PageUsesTransparency        false def
+  /.currentstrokeconstantalpha 1.0 def
+  /.currentfillconstantalpha   1.0 def
+  /.pushpdf14devicefilter      {pop} bind def
+  /.poppdf14devicefilter       {} bind def
+  /.begintransparencygroup     {pop pop pop pop pop} bind def
+  /.endtransparencygroup       {} bind def
+  /.setfillconstantalpha       {pop} bind def
+  /.setstrokeconstantalpha     {pop} bind def
+} if\n" port)
   (display (procset "music-drawing-routines.ps") port)
   (display (procset "lilyponddefs.ps") port)
   (display "%%EndProlog\n" port)
@@ -726,13 +747,13 @@ mark {ly~a_stream} /CLOSE pdfmark
          (set! remaining (cdr remaining))
          (if (and (number? page-number) alist
                   (not (memq id remaining)))
-             (display
-              (format "mark /Page ~a /Title (~a) /Count ~a\
+             (format
+              port
+              "mark /Page ~a /Title (~a) /Count ~a\
  /View [/XYZ null null 0] /Subtype /Link /OUT pdfmark\n"
-                      page-number
-                      (ps-quote (markup->string (assoc-get 'text alist)))
-                      (length (assoc-get 'children alist)))
-              port))))
+              page-number
+              (ps-quote (markup->string (assoc-get 'text alist)))
+              (length (assoc-get 'children alist))))))
      sorted-page-numbers)))
 
 (define-public (output-framework basename book scopes fields)
@@ -747,8 +768,8 @@ mark {ly~a_stream} /CLOSE pdfmark
          (page-number (1- (ly:output-def-lookup paper 'first-page-number)))
          (page-count (length page-stencils)))
     (cond-expand
-      (guile-2 (set-port-encoding! port "Latin1"))
-      (else))
+     (guile-2 (set-port-encoding! port "Latin1"))
+     (else))
     (initialize-font-embedding)
     (if (ly:get-option 'clip-systems)
         (clip-system-EPSes basename book))
