@@ -57,6 +57,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; moments
 
+(define-public INF-MOMENT (ly:make-moment +inf.0))
 (define-public ZERO-MOMENT (ly:make-moment 0 1))
 
 (define-public (moment-min a b)
@@ -153,6 +154,8 @@ This supports historic use of @code{Completion_heads_engraver} to split
                      (cons score (ly:parser-lookup 'toplevel-scores))))
 
 (define-public (collect-music-aux score-handler music)
+  "Pass @var{music} to @var{score-handler}, with preprocessing
+for page layout instructions. "
   (define (music-property symbol)
     (ly:music-property music symbol #f))
   (cond ((music-property 'page-marker)
@@ -942,7 +945,7 @@ numbers."
 ;;;;;;;;;;;;;;;;
 ;; other
 
-(define (sign x)
+(define-public (sign x)
   (if (= x 0)
       0
       (if (< x 0) -1 1)))
