@@ -219,7 +219,7 @@ variables to their value after the initial call of @var{thunk}."
           (module-for-each
            (lambda (s v)
              (let ((val (variable-ref v)))
-               (if (not (ly:lily-parser? val))
+               (if (and (not (eq? s '%module-public-interface)) (not (ly:lily-parser? val)))
                    (set! decl
                          (cons
                           (cons* s v val)
@@ -252,10 +252,12 @@ EPS backend.")
     (clip-systems #f
                   "Generate cut-out snippets of a score.")
     (crop #f
-          "Match the size of the normal output to the
-typeset image.")
+          "Generate additional, possibly tall
+single-page output file(s) with cropped margins.")
     (datadir #f
              "LilyPond prefix for data files (read-only).")
+    (debug-eval ,(ly:verbose-output?)
+                "Use the debugging Scheme evaluator.")
     (debug-gc #f
               "Dump memory debugging statistics.")
     (debug-gc-assert-parsed-dead #f
@@ -477,7 +479,7 @@ messages into errors.")
 ;;; default.
 
 
-(if (or (ly:get-option 'verbose))
+(if (or (ly:get-option 'verbose) (ly:get-option 'debug-eval))
     (begin
       (ly:set-option 'protected-scheme-parsing #f)
       (debug-enable 'backtrace)
@@ -724,7 +726,6 @@ messages into errors.")
 
 (define-public lilypond-exported-predicates
   `((,ly:book? . "book")
-    (,ly:box? . "box")
     (,ly:context? . "context")
     (,ly:context-def? . "context definition")
     (,ly:context-mod? . "context modification")
@@ -966,7 +967,9 @@ PIDs or the number of the process."
 
   (if (string-or-symbol? (ly:get-option 'log-file))
       (ly:stderr-redirect (format #f "~a.log" (ly:get-option 'log-file)) "w"))
-  (let ((failed (lilypond-all files)))
+  (let ((log-file (and (ly:get-option 'separate-log-files) (dup 2)))
+        (failed (lilypond-all files)))
+    (if log-file (ly:stderr-redirect log-file))
     (if (pair? failed)
         (begin (ly:error (_ "failed files: ~S") (string-join failed))
                (ly:exit 1 #f))
@@ -977,12 +980,7 @@ PIDs or the number of the process."
 (define-public (lilypond-all files)
   (let* ((failed '())
          (separate-logs (ly:get-option 'separate-log-files))
-         (ping-log
-          (and separate-logs
-               (if (string-or-symbol? (ly:get-option 'log-file))
-                   (open-file (format #f "~a.log" (ly:get-option 'log-file))
-                              "a")
-                   (fdes->outport 2))))
+         (ping-log (and separate-logs (dup 2)))
          (handler (lambda (key failed-file)
                     (set! failed (append (list failed-file) failed)))))
     (cond-expand
@@ -992,10 +990,12 @@ PIDs or the number of the process."
      (lambda (x)
        (let* ((base (dir-basename x ".ly"))
               (all-settings (ly:all-options)))
+         (if ping-log
+             (begin
+               (ly:stderr-redirect ping-log)
+               (ly:message (_ "Processing `~a'\n") x)))
          (if separate-logs
              (ly:stderr-redirect (format #f "~a.log" base) "w"))
-         (if ping-log
-             (format ping-log "Processing ~a\n" base))
          (lilypond-file handler x)
          (ly:check-expected-warnings)
          (session-terminate)
@@ -1025,10 +1025,6 @@ PIDs or the number of the process."
              (ly:reset-all-fonts))
          (flush-all-ports)))
      files)
-
-    ;; Ensure a notice re failed files is written to aggregate logfile.
-    (if ping-log
-        (format ping-log "Failed files: ~a\n" failed))
     failed))
 
 (define (lilypond-file handler file-name)
@@ -1051,8 +1047,6 @@ PIDs or the number of the process."
       (let ((failed (lilypond-all files)))
         (if (pair? failed)
             (begin
-              ;; ugh
-              (ly:stderr-redirect "foo" "r")
               (system (get-editor-command log-name 0 0 0))
               (ly:error (_ "failed files: ~S") (string-join failed))
               ;; not reached?
